=== modified file 'bzrlib/__init__.py'
--- bzrlib/__init__.py	2011-12-19 13:23:58 +0000
+++ bzrlib/__init__.py	2012-01-16 17:24:42 +0000
@@ -46,7 +46,7 @@
 IGNORE_FILENAME = ".bzrignore"
 
 
-__copyright__ = "Copyright 2005-2011 Canonical Ltd."
+__copyright__ = "Copyright 2005-2012 Canonical Ltd."
 
 # same format as sys.version_info: "A tuple containing the five components of
 # the version number: major, minor, micro, releaselevel, and serial. All
@@ -55,7 +55,7 @@
 # Python version 2.0 is (2, 0, 0, 'final', 0)."  Additionally we use a
 # releaselevel of 'dev' for unreleased under-development code.
 
-version_info = (2, 5, 0, 'dev', 5)
+version_info = (2, 5, 0, 'dev', 6)
 
 # API compatibility version
 api_minimum_version = (2, 4, 0)

=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2012-01-04 17:12:42 +0000
+++ bzrlib/branch.py	2012-01-07 01:45:31 +0000
@@ -2038,6 +2038,8 @@
         :param name: Name of colocated branch to create, if any
         :return: a branch in this format
         """
+        if name is None:
+            name = a_bzrdir._get_selected_branch()
         mutter('creating branch %r in %s', self, a_bzrdir.user_url)
         branch_transport = a_bzrdir.get_branch_transport(self, name=name)
         control_files = lockable_files.LockableFiles(branch_transport,
@@ -2060,6 +2062,8 @@
     def open(self, a_bzrdir, name=None, _found=False, ignore_fallbacks=False,
             found_repository=None, possible_transports=None):
         """See BranchFormat.open()."""
+        if name is None:
+            name = a_bzrdir._get_selected_branch()
         if not _found:
             format = BranchFormatMetadir.find_format(a_bzrdir, name=name)
             if format.__class__ != self.__class__:
@@ -2305,12 +2309,13 @@
         mutter('creating branch reference in %s', a_bzrdir.user_url)
         if a_bzrdir._format.fixed_components:
             raise errors.IncompatibleFormat(self, a_bzrdir._format)
+        if name is None:
+            name = a_bzrdir._get_selected_branch()
         branch_transport = a_bzrdir.get_branch_transport(self, name=name)
         branch_transport.put_bytes('location',
             target_branch.user_url)
         branch_transport.put_bytes('format', self.as_string())
-        branch = self.open(
-            a_bzrdir, name, _found=True,
+        branch = self.open(a_bzrdir, name, _found=True,
             possible_transports=[target_branch.bzrdir.root_transport])
         self._run_post_branch_init_hooks(a_bzrdir, name, branch)
         return branch
@@ -2342,6 +2347,8 @@
             a_bzrdir.
         :param possible_transports: An optional reusable transports list.
         """
+        if name is None:
+            name = a_bzrdir._get_selected_branch()
         if not _found:
             format = BranchFormatMetadir.find_format(a_bzrdir, name=name)
             if format.__class__ != self.__class__:
@@ -2351,8 +2358,7 @@
             location = self.get_reference(a_bzrdir, name)
         real_bzrdir = controldir.ControlDir.open(
             location, possible_transports=possible_transports)
-        result = real_bzrdir.open_branch(name=name, 
-            ignore_fallbacks=ignore_fallbacks,
+        result = real_bzrdir.open_branch(ignore_fallbacks=ignore_fallbacks,
             possible_transports=possible_transports)
         # this changes the behaviour of result.clone to create a new reference
         # rather than a copy of the content of the branch.
@@ -2445,10 +2451,11 @@
         """Create new branch object at a particular location."""
         if a_bzrdir is None:
             raise ValueError('a_bzrdir must be supplied')
-        else:
-            self.bzrdir = a_bzrdir
+        if name is None:
+            raise ValueError('name must be supplied')
+        self.bzrdir = a_bzrdir
         self._user_transport = self.bzrdir.transport.clone('..')
-        if name is not None:
+        if name != "":
             self._user_transport.set_segment_parameter(
                 "branch", urlutils.escape(name))
         self._base = self._user_transport.base

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2012-01-05 09:50:04 +0000
+++ bzrlib/builtins.py	2012-01-17 10:30:33 +0000
@@ -1444,13 +1444,13 @@
         else:
             dir = controldir.ControlDir.open_containing(location)[0]
             try:
-                active_branch = dir.open_branch(name=None)
+                active_branch = dir.open_branch(name="")
             except errors.NotBranchError:
                 active_branch = None
             branches = dir.get_branches()
             names = {}
             for name, branch in branches.iteritems():
-                if name is None:
+                if name == "":
                     continue
                 active = (active_branch is not None and
                           active_branch.base == branch.base)
@@ -4168,7 +4168,7 @@
     Merge will do its best to combine the changes in two branches, but there
     are some kinds of problems only a human can fix.  When it encounters those,
     it will mark a conflict.  A conflict means that you need to fix something,
-    before you should commit.
+    before you can commit.
 
     Use bzr resolve when you have fixed a problem.  See also bzr conflicts.
 

=== modified file 'bzrlib/bzrdir.py'
--- bzrlib/bzrdir.py	2011-12-22 19:54:56 +0000
+++ bzrlib/bzrdir.py	2012-01-07 01:06:26 +0000
@@ -829,7 +829,9 @@
 
     def destroy_branch(self, name=None):
         """See BzrDir.create_branch."""
-        if name is not None:
+        if name is None:
+            name = self._get_selected_branch()
+        if name != "":
             raise errors.NoColocatedBranchSupport(self)
         self.transport.delete_tree('branch')
 
@@ -887,7 +889,9 @@
 
     def get_branch_transport(self, branch_format, name=None):
         """See BzrDir.get_branch_transport()."""
-        if name is not None:
+        if name is None:
+            name = self._get_selected_branch()
+        if name != "":
             raise errors.NoColocatedBranchSupport(self)
         # XXX: this shouldn't implicitly create the directory if it's just
         # promising to get a transport -- mbp 20090727
@@ -1021,7 +1025,7 @@
         :param name: Optional branch name to use
         :return: Relative path to branch
         """
-        if name is None:
+        if name == "":
             return 'branch'
         return urlutils.join('branches', name.encode("utf-8"))
 
@@ -1056,7 +1060,7 @@
         if name is None:
             name = self._get_selected_branch()
         path = self._get_branch_path(name)
-        if name is not None:
+        if name != "":
             self.control_files.lock_write()
             try:
                 branches = self._read_branch_list()
@@ -1073,17 +1077,19 @@
         """See ControlDir.get_branches."""
         ret = {}
         try:
-            ret[None] = self.open_branch()
+            ret[""] = self.open_branch(name="")
         except (errors.NotBranchError, errors.NoRepositoryPresent):
             pass
 
         for name in self._read_branch_list():
-            ret[name] = self.open_branch(name.decode('utf-8'))
+            ret[name] = self.open_branch(name=name.decode('utf-8'))
 
         return ret
 
     def get_branch_transport(self, branch_format, name=None):
         """See BzrDir.get_branch_transport()."""
+        if name is None:
+            name = self._get_selected_branch()
         path = self._get_branch_path(name)
         # XXX: this shouldn't implicitly create the directory if it's just
         # promising to get a transport -- mbp 20090727
@@ -1093,7 +1099,7 @@
             branch_format.get_format_string()
         except NotImplementedError:
             raise errors.IncompatibleFormat(branch_format, self._format)
-        if name is not None:
+        if name != "":
             try:
                 self.transport.mkdir('branches', mode=self._get_mkdir_mode())
             except errors.FileExists:

=== modified file 'bzrlib/config.py'
--- bzrlib/config.py	2012-01-05 14:10:32 +0000
+++ bzrlib/config.py	2012-01-13 15:05:42 +0000
@@ -73,7 +73,7 @@
 """
 
 from __future__ import absolute_import
-
+from cStringIO import StringIO
 import os
 import sys
 
@@ -83,7 +83,6 @@
 lazy_import(globals(), """
 import fnmatch
 import re
-from cStringIO import StringIO
 
 from bzrlib import (
     atomicfile,
@@ -3114,10 +3113,6 @@
 class IniFileStore(Store):
     """A config Store using ConfigObj for storage.
 
-    :ivar transport: The transport object where the config file is located.
-
-    :ivar file_name: The config file basename in the transport directory.
-
     :ivar _config_obj: Private member to hold the ConfigObj instance used to
         serialize/deserialize the config file.
     """
@@ -3253,9 +3248,19 @@
             value = self._config_obj._unquote(value)
         return value
 
+    def external_url(self):
+        # Since an IniFileStore can be used without a file (at least in tests),
+        # it's better to provide something than raising a NotImplementedError.
+        # All daughter classes are supposed to provide an implementation
+        # anyway.
+        return 'In-Process Store, no URL'
 
 class TransportIniFileStore(IniFileStore):
     """IniFileStore that loads files from a transport.
+
+    :ivar transport: The transport object where the config file is located.
+
+    :ivar file_name: The config file basename in the transport directory.
     """
 
     def __init__(self, transport, file_name):
@@ -3435,9 +3440,8 @@
 
 class LocationSection(Section):
 
-    def __init__(self, section, length, extra_path):
+    def __init__(self, section, extra_path):
         super(LocationSection, self).__init__(section.id, section.options)
-        self.length = length
         self.extra_path = extra_path
         self.locals = {'relpath': extra_path,
                        'basename': urlutils.basename(extra_path)}
@@ -3465,6 +3469,53 @@
         return value
 
 
+class StartingPathMatcher(SectionMatcher):
+    """Select sections for a given location respecting the Store order."""
+
+    # FIXME: Both local paths and urls can be used for section names as well as
+    # ``location`` to stay consistent with ``LocationMatcher`` which itself
+    # inherited the fuzziness from the previous ``LocationConfig``
+    # implementation. We probably need to revisit which encoding is allowed for
+    # both ``location`` and section names and how we normalize
+    # them. http://pad.lv/85479, http://pad.lv/437009 and http://359320 are
+    # related too. -- vila 2012-01-04
+
+    def __init__(self, store, location):
+        super(StartingPathMatcher, self).__init__(store)
+        if location.startswith('file://'):
+            location = urlutils.local_path_from_url(location)
+        self.location = location
+
+    def get_sections(self):
+        """Get all sections matching ``location`` in the store.
+
+        The most generic sections are described first in the store, then more
+        specific ones can be provided for reduced scopes.
+
+        The returned section are therefore returned in the reversed order so
+        the most specific ones can be found first.
+        """
+        location_parts = self.location.rstrip('/').split('/')
+        store = self.store
+        sections = []
+        # Later sections are more specific, they should be returned first
+        for _, section in reversed(list(store.get_sections())):
+            if section.id is None:
+                # The no-name section is always included if present
+                yield store, LocationSection(section, self.location)
+                continue
+            section_path = section.id
+            if section_path.startswith('file://'):
+                # the location is already a local path or URL, convert the
+                # section id to the same format
+                section_path = urlutils.local_path_from_url(section_path)
+            if (self.location.startswith(section_path)
+                or fnmatch.fnmatch(self.location, section_path)):
+                section_parts = section_path.rstrip('/').split('/')
+                extra_path = '/'.join(location_parts[len(section_parts):])
+                yield store, LocationSection(section, extra_path)
+
+
 class LocationMatcher(SectionMatcher):
 
     def __init__(self, store, location):
@@ -3494,7 +3545,7 @@
         matching_sections = []
         if no_name_section is not None:
             matching_sections.append(
-                LocationSection(no_name_section, 0, self.location))
+                (0, LocationSection(no_name_section, self.location)))
         for section_id, extra_path, length in filtered_sections:
             # a section id is unique for a given store so it's safe to take the
             # first matching section while iterating. Also, all filtered
@@ -3504,7 +3555,7 @@
                 section = iter_all_sections.next()
                 if section_id == section.id:
                     matching_sections.append(
-                        LocationSection(section, length, extra_path))
+                        (length, LocationSection(section, extra_path)))
                     break
         return matching_sections
 
@@ -3513,10 +3564,10 @@
         matching_sections = self._get_matching_sections()
         # We want the longest (aka more specific) locations first
         sections = sorted(matching_sections,
-                          key=lambda section: (section.length, section.id),
+                          key=lambda (length, section): (length, section.id),
                           reverse=True)
         # Sections mentioning 'ignore_parents' restrict the selection
-        for section in sections:
+        for _, section in sections:
             # FIXME: We really want to use as_bool below -- vila 2011-04-07
             ignore = section.get('ignore_parents', None)
             if ignore is not None:

=== modified file 'bzrlib/conflicts.py'
--- bzrlib/conflicts.py	2011-12-18 12:46:49 +0000
+++ bzrlib/conflicts.py	2012-01-16 14:45:48 +0000
@@ -52,7 +52,7 @@
     Merge will do its best to combine the changes in two branches, but there
     are some kinds of problems only a human can fix.  When it encounters those,
     it will mark a conflict.  A conflict means that you need to fix something,
-    before you should commit.
+    before you can commit.
 
     Conflicts normally are listed as short, human-readable messages.  If --text
     is supplied, the pathnames of files with text conflicts are listed,
@@ -106,7 +106,7 @@
     Merge will do its best to combine the changes in two branches, but there
     are some kinds of problems only a human can fix.  When it encounters those,
     it will mark a conflict.  A conflict means that you need to fix something,
-    before you should commit.
+    before you can commit.
 
     Once you have fixed a problem, use "bzr resolve" to automatically mark
     text conflicts as fixed, "bzr resolve FILE" to mark a specific conflict as

=== modified file 'bzrlib/controldir.py'
--- bzrlib/controldir.py	2012-01-03 13:47:01 +0000
+++ bzrlib/controldir.py	2012-01-06 23:29:07 +0000
@@ -116,7 +116,7 @@
         :return: Dictionary mapping branch names to instances.
         """
         try:
-           return { None: self.open_branch() }
+           return { "": self.open_branch() }
         except (errors.NotBranchError, errors.NoRepositoryPresent):
            return {}
 
@@ -294,9 +294,9 @@
         :return: Name of the branch selected by the user, or None.
         """
         branch = self.root_transport.get_segment_parameters().get("branch")
-        if branch is not None:
-            branch = urlutils.unescape(branch)
-        return branch
+        if branch is None:
+            branch = ""
+        return urlutils.unescape(branch)
 
     def has_workingtree(self):
         """Tell if this controldir contains a working tree.

=== modified file 'bzrlib/mutabletree.py'
--- bzrlib/mutabletree.py	2012-01-06 01:58:27 +0000
+++ bzrlib/mutabletree.py	2012-01-18 10:42:07 +0000
@@ -524,13 +524,15 @@
             "Called before a tree transform on this tree. The hook is called "
             "with the tree that is being transformed and the transform.",
             (2, 5))
+        self.add_hook('post_build_tree',
+            "Called after a completely new tree is built. The hook is "
+            "called with the tree as its only argument.", (2, 5))
         self.add_hook('post_transform',
             "Called after a tree transform has been performed on a tree. "
             "The hook is called with the tree that is being transformed and "
             "the transform.",
             (2, 5))
 
-
 # install the default hooks into the MutableTree class.
 MutableTree.hooks = MutableTreeHooks()
 

=== modified file 'bzrlib/plugins/weave_fmt/branch.py'
--- bzrlib/plugins/weave_fmt/branch.py	2011-12-19 13:23:58 +0000
+++ bzrlib/plugins/weave_fmt/branch.py	2012-01-07 01:06:26 +0000
@@ -138,7 +138,9 @@
     def open(self, a_bzrdir, name=None, _found=False, ignore_fallbacks=False,
             found_repository=None, possible_transports=None):
         """See BranchFormat.open()."""
-        if name is not None:
+        if name is None:
+            name = a_bzrdir._get_selected_branch()
+        if name != "":
             raise errors.NoColocatedBranchSupport(self)
         if not _found:
             # we are being called directly and must probe.

=== modified file 'bzrlib/plugins/weave_fmt/workingtree.py'
--- bzrlib/plugins/weave_fmt/workingtree.py	2011-12-19 13:23:58 +0000
+++ bzrlib/plugins/weave_fmt/workingtree.py	2012-01-06 14:09:04 +0000
@@ -30,6 +30,7 @@
     xml5,
     )
 from bzrlib.decorators import needs_read_lock
+from bzrlib.mutabletree import MutableTree
 from bzrlib.transport.local import LocalTransport
 from bzrlib.workingtree import (
     WorkingTreeFormat,
@@ -113,6 +114,8 @@
             parent_trees = [(revision_id, basis_tree)]
         wt.set_parent_trees(parent_trees)
         transform.build_tree(basis_tree, wt)
+        for hook in MutableTree.hooks['post_build_tree']:
+            hook(wt)
         return wt
 
     def __init__(self):

=== modified file 'bzrlib/remote.py'
--- bzrlib/remote.py	2012-01-04 16:02:14 +0000
+++ bzrlib/remote.py	2012-01-07 01:06:26 +0000
@@ -625,6 +625,8 @@
 
     def create_branch(self, name=None, repository=None,
                       append_revisions_only=None):
+        if name is None:
+            name = self._get_selected_branch()
         # as per meta1 formats - just delegate to the format object which may
         # be parameterised.
         real_branch = self._format.get_branch_format().initialize(self,
@@ -724,6 +726,8 @@
 
     def open_branch(self, name=None, unsupported=False,
                     ignore_fallbacks=False, possible_transports=None):
+        if name is None:
+            name = self._get_selected_branch()
         if unsupported:
             raise NotImplementedError('unsupported flag support not implemented yet.')
         if self._next_open_branch_result is not None:
@@ -3102,6 +3106,8 @@
 
     def initialize(self, a_bzrdir, name=None, repository=None,
                    append_revisions_only=None):
+        if name is None:
+            name = a_bzrdir._get_selected_branch()
         # 1) get the network name to use.
         if self._custom_format:
             network_name = self._custom_format.network_name()
@@ -3122,7 +3128,7 @@
         # Creating on a remote bzr dir.
         # 2) try direct creation via RPC
         path = a_bzrdir._path_for_remote_call(a_bzrdir._client)
-        if name is not None:
+        if name != "":
             # XXX JRV20100304: Support creating colocated branches
             raise errors.NoColocatedBranchSupport(self)
         verb = 'BzrDir.create_branch'

=== modified file 'bzrlib/smart/bzrdir.py'
--- bzrlib/smart/bzrdir.py	2011-12-19 13:23:58 +0000
+++ bzrlib/smart/bzrdir.py	2012-01-07 01:06:26 +0000
@@ -268,7 +268,7 @@
             self.transport_from_client_path(path))
         format = branch.network_format_registry.get(network_name)
         bzrdir.branch_format = format
-        result = format.initialize(bzrdir)
+        result = format.initialize(bzrdir, name="")
         rich_root, tree_ref, external_lookup = self._format_to_capabilities(
             result.repository._format)
         branch_format = result._format.network_name()

=== modified file 'bzrlib/tests/blackbox/test_commit.py'
--- bzrlib/tests/blackbox/test_commit.py	2012-01-05 13:02:31 +0000
+++ bzrlib/tests/blackbox/test_commit.py	2012-01-06 11:05:23 +0000
@@ -859,12 +859,12 @@
         Regression test for bug 185211.
         """
         tree = self.make_branch_and_tree('.')
-        self.build_tree([u'abc\xc3/', u'abc\xc3/foo'])
+        self.build_tree([u'abc\xa7/', u'abc\xa7/foo'])
 
-        tree.add([u'abc\xc3/', u'abc\xc3/foo'])
+        tree.add([u'abc\xa7/', u'abc\xa7/foo'])
         tree.commit('checkin')
 
-        tree.rename_one(u'abc\xc3','abc')
+        tree.rename_one(u'abc\xa7','abc')
 
         self.run_bzr('ci -m "non-ascii mv"')
 

=== modified file 'bzrlib/tests/per_bzrdir/test_bzrdir.py'
--- bzrlib/tests/per_bzrdir/test_bzrdir.py	2011-12-12 12:09:50 +0000
+++ bzrlib/tests/per_bzrdir/test_bzrdir.py	2012-01-07 01:45:31 +0000
@@ -693,5 +693,5 @@
             raise TestNotApplicable('Format does not support colocation')
         reference = branch.BranchReferenceFormat().initialize(
             repo.bzrdir, target_branch=target_branch)
-        self.assertEqual(set([None, 'foo']),
+        self.assertEqual(set(["", 'foo']),
                          set(repo.bzrdir.get_branches().keys()))

=== modified file 'bzrlib/tests/per_controldir/test_controldir.py'
--- bzrlib/tests/per_controldir/test_controldir.py	2011-12-27 12:18:36 +0000
+++ bzrlib/tests/per_controldir/test_controldir.py	2012-01-06 23:29:07 +0000
@@ -1195,7 +1195,7 @@
     def test_get_branches(self):
         repo = self.make_repository('branch-1')
         target_branch = repo.bzrdir.create_branch()
-        self.assertEqual([None], repo.bzrdir.get_branches().keys())
+        self.assertEqual([""], repo.bzrdir.get_branches().keys())
 
     def test_create_repository(self):
         # a bzrdir can construct a repository for itself.
@@ -1342,7 +1342,7 @@
             raise TestSkipped("Can't initialize %r on transport %r"
                               % (self.bzrdir_format, t))
         dir = bzrdir.BzrDir.open(t.base)
-        self.assertIs(None, dir._get_selected_branch())
+        self.assertEqual(u"", dir._get_selected_branch())
 
     def test_root_transport(self):
         dir = self.make_bzrdir('.')

=== modified file 'bzrlib/tests/per_controldir_colo/test_unsupported.py'
--- bzrlib/tests/per_controldir_colo/test_unsupported.py	2011-12-11 04:07:08 +0000
+++ bzrlib/tests/per_controldir_colo/test_unsupported.py	2012-01-06 23:29:07 +0000
@@ -73,4 +73,4 @@
         made_control = self.make_bzrdir_with_repo()
         made_control.create_branch()
         self.assertEqual(made_control.get_branches().keys(),
-                         [None])
+                         [""])

=== modified file 'bzrlib/tests/per_workingtree/test_workingtree.py'
--- bzrlib/tests/per_workingtree/test_workingtree.py	2011-12-16 17:34:46 +0000
+++ bzrlib/tests/per_workingtree/test_workingtree.py	2012-01-06 19:46:41 +0000
@@ -37,6 +37,7 @@
     PathsNotVersionedError,
     )
 from bzrlib.inventory import Inventory
+from bzrlib.mutabletree import MutableTree
 from bzrlib.osutils import pathjoin, getcwd, has_symlinks
 from bzrlib.tests import (
     features,
@@ -451,6 +452,23 @@
             revision_id='a')
         self.assertEqual(['a'], made_tree.get_parent_ids())
 
+    def test_post_build_tree_hook(self):
+        calls = []
+        def track_post_build_tree(tree):
+            calls.append(tree.last_revision())
+        source = self.make_branch_and_tree('source')
+        source.commit('a', rev_id='a', allow_pointless=True)
+        source.commit('b', rev_id='b', allow_pointless=True)
+        self.build_tree(['new/'])
+        made_control = self.bzrdir_format.initialize('new')
+        source.branch.repository.clone(made_control)
+        source.branch.clone(made_control)
+        MutableTree.hooks.install_named_hook("post_build_tree",
+            track_post_build_tree, "Test")
+        made_tree = self.workingtree_format.initialize(made_control,
+            revision_id='a')
+        self.assertEqual(['a'], calls)
+
     def test_update_sets_last_revision(self):
         # working tree formats from the meta-dir format and newer support
         # setting the last revision on a tree independently of that on the

=== modified file 'bzrlib/tests/test_config.py'
--- bzrlib/tests/test_config.py	2012-01-05 10:39:49 +0000
+++ bzrlib/tests/test_config.py	2012-01-09 12:20:41 +0000
@@ -3336,8 +3336,7 @@
 
     def get_section(self, options, extra_path):
         section = config.Section('foo', options)
-        # We don't care about the length so we use '0'
-        return config.LocationSection(section, 0, extra_path)
+        return config.LocationSection(section, extra_path)
 
     def test_simple_option(self):
         section = self.get_section({'foo': 'bar'}, '')
@@ -3380,9 +3379,7 @@
                            '/quux/quux'],
                           [section.id for _, section in store.get_sections()])
         matcher = config.LocationMatcher(store, '/foo/bar/quux')
-        sections = [section for s, section in matcher.get_sections()]
-        self.assertEquals([3, 2],
-                          [section.length for section in sections])
+        sections = [section for _, section in matcher.get_sections()]
         self.assertEquals(['/foo/bar', '/foo'],
                           [section.id for section in sections])
         self.assertEquals(['quux', 'bar/quux'],
@@ -3399,9 +3396,7 @@
         self.assertEquals(['/foo', '/foo/bar'],
                           [section.id for _, section in store.get_sections()])
         matcher = config.LocationMatcher(store, '/foo/bar/baz')
-        sections = [section for s, section in matcher.get_sections()]
-        self.assertEquals([3, 2],
-                          [section.length for section in sections])
+        sections = [section for _, section in matcher.get_sections()]
         self.assertEquals(['/foo/bar', '/foo'],
                           [section.id for section in sections])
         self.assertEquals(['baz', 'bar/baz'],
@@ -3432,6 +3427,90 @@
         self.assertEquals(expected_location, matcher.location)
 
 
+class TestStartingPathMatcher(TestStore):
+
+    def setUp(self):
+        super(TestStartingPathMatcher, self).setUp()
+        # Any simple store is good enough
+        self.store = config.IniFileStore()
+
+    def assertSectionIDs(self, expected, location, content):
+        self.store._load_from_string(content)
+        matcher = config.StartingPathMatcher(self.store, location)
+        sections = list(matcher.get_sections())
+        self.assertLength(len(expected), sections)
+        self.assertEqual(expected, [section.id for _, section in sections])
+        return sections
+
+    def test_empty(self):
+        self.assertSectionIDs([], self.get_url(), '')
+
+    def test_url_vs_local_paths(self):
+        # The matcher location is an url and the section names are local paths
+        sections = self.assertSectionIDs(['/foo/bar', '/foo'],
+                                         'file:///foo/bar/baz', '''\
+[/foo]
+[/foo/bar]
+''')
+
+    def test_local_path_vs_url(self):
+        # The matcher location is a local path and the section names are urls
+        sections = self.assertSectionIDs(['file:///foo/bar', 'file:///foo'],
+                                         '/foo/bar/baz', '''\
+[file:///foo]
+[file:///foo/bar]
+''')
+
+
+    def test_no_name_section_included_when_present(self):
+        # Note that other tests will cover the case where the no-name section
+        # is empty and as such, not included.
+        sections = self.assertSectionIDs(['/foo/bar', '/foo', None],
+                                         '/foo/bar/baz', '''\
+option = defined so the no-name section exists
+[/foo]
+[/foo/bar]
+''')
+        self.assertEquals(['baz', 'bar/baz', '/foo/bar/baz'],
+                          [s.locals['relpath'] for _, s in sections])
+
+    def test_order_reversed(self):
+        self.assertSectionIDs(['/foo/bar', '/foo'], '/foo/bar/baz', '''\
+[/foo]
+[/foo/bar]
+''')
+
+    def test_unrelated_section_excluded(self):
+        self.assertSectionIDs(['/foo/bar', '/foo'], '/foo/bar/baz', '''\
+[/foo]
+[/foo/qux]
+[/foo/bar]
+''')
+
+    def test_glob_included(self):
+        sections = self.assertSectionIDs(['/foo/*/baz', '/foo/b*', '/foo'],
+                                         '/foo/bar/baz', '''\
+[/foo]
+[/foo/qux]
+[/foo/b*]
+[/foo/*/baz]
+''')
+        # Note that 'baz' as a relpath for /foo/b* is not fully correct, but
+        # nothing really is... as far using {relpath} to append it to something
+        # else, this seems good enough though.
+        self.assertEquals(['', 'baz', 'bar/baz'],
+                          [s.locals['relpath'] for _, s in sections])
+
+    def test_respect_order(self):
+        self.assertSectionIDs(['/foo', '/foo/b*', '/foo/*/baz'],
+                              '/foo/bar/baz', '''\
+[/foo/*/baz]
+[/foo/qux]
+[/foo/b*]
+[/foo]
+''')
+
+
 class TestNameMatcher(TestStore):
 
     def setUp(self):

=== modified file 'bzrlib/tests/test_foreign.py'
--- bzrlib/tests/test_foreign.py	2011-12-19 19:15:58 +0000
+++ bzrlib/tests/test_foreign.py	2012-01-07 01:06:26 +0000
@@ -240,6 +240,8 @@
 
     def open(self, a_bzrdir, name=None, _found=False, ignore_fallbacks=False,
             found_repository=None):
+        if name is None:
+            name = a_bzrdir._get_selected_branch()
         if not _found:
             raise NotImplementedError
         try:
@@ -251,7 +253,8 @@
             return DummyForeignVcsBranch(_format=self,
                               _control_files=control_files,
                               a_bzrdir=a_bzrdir,
-                              _repository=found_repository)
+                              _repository=found_repository,
+                              name=name)
         except errors.NoSuchFile:
             raise errors.NotBranchError(path=transport.base)
 
@@ -317,7 +320,9 @@
 
     def open_branch(self, name=None, unsupported=False, ignore_fallbacks=True,
             possible_transports=None):
-        if name is not None:
+        if name is None:
+            name = self._get_selected_branch()
+        if name != "":
             raise errors.NoColocatedBranchSupport(self)
         return self._format.get_branch_format().open(self, _found=True)
 

=== modified file 'bzrlib/transform.py'
--- bzrlib/transform.py	2012-01-06 01:58:27 +0000
+++ bzrlib/transform.py	2012-01-18 10:42:07 +0000
@@ -232,7 +232,7 @@
         irrelevant.
 
         """
-        new_roots = [k for k, v in self._new_parent.iteritems() if v is
+        new_roots = [k for k, v in self._new_parent.iteritems() if v ==
                      ROOT_PARENT]
         if len(new_roots) < 1:
             return
@@ -628,7 +628,7 @@
         for trans_id in self._new_parent:
             seen = set()
             parent_id = trans_id
-            while parent_id is not ROOT_PARENT:
+            while parent_id != ROOT_PARENT:
                 seen.add(parent_id)
                 try:
                     parent_id = self.final_parent(parent_id)
@@ -644,7 +644,7 @@
         """If parent directories are versioned, children must be versioned."""
         conflicts = []
         for parent_id, children in by_parent.iteritems():
-            if parent_id is ROOT_PARENT:
+            if parent_id == ROOT_PARENT:
                 continue
             if self.final_file_id(parent_id) is not None:
                 continue
@@ -743,7 +743,7 @@
         """Children must have a directory parent"""
         conflicts = []
         for parent_id, children in by_parent.iteritems():
-            if parent_id is ROOT_PARENT:
+            if parent_id == ROOT_PARENT:
                 continue
             no_children = True
             for child_id in children:

=== modified file 'bzrlib/workingtree_3.py'
--- bzrlib/workingtree_3.py	2011-12-19 19:15:58 +0000
+++ bzrlib/workingtree_3.py	2012-01-06 14:09:04 +0000
@@ -36,6 +36,7 @@
     )
 from bzrlib.lockable_files import LockableFiles
 from bzrlib.lockdir import LockDir
+from bzrlib.mutabletree import MutableTree
 from bzrlib.transport.local import LocalTransport
 from bzrlib.workingtree import (
     InventoryWorkingTree,
@@ -227,6 +228,8 @@
             else:
                 wt.set_parent_trees([(revision_id, basis_tree)])
             transform.build_tree(basis_tree, wt)
+            for hook in MutableTree.hooks['post_build_tree']:
+                hook(wt)
         finally:
             # Unlock in this order so that the unlock-triggers-flush in
             # WorkingTree is given a chance to fire.

=== modified file 'bzrlib/workingtree_4.py'
--- bzrlib/workingtree_4.py	2011-12-19 19:15:58 +0000
+++ bzrlib/workingtree_4.py	2012-01-06 14:09:04 +0000
@@ -57,7 +57,10 @@
 from bzrlib.lock import LogicalLockResult
 from bzrlib.lockable_files import LockableFiles
 from bzrlib.lockdir import LockDir
-from bzrlib.mutabletree import needs_tree_write_lock
+from bzrlib.mutabletree import (
+    MutableTree,
+    needs_tree_write_lock,
+    )
 from bzrlib.osutils import (
     file_kind,
     isdir,
@@ -1544,6 +1547,8 @@
                 transform.build_tree(basis, wt, accelerator_tree,
                                      hardlink=hardlink,
                                      delta_from_tree=delta_from_tree)
+                for hook in MutableTree.hooks['post_build_tree']:
+                    hook(wt)
             finally:
                 basis.unlock()
         finally:

=== modified file 'doc/developers/configuration.txt'
--- doc/developers/configuration.txt	2011-12-22 18:37:21 +0000
+++ doc/developers/configuration.txt	2012-01-09 12:20:41 +0000
@@ -301,12 +301,15 @@
 
 ``bzrlib`` provides:
 
-* ``LocationMatcher(store, location)``: To select all sections that match
-  ``location``.
-
 * ``NameMatcher(store, unique_id)``: To select a single section matching
   ``unique_id``.
 
+* ``LocationMatcher(store, location)``: To select all sections that match
+  ``location`` sorted by decreasing number of path components.
+
+* ``StartingPathMatcher(store, location)``: To select all sections that
+  match ``location`` in the order they appear in the ``store``.
+
 Stacks
 ------
 

=== modified file 'doc/developers/releasing.txt'
--- doc/developers/releasing.txt	2011-11-15 17:14:30 +0000
+++ doc/developers/releasing.txt	2012-01-16 17:24:42 +0000
@@ -487,9 +487,9 @@
    turn on ``Import template files`` then for exports click ``Choose a
    target branch`` and point it at the branch you just pushed.
 
-#. E-mail translators to announce that the forthcoming stable release
-   of bzr is ready for translations.  Send to
-   ``translators@lists.launchpad.net`` and
+#. E-mail translators to announce that the forthcoming stable release of bzr
+   is ready for translations.  Send to
+   ``launchpad-translators@lists.launchpad.net`` and
    ``ubuntu-translators@lists.ubuntu.com``.
 
 #. The series is now frozen for strings and API, see below for adding

=== modified file 'doc/en/admin-guide/migration.txt'
--- doc/en/admin-guide/migration.txt	2010-08-13 19:08:57 +0000
+++ doc/en/admin-guide/migration.txt	2012-01-17 17:22:36 +0000
@@ -47,7 +47,7 @@
 Bazaar's `svn`_ plugin provides tools for interaction with Subversion
 projects.  In fact, Bazaar can be used transparently with projects stored in
 Subversion, but that is beyond the scope of this document.  (See
-http://doc.bazaar.canonical.com/en/migration/foreign/bzr-on-svn-projects.html for
+http://doc.bazaar.canonical.com/migration/en/foreign/bzr-on-svn-projects.html for
 more on that subject.)  What is relevant here is the ``svn-import`` command
 provided by that plugin.  This can import an entire subversion repository
 including tags and branches, particularly if they are stored in Subversion's

=== modified file 'doc/en/release-notes/bzr-2.3.txt'
--- doc/en/release-notes/bzr-2.3.txt	2011-12-10 21:21:31 +0000
+++ doc/en/release-notes/bzr-2.3.txt	2012-01-13 15:05:42 +0000
@@ -35,6 +35,9 @@
 * Cope cleanly with buggy HTTP proxies that close the socket in the middle
   of a multipart response.  (Martin Pool, #198646).
 
+* cStringIO is now unconditionally imported in ``bzrlib.config``.
+  (Jelmer Vernooij, #905361)
+
 * Fix "Unprintable exception" error when a RetryWithNewPacks error is
   displayed.  (Andrew Bennetts)
 

=== modified file 'doc/en/release-notes/bzr-2.5.txt'
--- doc/en/release-notes/bzr-2.5.txt	2012-01-06 01:58:27 +0000
+++ doc/en/release-notes/bzr-2.5.txt	2012-01-18 10:42:07 +0000
@@ -5,16 +5,84 @@
 .. toctree::
    :maxdepth: 1
 
+bzr 2.5.0
+#########
+
+:2.5.0: NOT RELEASED YET
+
+External Compatibility Breaks
+*****************************
+
+.. These may require users to change the way they use Bazaar.
+
+New Features
+************
+
+.. New commands, options, etc that users may wish to try out.
+
+Improvements
+************
+
+.. Improvements to existing commands, especially improved performance 
+   or memory usage, or better results.
+
+Bug Fixes
+*********
+
+.. Fixes for situations where bzr would previously crash or give incorrect
+   or undesirable results.
+
+* Test for equality instead of object identity where ROOT_PARENT is concerned.
+  (Wouter van Heyst, #881142)
+
+Documentation
+*************
+
+.. Improved or updated documentation.
+
+API Changes
+***********
+
+.. Changes that may require updates in plugins or other code that uses
+   bzrlib.
+
+Internals
+*********
+
+.. Major internal changes, unlikely to be visible to users or plugin 
+   developers, but interesting for bzr developers.
+
+* ``MutableTree`` has two new hooks ``pre_transform`` and
+  ``post_transform`` that are called for tree transform operations.
+  (Jelmer Vernooij, #912084)
+
+Testing
+*******
+
+.. Fixes and changes that are only relevant to bzr's test framework and 
+   suite.  This can include new facilities for writing tests, fixes to 
+   spurious test failures and changes to the way things should be tested.
+
+
 bzr 2.5b5
 #########
 
-:2.5b5: NOT RELEASED YET
+:2.5b5: 2012-01-12
+
+This is the firth (ans last) beta of the 2.5 series, leading to a 2.5.0
+release in February 2012. Beta releases are suitable for everyday use but
+may cause some incompatibilities with plugins.
+
+This release includes many improvements in the smart server, UI polish for
+the colocated branches, enhancements to the config framework and more
+internal uses, bug fixes related to unicode and locale support and more.
+
+All bug fixed in previous series known at the time of this release are
+included.
 
 External Compatibility Breaks
 *****************************
 
-.. These may require users to change the way they use Bazaar.
-
 * The '.bzr/branch/email' file is no longer read to determine the users'
   identity. Instead, the 'email' setting in '.bzr/branch/branch.conf'
   should be used. (Jelmer Vernooij, #903894)
@@ -22,8 +90,6 @@
 New Features
 ************
 
-.. New commands, options, etc that users may wish to try out.
-
 * "bzr mkdir" now includes -p (--parents) option for recursively adding
   parent directories.
   (Jared Hance, Jelmer Vernooij, #253529)
@@ -35,9 +101,6 @@
 Improvements
 ************
 
-.. Improvements to existing commands, especially improved performance 
-   or memory usage, or better results.
-
 * New HPSS call for ``Repository.reconcile``. (Jelmer Vernooij, #894455)
 
 * Merge now has two new hooks ``pre_merge`` and ``post_merge``
@@ -62,9 +125,6 @@
 Bug Fixes
 *********
 
-.. Fixes for situations where bzr would previously crash or give incorrect
-   or undesirable results.
-
 * Allow configuration option default value to be a python callable at
   registration. (Vincent Ladeuil, #832064)
 
@@ -113,17 +173,9 @@
 * Uncommit no longer removes tags if they are part of the working
   trees pending merges. (Jelmer Vernooij, #905462)
 
-Documentation
-*************
-
-.. Improved or updated documentation.
-
 API Changes
 ***********
 
-.. Changes that may require updates in plugins or other code that uses
-   bzrlib.
-
 * ``Config.signature_needed``, ``Config.signing_policy``,
   ``Config.gpg_signing_key``, ``Config.gpg_signing_command``,
   ``Config.checking_policy`` and ``Config.post_commit`` are now deprecated.
@@ -145,8 +197,19 @@
 Internals
 *********
 
-.. Major internal changes, unlikely to be visible to users or plugin 
-   developers, but interesting for bzr developers.
+* Add HPSS call for ``Branch.get_checkout_format``. (Jelmer Vernooij, #894459)
+
+* Add HPSS call for ``Repository.pack``. (Jelmer Vernooij, #894461)
+
+* Add HPSS calls for ``Repository.iter_files_bytes``, speeding up
+  several commands including ``bzr export`` and ``bzr co --lightweight``.
+  (Jelmer Vernooij, #608640)
+
+* All bzr control directories, branch formats, repository formats and
+  working tree formats now support feature flags, which are
+  serialized in their respective format files. See
+  ``doc/developers/feature-flags.txt`` for details.
+  (Jelmer Vernooij)
 
 * ``bzrlib.urlutils`` now includes ``quote`` and ``unquote`` functions,
   rather than importing them from ``urllib``. This prevents loading
@@ -156,6 +219,11 @@
 * Configuration options can be SI units by using ``int_SI_from_unicode`` as
   their ``convert_from_unicode`` helper. (Vincent Ladeuil)
 
+* Configuration stacks can now use ``StartingPathMatcher`` to select the
+  sections matching a location while respecting the order chosen by the user
+  in the configuration file: from generic sections to specific
+  sections. (Vincent Ladeuil, #832046).
+
 * Configuration stores can now save incremental changes by using
   ``save_changes()`` instead of ``save()``. This reduces the number or
   required input/outputs and allows stores to be shared between
@@ -178,9 +246,8 @@
   which contains the branch from which the ``other_tree``
   was obtained, if any. (Jelmer Vernooij)
 
-* ``MutableTree`` has two new hooks ``pre_transform`` and
-  ``post_transform`` that are called for tree transform operations.
-  (Jelmer Vernooij, #912084)
+* MutableTree now has a hook ``post_build_tree`` which is called after
+  a new mutable tree has been created. (Jelmer Vernooij, #912765)
 
 * New HPSS call ``BzrDir.checkout_metadir``. (Jelmer Vernooij, #894459)
 
@@ -194,10 +261,6 @@
 Testing
 *******
 
-.. Fixes and changes that are only relevant to bzr's test framework and 
-   suite.  This can include new facilities for writing tests, fixes to 
-   spurious test failures and changes to the way things should be tested.
-
 * New matcher ``ContainsNoVfsCalls`` which filters a list of HPSS
   calls for VFS requests. (Jelmer Vernooij)
 
@@ -256,9 +319,6 @@
 * Plugins can now register additional "location aliases".
   (Jelmer Vernooij)
 
-* ``bzr status`` no longer shows shelves if files are specified.
-  (Francis Devereux)
-
 * Revision specifiers will now only browse as much history as they
   need to, rather than grabbing the whole history unnecessarily in some
   cases. (Jelmer Vernooij)
@@ -280,8 +340,7 @@
 
 * Add HPSS call for retrieving file contents from remote repositories.
   Should improve performance for lightweight checkouts and exports of
-  from remote repositories.  (Jelmer Vernooij, #368717, #762330,
-  #608640)
+  from remote repositories.  (Jelmer Vernooij, #368717, #762330, #608640)
 
 * Allow lazy compiled patterns from ``bzrlib.lazy_regex`` to be
   pickled. (Jelmer Vernooij, #893149)
@@ -384,34 +443,12 @@
   ``Repository.get_revision_signature_text``.
   (Jelmer Vernooij)
 
-* Add HPSS call for ``Branch.get_checkout_format``. (Jelmer Vernooij, #894459)
-
-* Add HPSS call for ``Repository.pack``. (Jelmer Vernooij, #894461)
-
-* Add HPSS calls for ``Repository.iter_files_bytes``, speeding up
-  several commands including ``bzr export`` and ``bzr co --lightweight``.
-  (Jelmer Vernooij, #608640)
-
-* Custom HPSS error handlers can now be installed in the smart server client
-  using the ``error_translators`` and ``no_context_error_translators``
-  registries. (Jelmer Vernooij)
-
 * ``RemoteBranch.get_config_stack`` and ``RemoteBzrDir.get_config_stack``
   will now use HPSS calls where possible. (Jelmer Vernooij)
 
-* Custom HPSS error handlers can now be installed in the smart server client
-  using the ``error_translators`` and ``no_context_error_translators``
-  registries. (Jelmer Vernooij)
-
 * The registry of merge types has been moved to ``merge`` from ``option`` but
   ``merge.get_merge_type_registry`` remains as an accessor. (Martin Packman)
 
-* All bzr control directories, branch formats, repository formats and
-  working tree formats now support feature flags, which are
-  serialized in their respective format files. See
-  ``doc/developers/feature-flags.txt`` for details.
-  (Jelmer Vernooij)
-
 Testing
 *******
 

=== modified file 'po/bzr.pot'
--- po/bzr.pot	2011-12-08 08:32:36 +0000
+++ po/bzr.pot	2012-01-16 14:45:48 +0000
@@ -8,7 +8,7 @@
 msgstr ""
 "Project-Id-Version: bzr\n"
 "Report-Msgid-Bugs-To: <bazaar@canonical.com>\n"
-"POT-Creation-Date: 2011-12-08 09:21+0100\n"
+"POT-Creation-Date: 2012-01-16 15:18+0100\n"
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
 "Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
 "Language-Team: LANGUAGE <LL@li.org>\n"
@@ -22,73 +22,73 @@
 msgid "skipping {0} (larger than {1} of {2} bytes)"
 msgstr ""
 
-#: bzrlib/branch.py:871
+#: bzrlib/branch.py:872
 msgid "Unstacking"
 msgstr ""
 
-#: bzrlib/branch.py:3173
+#: bzrlib/branch.py:3183
 #, python-format
 msgid "Pushed up to revision %d."
 msgstr ""
 
-#: bzrlib/branch.py:3175
+#: bzrlib/branch.py:3185
 #, python-format
 msgid "%d tag updated."
 msgid_plural "%d tags updated."
 msgstr[0] ""
 msgstr[1] ""
 
-#: bzrlib/branch.py:3178
+#: bzrlib/branch.py:3188
 msgid "No new revisions or tags to push."
 msgstr ""
 
-#: bzrlib/branch.py:3180
+#: bzrlib/branch.py:3190
 msgid "No new revisions to push."
 msgstr ""
 
-#: bzrlib/branch.py:3200
+#: bzrlib/branch.py:3210
 msgid "checked branch {0} format {1}"
 msgstr ""
 
-#: bzrlib/branch.py:3203
+#: bzrlib/branch.py:3213
 #, python-format
 msgid "found error:%s"
 msgstr ""
 
-#: bzrlib/builtins.py:118 bzrlib/builtins.py:2868 bzrlib/workingtree.py:304
+#: bzrlib/builtins.py:121 bzrlib/builtins.py:2923 bzrlib/workingtree.py:315
 #, python-format
 msgid "Ignoring files outside view. View is %s"
 msgstr ""
 
-#: bzrlib/builtins.py:127
+#: bzrlib/builtins.py:130
 #, python-format
 msgid "bzr %s --revision takes exactly one revision identifier"
 msgstr ""
 
-#: bzrlib/builtins.py:212
+#: bzrlib/builtins.py:215
 msgid "Display status summary."
 msgstr ""
 
-#: bzrlib/builtins.py:214
+#: bzrlib/builtins.py:217
 msgid ""
 "This reports on versioned and unknown files, reporting them\n"
 "grouped by state.  Possible states are:"
 msgstr ""
 
-#: bzrlib/builtins.py:217
+#: bzrlib/builtins.py:220
 msgid ""
 "added\n"
 "    Versioned in the working copy but not in the previous revision."
 msgstr ""
 
-#: bzrlib/builtins.py:220
+#: bzrlib/builtins.py:223
 msgid ""
 "removed\n"
 "    Versioned in the previous revision but removed or deleted\n"
 "    in the working copy."
 msgstr ""
 
-#: bzrlib/builtins.py:224
+#: bzrlib/builtins.py:227
 msgid ""
 "renamed\n"
 "    Path of this file changed from the previous revision;\n"
@@ -96,25 +96,25 @@
 "    parent directory was renamed."
 msgstr ""
 
-#: bzrlib/builtins.py:229
+#: bzrlib/builtins.py:232
 msgid ""
 "modified\n"
 "    Text has changed since the previous revision."
 msgstr ""
 
-#: bzrlib/builtins.py:232
+#: bzrlib/builtins.py:235
 msgid ""
 "kind changed\n"
 "    File kind has been changed (e.g. from file to directory)."
 msgstr ""
 
-#: bzrlib/builtins.py:235
+#: bzrlib/builtins.py:238
 msgid ""
 "unknown\n"
 "    Not versioned and not matching an ignore pattern."
 msgstr ""
 
-#: bzrlib/builtins.py:238
+#: bzrlib/builtins.py:241
 msgid ""
 "Additionally for directories, symlinks and files with a changed\n"
 "executable bit, Bazaar indicates their type using a trailing\n"
@@ -122,20 +122,20 @@
 "disabled using the '--no-classify' option."
 msgstr ""
 
-#: bzrlib/builtins.py:243
+#: bzrlib/builtins.py:246
 msgid ""
 "To see ignored files use 'bzr ignored'.  For details on the\n"
 "changes to file texts, use 'bzr diff'."
 msgstr ""
 
-#: bzrlib/builtins.py:246
+#: bzrlib/builtins.py:249
 msgid ""
 "Note that --short or -S gives status flags for each item, similar\n"
 "to Subversion's status command. To get output similar to svn -q,\n"
 "use bzr status -SV."
 msgstr ""
 
-#: bzrlib/builtins.py:250
+#: bzrlib/builtins.py:253
 msgid ""
 "If no arguments are specified, the status of the entire working\n"
 "directory is shown.  Otherwise, only the status of the specified\n"
@@ -143,7 +143,7 @@
 "is reported for everything inside that directory."
 msgstr ""
 
-#: bzrlib/builtins.py:255
+#: bzrlib/builtins.py:258
 msgid ""
 "Before merges are committed, the pending merge tip revisions are\n"
 "shown. To see all pending merge revisions, use the -v option.\n"
@@ -151,13 +151,13 @@
 "the no-pending option or specify a file/directory."
 msgstr ""
 
-#: bzrlib/builtins.py:260
+#: bzrlib/builtins.py:263
 msgid ""
 "To compare the working directory to a specific revision, pass a\n"
 "single revision to the revision argument."
 msgstr ""
 
-#: bzrlib/builtins.py:263
+#: bzrlib/builtins.py:266
 msgid ""
 "To see which files have changed in a specific revision, or between\n"
 "two revisions, pass a revision range to the revision argument.\n"
@@ -165,130 +165,130 @@
 msgstr ""
 
 # help of 'short' option of 'status' command
-#: bzrlib/builtins.py:272
+#: bzrlib/builtins.py:275
 msgid "Use short status indicators."
 msgstr ""
 
 # help of 'versioned' option of 'status' command
-#: bzrlib/builtins.py:274
+#: bzrlib/builtins.py:277
 msgid "Only show versioned files."
 msgstr ""
 
 # help of 'no-pending' option of 'status' command
-#: bzrlib/builtins.py:276
+#: bzrlib/builtins.py:279
 msgid "Don't show pending merges."
 msgstr ""
 
 # help of 'no-classify' option of 'status' command
-#: bzrlib/builtins.py:279
+#: bzrlib/builtins.py:282
 msgid "Do not mark object type using indicator."
 msgstr ""
 
-#: bzrlib/builtins.py:294
+#: bzrlib/builtins.py:297
 msgid "bzr status --revision takes exactly one or two revision specifiers"
 msgstr ""
 
-#: bzrlib/builtins.py:338 bzrlib/builtins.py:5024
+#: bzrlib/builtins.py:341 bzrlib/builtins.py:5090
 msgid "You can only supply one of revision_id or --revision"
 msgstr ""
 
-#: bzrlib/builtins.py:341 bzrlib/builtins.py:5026
+#: bzrlib/builtins.py:344 bzrlib/builtins.py:5092
 msgid "You must supply either --revision or a revision_id"
 msgstr ""
 
-#: bzrlib/builtins.py:348
+#: bzrlib/builtins.py:351
 #, python-format
 msgid "Repository %r does not support access to raw revision texts"
 msgstr ""
 
-#: bzrlib/builtins.py:359
+#: bzrlib/builtins.py:362
 msgid "The repository {0} contains no revision {1}."
 msgstr ""
 
-#: bzrlib/builtins.py:366
+#: bzrlib/builtins.py:369
 msgid "You cannot specify a NULL revision."
 msgstr ""
 
-#: bzrlib/builtins.py:458
+#: bzrlib/builtins.py:461
 msgid "Remove the working tree from a given branch/checkout."
 msgstr ""
 
-#: bzrlib/builtins.py:460
+#: bzrlib/builtins.py:463
 msgid ""
 "Since a lightweight checkout is little more than a working tree\n"
 "this will refuse to run against one."
 msgstr ""
 
-#: bzrlib/builtins.py:463
+#: bzrlib/builtins.py:466
 msgid "To re-create the working tree, use \"bzr checkout\"."
 msgstr ""
 
 # help of 'force' option of 'remove-tree' command
-#: bzrlib/builtins.py:469
+#: bzrlib/builtins.py:472
 msgid "Remove the working tree even if it has uncommitted or shelved changes."
 msgstr ""
 
-#: bzrlib/builtins.py:483
+#: bzrlib/builtins.py:486
 msgid "No working tree to remove"
 msgstr ""
 
-#: bzrlib/builtins.py:485
+#: bzrlib/builtins.py:488
 msgid "You cannot remove the working tree of a remote path"
 msgstr ""
 
-#: bzrlib/builtins.py:494
+#: bzrlib/builtins.py:497
 msgid "You cannot remove the working tree from a lightweight checkout"
 msgstr ""
 
-#: bzrlib/builtins.py:534
+#: bzrlib/builtins.py:537
 msgid ""
 "The tree does not appear to be corrupt. You probably want \"bzr revert\" "
 "instead. Use \"--force\" if you are sure you want to reset the working tree."
 msgstr ""
 
-#: bzrlib/builtins.py:545
+#: bzrlib/builtins.py:548
 msgid ""
 ", the header appears corrupt, try passing -r -1 to set the state to the last "
 "commit"
 msgstr ""
 
-#: bzrlib/builtins.py:549
+#: bzrlib/builtins.py:552
 msgid "failed to reset the tree state{0}"
 msgstr ""
 
-#: bzrlib/builtins.py:553
+#: bzrlib/builtins.py:556
 msgid "Show current revision number."
 msgstr ""
 
-#: bzrlib/builtins.py:555
+#: bzrlib/builtins.py:558
 msgid "This is equal to the number of revisions on this branch."
 msgstr ""
 
-#: bzrlib/builtins.py:568
+#: bzrlib/builtins.py:571
 msgid "--tree and --revision can not be used together"
 msgstr ""
 
-#: bzrlib/builtins.py:585 bzrlib/builtins.py:5808
+#: bzrlib/builtins.py:588 bzrlib/builtins.py:5874
 msgid "Tags can only be placed on a single revision, not on a range"
 msgstr ""
 
 # help of 'tree' option of 'revno' command
-#: bzrlib/builtins.py:609
+#: bzrlib/builtins.py:612
 msgid "Show revno of working tree."
 msgstr ""
 
-#: bzrlib/builtins.py:657
+#: bzrlib/builtins.py:660
 msgid "Add specified files or directories."
 msgstr ""
 
-#: bzrlib/builtins.py:659
+#: bzrlib/builtins.py:662
 msgid ""
 "In non-recursive mode, all the named items are added, regardless\n"
 "of whether they were previously ignored.  A warning is given if\n"
 "any of the named files are already versioned."
 msgstr ""
 
-#: bzrlib/builtins.py:663
+#: bzrlib/builtins.py:666
 msgid ""
 "In recursive mode (the default), files are treated the same way\n"
 "but the behaviour for directories is different.  Directories that\n"
@@ -299,19 +299,19 @@
 "directories.  If no names are given '.' is assumed."
 msgstr ""
 
-#: bzrlib/builtins.py:671
+#: bzrlib/builtins.py:674
 msgid ""
 "A warning will be printed when nested trees are encountered,\n"
 "unless they are explicitly ignored."
 msgstr ""
 
-#: bzrlib/builtins.py:674
+#: bzrlib/builtins.py:677
 msgid ""
 "Therefore simply saying 'bzr add' will version all files that\n"
 "are currently unknown."
 msgstr ""
 
-#: bzrlib/builtins.py:677
+#: bzrlib/builtins.py:680
 msgid ""
 "Adding a file whose parent directory is not versioned will\n"
 "implicitly add the parent, and so on up to the root. This means\n"
@@ -319,13 +319,13 @@
 "get added when you add a file in the directory."
 msgstr ""
 
-#: bzrlib/builtins.py:682
+#: bzrlib/builtins.py:685
 msgid ""
 "--dry-run will show which files would be added, but not actually\n"
 "add them."
 msgstr ""
 
-#: bzrlib/builtins.py:685
+#: bzrlib/builtins.py:688
 msgid ""
 "--file-ids-from will try to use the file ids from the supplied path.\n"
 "It looks up ids trying to find a matching parent directory with the\n"
@@ -336,13 +336,13 @@
 "into a subdirectory of this one."
 msgstr ""
 
-#: bzrlib/builtins.py:693
+#: bzrlib/builtins.py:696
 msgid ""
 "Any files matching patterns in the ignore list will not be added\n"
 "unless they are explicitly mentioned."
 msgstr ""
 
-#: bzrlib/builtins.py:696
+#: bzrlib/builtins.py:699
 msgid ""
 "In recursive mode, files larger than the configuration option \n"
 "add.maximum_file_size will be skipped. Named items are never skipped due\n"
@@ -350,53 +350,58 @@
 msgstr ""
 
 # help of 'no-recurse' option of 'add' command
-#: bzrlib/builtins.py:703
+#: bzrlib/builtins.py:706
 msgid "Don't recursively add the contents of directories."
 msgstr ""
 
 # help of 'file-ids-from' option of 'add' command
-#: bzrlib/builtins.py:709
+#: bzrlib/builtins.py:712
 msgid "Lookup file ids from this tree."
 msgstr ""
 
-#: bzrlib/builtins.py:745
+#: bzrlib/builtins.py:748
 msgid "ignored {0} matching \"{1}\"\n"
 msgstr ""
 
-#: bzrlib/builtins.py:750
+#: bzrlib/builtins.py:753
 msgid "Create a new versioned directory."
 msgstr ""
 
-#: bzrlib/builtins.py:752
+#: bzrlib/builtins.py:755
 msgid "This is equivalent to creating the directory and then adding it."
 msgstr ""
 
-#: bzrlib/builtins.py:767
+# help of 'parents' option of 'mkdir' command
+#: bzrlib/builtins.py:762
+msgid "No error if existing, make parent directories as needed."
+msgstr ""
+
+#: bzrlib/builtins.py:796
 #, python-format
 msgid "added %s\n"
 msgstr ""
 
-#: bzrlib/builtins.py:811
+#: bzrlib/builtins.py:838
 #, python-format
 msgid "invalid kind %r specified"
 msgstr ""
 
-#: bzrlib/builtins.py:848
+#: bzrlib/builtins.py:875
 msgid "Move or rename a file."
 msgstr ""
 
-#: bzrlib/builtins.py:850
+#: bzrlib/builtins.py:877
 msgid "    bzr mv SOURCE... DESTINATION"
 msgstr ""
 
-#: bzrlib/builtins.py:852
+#: bzrlib/builtins.py:879
 msgid ""
 "If the last argument is a versioned directory, all the other names\n"
 "are moved into it.  Otherwise, there must be exactly two arguments\n"
 "and the file is changed to a new name."
 msgstr ""
 
-#: bzrlib/builtins.py:856
+#: bzrlib/builtins.py:883
 msgid ""
 "If OLDNAME does not exist on the filesystem but is versioned and\n"
 "NEWNAME does exist on the filesystem but is not versioned, mv\n"
@@ -405,56 +410,56 @@
 "The same is valid when moving many SOURCE files to a DESTINATION."
 msgstr ""
 
-#: bzrlib/builtins.py:862
+#: bzrlib/builtins.py:889
 msgid "Files cannot be moved between branches."
 msgstr ""
 
 # help of 'after' option of 'mv' command
-#: bzrlib/builtins.py:869
+#: bzrlib/builtins.py:896
 msgid ""
 "Move only the bzr identifier of the file, because the file has already been "
 "moved."
 msgstr ""
 
 # help of 'auto' option of 'mv' command
-#: bzrlib/builtins.py:871
+#: bzrlib/builtins.py:898
 msgid "Automatically guess renames."
 msgstr ""
 
 # help of 'dry-run' option of 'mv' command
-#: bzrlib/builtins.py:872
+#: bzrlib/builtins.py:899
 msgid "Avoid making changes when guessing renames."
 msgstr ""
 
-#: bzrlib/builtins.py:881
+#: bzrlib/builtins.py:908
 msgid "--dry-run requires --auto."
 msgstr ""
 
-#: bzrlib/builtins.py:885
+#: bzrlib/builtins.py:912
 msgid "missing file argument"
 msgstr ""
 
-#: bzrlib/builtins.py:889
+#: bzrlib/builtins.py:916
 msgid "can not move root of branch"
 msgstr ""
 
-#: bzrlib/builtins.py:895
+#: bzrlib/builtins.py:922
 msgid "Only one path may be specified to --auto."
 msgstr ""
 
-#: bzrlib/builtins.py:898
+#: bzrlib/builtins.py:925
 msgid "--after cannot be specified with --auto."
 msgstr ""
 
-#: bzrlib/builtins.py:935
+#: bzrlib/builtins.py:962
 msgid "to mv multiple files the destination must be a versioned directory"
 msgstr ""
 
-#: bzrlib/builtins.py:987
+#: bzrlib/builtins.py:1014
 msgid "Turn this branch into a mirror of another branch."
 msgstr ""
 
-#: bzrlib/builtins.py:989
+#: bzrlib/builtins.py:1016
 msgid ""
 "By default, this command only works on branches that have not diverged.\n"
 "Branches are considered diverged if the destination branch's most recent \n"
@@ -462,21 +467,21 @@
 "parent."
 msgstr ""
 
-#: bzrlib/builtins.py:994
+#: bzrlib/builtins.py:1021
 msgid ""
 "If branches have diverged, you can use 'bzr merge' to integrate the changes\n"
 "from one into the other.  Once one branch has merged, the other should\n"
 "be able to pull it again."
 msgstr ""
 
-#: bzrlib/builtins.py:998
+#: bzrlib/builtins.py:1025
 msgid ""
 "If you want to replace your local changes and just want your branch to\n"
 "match the remote one, use pull --overwrite. This will work even if the two\n"
 "branches have diverged."
 msgstr ""
 
-#: bzrlib/builtins.py:1002
+#: bzrlib/builtins.py:1029
 msgid ""
 "If there is no default location set, the first pull will set it (use\n"
 "--no-remember to avoid setting it). After that, you can omit the\n"
@@ -484,14 +489,14 @@
 "value will only be saved if the remote location can be accessed."
 msgstr ""
 
-#: bzrlib/builtins.py:1007
+#: bzrlib/builtins.py:1034
 msgid ""
 "The --verbose option will display the revisions pulled using the log_format\n"
 "configuration option. You can use a different format by overriding it with\n"
 "-Olog_format=<other_format>."
 msgstr ""
 
-#: bzrlib/builtins.py:1011
+#: bzrlib/builtins.py:1038
 msgid ""
 "Note: The location can be specified either in the form of a branch,\n"
 "or in the form of a path to a file containing a merge directive generated\n"
@@ -499,77 +504,77 @@
 msgstr ""
 
 # help of 'verbose' option of 'pull' command
-#: bzrlib/builtins.py:1019
+#: bzrlib/builtins.py:1046
 msgid "Show logs of pulled revisions."
 msgstr ""
 
 # help of 'directory' option of 'pull' command
-#: bzrlib/builtins.py:1021
+#: bzrlib/builtins.py:1048
 msgid ""
 "Branch to pull into, rather than the one containing the working directory."
 msgstr ""
 
 # help of 'local' option of 'pull' command
-#: bzrlib/builtins.py:1024
+#: bzrlib/builtins.py:1051
 msgid ""
 "Perform a local pull in a bound branch.  Local pulls are not applied to the "
 "master branch."
 msgstr ""
 
-#: bzrlib/builtins.py:1053
+#: bzrlib/builtins.py:1080
 msgid "Need working tree for --show-base."
 msgstr ""
 
-#: bzrlib/builtins.py:1069
+#: bzrlib/builtins.py:1096
 msgid "No pull location known or specified."
 msgstr ""
 
-#: bzrlib/builtins.py:1075
+#: bzrlib/builtins.py:1102
 #, python-format
 msgid "Using saved parent location: %s\n"
 msgstr ""
 
-#: bzrlib/builtins.py:1082 bzrlib/builtins.py:4234
+#: bzrlib/builtins.py:1109 bzrlib/builtins.py:4300
 msgid "Cannot use -r with merge directives or bundles"
 msgstr ""
 
-#: bzrlib/builtins.py:1123
+#: bzrlib/builtins.py:1150
 msgid "Update a mirror of this branch."
 msgstr ""
 
-#: bzrlib/builtins.py:1125
+#: bzrlib/builtins.py:1152
 msgid ""
 "The target branch will not have its working tree populated because this\n"
 "is both expensive, and is not supported on remote file systems."
 msgstr ""
 
-#: bzrlib/builtins.py:1128
+#: bzrlib/builtins.py:1155
 msgid ""
 "Some smart servers or protocols *may* put the working tree in place in\n"
 "the future."
 msgstr ""
 
-#: bzrlib/builtins.py:1131
+#: bzrlib/builtins.py:1158
 msgid ""
 "This command only works on branches that have not diverged.  Branches are\n"
 "considered diverged if the destination branch's most recent commit is one\n"
 "that has not been merged (directly or indirectly) by the source branch."
 msgstr ""
 
-#: bzrlib/builtins.py:1135
+#: bzrlib/builtins.py:1162
 msgid ""
 "If branches have diverged, you can use 'bzr push --overwrite' to replace\n"
 "the other branch completely, discarding its unmerged changes."
 msgstr ""
 
-#: bzrlib/builtins.py:1138
+#: bzrlib/builtins.py:1165
 msgid ""
 "If you want to ensure you have the different changes in the other branch,\n"
 "do a merge (see bzr help merge) from the other branch, and commit that.\n"
 "After that you will be able to do a push without '--overwrite'."
 msgstr ""
 
-#: bzrlib/builtins.py:1142
+#: bzrlib/builtins.py:1169
 msgid ""
 "If there is no default push location set, the first push will set it (use\n"
 "--no-remember to avoid setting it).  After that, you can omit the\n"
@@ -577,58 +582,80 @@
 "value will only be saved if the remote location can be accessed."
 msgstr ""
 
-#: bzrlib/builtins.py:1147
+#: bzrlib/builtins.py:1174
 msgid ""
 "The --verbose option will display the revisions pushed using the log_format\n"
 "configuration option. You can use a different format by overriding it with\n"
 "-Olog_format=<other_format>."
 msgstr ""
 
+# help of 'directory' option of 'dpush' command
+# help of 'directory' option of 'push' command
+#: bzrlib/builtins.py:1185 bzrlib/foreign.py:272
+msgid ""
+"Branch to push from, rather than the one containing the working directory."
+msgstr ""
+
 # help of 'use-existing-dir' option of 'push' command
-#: bzrlib/builtins.py:1161
+#: bzrlib/builtins.py:1188
 msgid ""
 "By default push will fail if the target directory exists, but does not "
 "already have a control directory.  This flag will allow push to proceed."
 msgstr ""
 
 # help of 'stacked' option of 'push' command
-#: bzrlib/builtins.py:1166
+#: bzrlib/builtins.py:1193
 msgid ""
 "Create a stacked branch that references the public location of the parent "
 "branch."
 msgstr ""
 
 # help of 'stacked-on' option of 'push' command
-#: bzrlib/builtins.py:1169
+#: bzrlib/builtins.py:1196
 msgid ""
 "Create a stacked branch that refers to another branch for the commit "
 "history. Only the work not present in the referenced branch is included in "
 "the branch created."
 msgstr ""
 
+# help of 'strict' option of 'dpush' command
+# help of 'strict' option of 'push' command
+#: bzrlib/builtins.py:1201 bzrlib/foreign.py:279
+msgid ""
+"Refuse to push if there are uncommitted changes in the working tree, --no-"
+"strict disables the check."
+msgstr ""
+
 # help of 'no-tree' option of 'push' command
-#: bzrlib/builtins.py:1177
+#: bzrlib/builtins.py:1204
 msgid "Don't populate the working tree, even for protocols that support it."
 msgstr ""
 
-#: bzrlib/builtins.py:1221
+#: bzrlib/builtins.py:1248
 msgid "Could not determine branch to refer to."
 msgstr ""
 
-#: bzrlib/builtins.py:1228 bzrlib/foreign.py:305
+#: bzrlib/builtins.py:1257
+#, python-format
+msgid ""
+"No push location known or specified. To push to the parent branch (at %s), "
+"use 'bzr push :parent'."
+msgstr ""
+
+#: bzrlib/builtins.py:1263 bzrlib/foreign.py:306
 msgid "No push location known or specified."
 msgstr ""
 
-#: bzrlib/builtins.py:1232
+#: bzrlib/builtins.py:1267
 #, python-format
 msgid "Using saved push location: %s"
 msgstr ""
 
-#: bzrlib/builtins.py:1242
+#: bzrlib/builtins.py:1277
 msgid "Create a new branch that is a copy of an existing branch."
 msgstr ""
 
-#: bzrlib/builtins.py:1244
+#: bzrlib/builtins.py:1279
 msgid ""
 "If the TO_LOCATION is omitted, the last component of the FROM_LOCATION will\n"
 "be used.  In other words, \"branch ../foo/bar\" will attempt to create ./"
@@ -639,112 +666,112 @@
 "create ./foo-bar."
 msgstr ""
 
-#: bzrlib/builtins.py:1251
+#: bzrlib/builtins.py:1286
 msgid ""
 "To retrieve the branch as of a particular revision, supply the --revision\n"
 "parameter, as in \"branch foo/bar -r 5\"."
 msgstr ""
 
-#: bzrlib/builtins.py:1254
+#: bzrlib/builtins.py:1289
 msgid "The synonyms 'clone' and 'get' for this command are deprecated."
 msgstr ""
 
 # help of 'no-tree' option of 'branch' command
-#: bzrlib/builtins.py:1264
+#: bzrlib/builtins.py:1299
 msgid "Create a branch without a working-tree."
 msgstr ""
 
 # help of 'switch' option of 'branch' command
-#: bzrlib/builtins.py:1266
+#: bzrlib/builtins.py:1301
 msgid "Switch the checkout in the current directory to the new branch."
 msgstr ""
 
 # help of 'stacked' option of 'branch' command
-#: bzrlib/builtins.py:1269
+#: bzrlib/builtins.py:1304
 msgid ""
 "Create a stacked branch referring to the source branch. The new branch will "
 "depend on the availability of the source branch for all operations."
 msgstr ""
 
 # help of 'standalone' option of 'branch' command
-#: bzrlib/builtins.py:1273
+#: bzrlib/builtins.py:1308
 msgid "Do not use a shared repository, even if available."
 msgstr ""
 
 # help of 'use-existing-dir' option of 'branch' command
-#: bzrlib/builtins.py:1275
+#: bzrlib/builtins.py:1310
 msgid ""
 "By default branch will fail if the target directory exists, but does not "
 "already have a control directory.  This flag will allow branch to proceed."
 msgstr ""
 
 # help of 'bind' option of 'branch' command
-#: bzrlib/builtins.py:1280
+#: bzrlib/builtins.py:1315
 msgid "Bind new branch to from location."
 msgstr ""
 
-#: bzrlib/builtins.py:1327
+#: bzrlib/builtins.py:1362
 #, python-format
 msgid "Target directory \"%s\" already exists."
 msgstr ""
 
-#: bzrlib/builtins.py:1339
+#: bzrlib/builtins.py:1374
 #, python-format
 msgid "Parent of \"%s\" does not exist."
 msgstr ""
 
-#: bzrlib/builtins.py:1358
+#: bzrlib/builtins.py:1393
 msgid "The branch {0} has no revision {1}."
 msgstr ""
 
-#: bzrlib/builtins.py:1368 bzrlib/push.py:51
+#: bzrlib/builtins.py:1403 bzrlib/push.py:53
 #, python-format
 msgid "Created new stacked branch referring to %s."
 msgstr ""
 
-#: bzrlib/builtins.py:1372
+#: bzrlib/builtins.py:1407
 #, python-format
 msgid "Branched %d revision."
 msgid_plural "Branched %d revisions."
 msgstr[0] ""
 msgstr[1] ""
 
-#: bzrlib/builtins.py:1377
+#: bzrlib/builtins.py:1412
 #, python-format
 msgid "New branch bound to %s"
 msgstr ""
 
-#: bzrlib/builtins.py:1382 bzrlib/builtins.py:6121
+#: bzrlib/builtins.py:1417 bzrlib/builtins.py:6187
 #, python-format
 msgid "Switched to branch: %s"
 msgstr ""
 
-#: bzrlib/builtins.py:1387
+#: bzrlib/builtins.py:1422
 msgid "List the branches available at the current location."
 msgstr ""
 
-#: bzrlib/builtins.py:1389
+#: bzrlib/builtins.py:1424
 msgid ""
 "This command will print the names of all the branches at the current\n"
 "location."
 msgstr ""
 
 # help of 'recursive' option of 'branches' command
-#: bzrlib/builtins.py:1396
+#: bzrlib/builtins.py:1431
 msgid ""
 "Recursively scan for branches rather than just looking in the specified "
 "location."
 msgstr ""
 
-#: bzrlib/builtins.py:1413
-msgid " (default)\n"
+#: bzrlib/builtins.py:1461
+msgid "(default)"
 msgstr ""
 
-#: bzrlib/builtins.py:1420
+#: bzrlib/builtins.py:1473
 msgid "Create a new checkout of an existing branch."
 msgstr ""
 
-#: bzrlib/builtins.py:1422
+#: bzrlib/builtins.py:1475
 msgid ""
 "If BRANCH_LOCATION is omitted, checkout will reconstitute a working tree "
 "for\n"
@@ -754,7 +781,7 @@
 "location using SFTP."
 msgstr ""
 
-#: bzrlib/builtins.py:1427
+#: bzrlib/builtins.py:1480
 msgid ""
 "If the TO_LOCATION is omitted, the last component of the BRANCH_LOCATION "
 "will\n"
@@ -766,7 +793,7 @@
 "create ./foo-bar."
 msgstr ""
 
-#: bzrlib/builtins.py:1434
+#: bzrlib/builtins.py:1487
 msgid ""
 "To retrieve the branch as of a particular revision, supply the --revision\n"
 "parameter, as in \"checkout foo/bar -r 5\". Note that this will be "
@@ -777,7 +804,7 @@
 msgstr ""
 
 # help of 'lightweight' option of 'checkout' command
-#: bzrlib/builtins.py:1444
+#: bzrlib/builtins.py:1497
 msgid ""
 "Perform a lightweight checkout.  Lightweight checkouts depend on access to "
 "the branch for every operation.  Normal checkouts can perform common "
@@ -786,39 +813,41 @@
 msgstr ""
 
 # help of 'files-from' option of 'branch' command
-#: bzrlib/builtins.py:1451
+# help of 'files-from' option of 'checkout' command
+#: bzrlib/builtins.py:1504
 msgid "Get file contents from this tree."
 msgstr ""
 
 # help of 'hardlink' option of 'branch' command
-#: bzrlib/builtins.py:1453
+# help of 'hardlink' option of 'checkout' command
+#: bzrlib/builtins.py:1506
 msgid "Hard-link working tree files where possible."
 msgstr ""
 
-#: bzrlib/builtins.py:1494
+#: bzrlib/builtins.py:1547
 msgid ""
 "Show list of renamed files.\n"
 "    "
 msgstr ""
 
-#: bzrlib/builtins.py:1524
+#: bzrlib/builtins.py:1577
 msgid "Update a working tree to a new revision."
 msgstr ""
 
-#: bzrlib/builtins.py:1526
+#: bzrlib/builtins.py:1579
 msgid ""
 "This will perform a merge of the destination revision (the tip of the\n"
 "branch, or the specified revision) into the working tree, and then make\n"
 "that revision the basis revision for the working tree.  "
 msgstr ""
 
-#: bzrlib/builtins.py:1530
+#: bzrlib/builtins.py:1583
 msgid ""
 "You can use this to visit an older revision, or to update a working tree\n"
 "that is out of date from its branch."
 msgstr ""
 
-#: bzrlib/builtins.py:1533
+#: bzrlib/builtins.py:1586
 msgid ""
 "If there are any uncommitted changes in the tree, they will be carried\n"
 "across and remain as uncommitted changes after the update.  To discard\n"
@@ -826,13 +855,13 @@
 "with the changes brought in by the change in basis revision."
 msgstr ""
 
-#: bzrlib/builtins.py:1538
+#: bzrlib/builtins.py:1591
 msgid ""
 "If the tree's branch is bound to a master branch, bzr will also update\n"
 "the branch from the master."
 msgstr ""
 
-#: bzrlib/builtins.py:1541
+#: bzrlib/builtins.py:1594
 msgid ""
 "You cannot update just a single file or directory, because each Bazaar\n"
 "working tree has just a single basis revision.  If you want to restore a\n"
@@ -842,95 +871,100 @@
 "out the old content of that file to a new location."
 msgstr ""
 
-#: bzrlib/builtins.py:1548
+#: bzrlib/builtins.py:1601
 msgid ""
 "The 'dir' argument, if given, must be the location of the root of a\n"
 "working tree to update.  By default, the working tree that contains the \n"
 "current working directory is used."
 msgstr ""
 
-#: bzrlib/builtins.py:1564
+#: bzrlib/builtins.py:1617
 msgid "bzr update --revision takes exactly one revision"
 msgstr ""
 
-#: bzrlib/builtins.py:1572
+#: bzrlib/builtins.py:1625
 msgid "bzr update can only update a whole tree, not a file or subdirectory"
 msgstr ""
 
-#: bzrlib/builtins.py:1603
+#: bzrlib/builtins.py:1656
 msgid "Tree is up to date at revision {0} of branch {1}"
 msgstr ""
 
-#: bzrlib/builtins.py:1619
+#: bzrlib/builtins.py:1672
 #, python-format
 msgid ""
 "branch has no revision %s\n"
 "bzr update --revision only works for a revision in the branch history"
 msgstr ""
 
-#: bzrlib/builtins.py:1625
+#: bzrlib/builtins.py:1678
 msgid "Updated to revision {0} of branch {1}"
 msgstr ""
 
-#: bzrlib/builtins.py:1629
+#: bzrlib/builtins.py:1682
 msgid ""
 "Your local commits will now show as pending merges with 'bzr status', and "
 "can be committed with 'bzr commit'."
 msgstr ""
 
-#: bzrlib/builtins.py:1638
+#: bzrlib/builtins.py:1691
 msgid "Show information about a working tree, branch or repository."
 msgstr ""
 
-#: bzrlib/builtins.py:1640
+#: bzrlib/builtins.py:1693
 msgid ""
 "This command will show all known locations and formats associated to the\n"
 "tree, branch or repository."
 msgstr ""
 
-#: bzrlib/builtins.py:1643
+#: bzrlib/builtins.py:1696
 msgid ""
 "In verbose mode, statistical information is included with each report.\n"
 "To see extended statistic information, use a verbosity level of 2 or\n"
 "higher by specifying the verbose option multiple times, e.g. -vv."
 msgstr ""
 
-#: bzrlib/builtins.py:1647
+#: bzrlib/builtins.py:1700
 msgid "Branches and working trees will also report any missing revisions."
 msgstr ""
 
-#: bzrlib/builtins.py:1651
+#: bzrlib/builtins.py:1702 bzrlib/builtins.py:3622 bzrlib/builtins.py:4752
+#: bzrlib/builtins.py:6389
+msgid ":Examples:"
+msgstr ""
+
+#: bzrlib/builtins.py:1704
 msgid "  Display information on the format and related locations:"
 msgstr ""
 
-#: bzrlib/builtins.py:1653
+#: bzrlib/builtins.py:1706
 msgid "    bzr info"
 msgstr ""
 
-#: bzrlib/builtins.py:1655
+#: bzrlib/builtins.py:1708
 msgid ""
 "  Display the above together with extended format information and\n"
 "  basic statistics (like the number of files in the working tree and\n"
 "  number of revisions in the branch and repository):"
 msgstr ""
 
-#: bzrlib/builtins.py:1659
+#: bzrlib/builtins.py:1712
 msgid "    bzr info -v"
 msgstr ""
 
-#: bzrlib/builtins.py:1661
+#: bzrlib/builtins.py:1714
 msgid "  Display the above together with number of committers to the branch:"
 msgstr ""
 
-#: bzrlib/builtins.py:1663
+#: bzrlib/builtins.py:1716
 msgid "    bzr info -vv"
 msgstr ""
 
-#: bzrlib/builtins.py:1682
+#: bzrlib/builtins.py:1735
 msgid "Remove files or directories."
 msgstr ""
 
-#: bzrlib/builtins.py:1684
+#: bzrlib/builtins.py:1737
 msgid ""
 "This makes Bazaar stop tracking changes to the specified files. Bazaar will\n"
 "delete them if they can easily be recovered using revert otherwise they\n"
@@ -940,55 +974,55 @@
 msgstr ""
 
 # help of 'new' option of 'remove' command
-#: bzrlib/builtins.py:1692
+#: bzrlib/builtins.py:1745
 msgid "Only remove files that have never been committed."
 msgstr ""
 
 # help of 'file-deletion-strategy' option of 'remove' command
-#: bzrlib/builtins.py:1694
+#: bzrlib/builtins.py:1747
 msgid "The file deletion mode to be used."
 msgstr ""
 
 # title of 'file-deletion-strategy' option of 'remove' command
-#: bzrlib/builtins.py:1695
+#: bzrlib/builtins.py:1748
 msgid "Deletion Strategy"
 msgstr ""
 
 # help of 'file-deletion-strategy=safe' option of 'remove' command
-#: bzrlib/builtins.py:1696
+#: bzrlib/builtins.py:1749
 msgid "Backup changed files (default)."
 msgstr ""
 
 # help of 'file-deletion-strategy=keep' option of 'remove' command
-#: bzrlib/builtins.py:1697
+#: bzrlib/builtins.py:1750
 msgid "Delete from bzr but leave the working copy."
 msgstr ""
 
 # help of 'file-deletion-strategy=no-backup' option of 'remove' command
-#: bzrlib/builtins.py:1698
+#: bzrlib/builtins.py:1751
 msgid "Don't backup changed files."
 msgstr ""
 
 # help of 'file-deletion-strategy=force' option of 'remove' command
-#: bzrlib/builtins.py:1699
+#: bzrlib/builtins.py:1752
 msgid ""
 "Delete all the specified files, even if they can not be recovered and even "
 "if they are non-empty directories. (deprecated, use no-backup)"
 msgstr ""
 
-#: bzrlib/builtins.py:1708
+#: bzrlib/builtins.py:1761
 msgid "(The --force option is deprecated, rather use --no-backup in future.)"
 msgstr ""
 
-#: bzrlib/builtins.py:1725
+#: bzrlib/builtins.py:1778
 msgid "No matching files."
 msgstr ""
 
-#: bzrlib/builtins.py:1786
+#: bzrlib/builtins.py:1839
 msgid "Reconcile bzr metadata in a branch."
 msgstr ""
 
-#: bzrlib/builtins.py:1788
+#: bzrlib/builtins.py:1841
 msgid ""
 "This can correct data mismatches that may have been caused by\n"
 "previous ghost operations or bzr upgrades. You should only\n"
@@ -996,7 +1030,7 @@
 "advises you to run it."
 msgstr ""
 
-#: bzrlib/builtins.py:1793
+#: bzrlib/builtins.py:1846
 msgid ""
 "If a second branch is provided, cross-branch reconciliation is\n"
 "also attempted, which will check that data like the tree root\n"
@@ -1004,18 +1038,23 @@
 "correctly in both branches."
 msgstr ""
 
-#: bzrlib/builtins.py:1798
+#: bzrlib/builtins.py:1851
 msgid ""
 "At the same time it is run it may recompress data resulting in\n"
 "a potential saving in disk space or performance gain."
 msgstr ""
 
-#: bzrlib/builtins.py:1801
+#: bzrlib/builtins.py:1854
 msgid "The branch *MUST* be on a listable system such as local disk or sftp."
 msgstr ""
 
 # help of 'format=2a' option of 'init' command
-#: bzrlib/builtins.py:1868
+# help of 'format=default' option of 'init' command
+# help of 'format=2a' option of 'init-repository' command
+# help of 'format=default' option of 'init-repository' command
+# help of 'format=2a' option of 'upgrade' command
+# help of 'format=default' option of 'upgrade' command
+#: bzrlib/builtins.py:1921 bzrlib/builtins.py:2039 bzrlib/builtins.py:3657
 msgid ""
 "Format for the bzr 2.0 series.\n"
 "Uses group-compress storage.\n"
@@ -1023,28 +1062,32 @@
 msgstr ""
 
 # help of 'format=pack-0.92' option of 'init' command
-#: bzrlib/builtins.py:1868
+# help of 'format=pack-0.92' option of 'init-repository' command
+# help of 'format=pack-0.92' option of 'upgrade' command
+#: bzrlib/builtins.py:1921 bzrlib/builtins.py:2039 bzrlib/builtins.py:3657
 msgid ""
 "Pack-based format used in 1.x series. Introduced in 0.92. Interoperates with "
 "bzr repositories before 0.92 but cannot be read by bzr < 0.92. "
 msgstr ""
 
 # help of 'format=development-colo' option of 'init' command
-#: bzrlib/builtins.py:1868
+# help of 'format=development-colo' option of 'init-repository' command
+# help of 'format=development-colo' option of 'upgrade' command
+#: bzrlib/builtins.py:1921 bzrlib/builtins.py:2039 bzrlib/builtins.py:3657
 msgid "The 2a format with experimental support for colocated branches.\n"
 msgstr ""
 
-#: bzrlib/builtins.py:1869
+#: bzrlib/builtins.py:1922
 msgid "Make a directory into a versioned branch."
 msgstr ""
 
-#: bzrlib/builtins.py:1871
+#: bzrlib/builtins.py:1924
 msgid ""
 "Use this to create an empty branch, or before importing an\n"
 "existing project."
 msgstr ""
 
-#: bzrlib/builtins.py:1874
+#: bzrlib/builtins.py:1927
 msgid ""
 "If there is a repository in a parent directory of the location, then\n"
 "the history of the branch will be stored in the repository.  Otherwise\n"
@@ -1052,17 +1095,17 @@
 "in the .bzr directory."
 msgstr ""
 
-#: bzrlib/builtins.py:1879
+#: bzrlib/builtins.py:1932
 msgid ""
 "If there is already a branch at the location but it has no working tree,\n"
 "the tree can be populated with 'bzr checkout'."
 msgstr ""
 
-#: bzrlib/builtins.py:1882
+#: bzrlib/builtins.py:1935
 msgid "Recipe for importing a tree of files::"
 msgstr ""
 
-#: bzrlib/builtins.py:1884
+#: bzrlib/builtins.py:1937
 msgid ""
 "    cd ~/project\n"
 "    bzr init\n"
@@ -1072,51 +1115,52 @@
 msgstr ""
 
 # help of 'create-prefix' option of 'init' command
-#: bzrlib/builtins.py:1895
+# help of 'create-prefix' option of 'push' command
+#: bzrlib/builtins.py:1948
 msgid "Create the path leading up to the branch if it does not already exist."
 msgstr ""
 
 # help of 'format' option of 'init' command
-#: bzrlib/builtins.py:1898
+#: bzrlib/builtins.py:1951
 msgid "Specify a format for this branch. See \"help formats\"."
 msgstr ""
 
 # help of 'append-revisions-only' option of 'init' command
-#: bzrlib/builtins.py:1906
+#: bzrlib/builtins.py:1959
 msgid "Never change revnos or the existing log.  Append revisions to it only."
 msgstr ""
 
 # help of 'no-tree' option of 'init' command
-#: bzrlib/builtins.py:1909
+#: bzrlib/builtins.py:1962
 msgid "Create a branch without a working tree."
 msgstr ""
 
-#: bzrlib/builtins.py:1929 bzrlib/push.py:108
+#: bzrlib/builtins.py:1982 bzrlib/push.py:110
 #, python-format
 msgid ""
 "Parent directory of %s does not exist.\n"
 "You may supply --create-prefix to create all leading parent directories."
 msgstr ""
 
-#: bzrlib/builtins.py:1963
+#: bzrlib/builtins.py:2016
 msgid ""
 "This branch format cannot be set to append-revisions-only.  Try --default."
 msgstr ""
 
-#: bzrlib/builtins.py:1974
+#: bzrlib/builtins.py:2027
 msgid "Created a {0} (format: {1})\n"
 msgstr ""
 
-#: bzrlib/builtins.py:1983
+#: bzrlib/builtins.py:2036
 #, python-format
 msgid "Using shared repository: %s\n"
 msgstr ""
 
-#: bzrlib/builtins.py:1987
+#: bzrlib/builtins.py:2040
 msgid "Create a shared repository for branches to share storage space."
 msgstr ""
 
-#: bzrlib/builtins.py:1989
+#: bzrlib/builtins.py:2042
 msgid ""
 "New branches created under the repository directory will store their\n"
 "revisions in the repository, not in the branch directory.  For branches\n"
@@ -1124,7 +1168,7 @@
 "speeds up the creation of new branches."
 msgstr ""
 
-#: bzrlib/builtins.py:1994
+#: bzrlib/builtins.py:2047
 msgid ""
 "If the --no-trees option is given then the branches in the repository\n"
 "will not have working trees by default.  They will still exist as \n"
@@ -1134,23 +1178,23 @@
 "branches, such as on a server."
 msgstr ""
 
-#: bzrlib/builtins.py:2001
+#: bzrlib/builtins.py:2054
 msgid ""
 ":Examples:\n"
 "    Create a shared repository holding just branches::"
 msgstr ""
 
-#: bzrlib/builtins.py:2004
+#: bzrlib/builtins.py:2057
 msgid ""
 "        bzr init-repo --no-trees repo\n"
 "        bzr init repo/trunk"
 msgstr ""
 
-#: bzrlib/builtins.py:2007
+#: bzrlib/builtins.py:2060
 msgid "    Make a lightweight checkout elsewhere::"
 msgstr ""
 
-#: bzrlib/builtins.py:2009
+#: bzrlib/builtins.py:2062
 msgid ""
 "        bzr checkout --lightweight repo/trunk trunk-checkout\n"
 "        cd trunk-checkout\n"
@@ -1158,26 +1202,26 @@
 msgstr ""
 
 # help of 'format' option of 'init-repository' command
-#: bzrlib/builtins.py:2017
+#: bzrlib/builtins.py:2070
 msgid ""
 "Specify a format for this repository. See \"bzr help formats\" for details."
 msgstr ""
 
 # title of 'format' option of 'init-repository' command
-#: bzrlib/builtins.py:2021
+#: bzrlib/builtins.py:2074
 msgid "Repository format"
 msgstr ""
 
 # help of 'no-trees' option of 'init-repository' command
-#: bzrlib/builtins.py:2023
+#: bzrlib/builtins.py:2076
 msgid "Branches in the repository will default to not having a working tree."
 msgstr ""
 
-#: bzrlib/builtins.py:2047
+#: bzrlib/builtins.py:2102
 msgid "Show differences in the working tree, between revisions or branches."
 msgstr ""
 
-#: bzrlib/builtins.py:2049
+#: bzrlib/builtins.py:2104
 msgid ""
 "If no arguments are given, all changes for the current tree are listed.\n"
 "If files are given, only the changes in those files are listed.\n"
@@ -1187,13 +1231,13 @@
 "given."
 msgstr ""
 
-#: bzrlib/builtins.py:2056
+#: bzrlib/builtins.py:2111
 msgid ""
 "\"bzr diff -p1\" is equivalent to \"bzr diff --prefix old/:new/\", and\n"
 "produces patches suitable for \"patch -p1\"."
 msgstr ""
 
-#: bzrlib/builtins.py:2059
+#: bzrlib/builtins.py:2114
 msgid ""
 "Note that when using the -r argument with a range of revisions, the\n"
 "differences are computed between the two specified revisions.  That\n"
@@ -1203,7 +1247,7 @@
 "in the range."
 msgstr ""
 
-#: bzrlib/builtins.py:2066
+#: bzrlib/builtins.py:2121
 msgid ""
 ":Exit values:\n"
 "    1 - changed\n"
@@ -1212,113 +1256,113 @@
 "    0 - no change"
 msgstr ""
 
-#: bzrlib/builtins.py:2072
+#: bzrlib/builtins.py:2127
 msgid ""
 ":Examples:\n"
 "    Shows the difference in the working tree versus the last commit::"
 msgstr ""
 
-#: bzrlib/builtins.py:2075
+#: bzrlib/builtins.py:2130
 msgid "        bzr diff"
 msgstr ""
 
-#: bzrlib/builtins.py:2077
+#: bzrlib/builtins.py:2132
 msgid "    Difference between the working tree and revision 1::"
 msgstr ""
 
-#: bzrlib/builtins.py:2079
+#: bzrlib/builtins.py:2134
 msgid "        bzr diff -r1"
 msgstr ""
 
-#: bzrlib/builtins.py:2081
+#: bzrlib/builtins.py:2136
 msgid "    Difference between revision 3 and revision 1::"
 msgstr ""
 
-#: bzrlib/builtins.py:2083
+#: bzrlib/builtins.py:2138
 msgid "        bzr diff -r1..3"
 msgstr ""
 
-#: bzrlib/builtins.py:2085
+#: bzrlib/builtins.py:2140
 msgid "    Difference between revision 3 and revision 1 for branch xxx::"
 msgstr ""
 
-#: bzrlib/builtins.py:2087
+#: bzrlib/builtins.py:2142
 msgid "        bzr diff -r1..3 xxx"
 msgstr ""
 
-#: bzrlib/builtins.py:2089
+#: bzrlib/builtins.py:2144
 msgid "    The changes introduced by revision 2 (equivalent to -r1..2)::"
 msgstr ""
 
-#: bzrlib/builtins.py:2091
+#: bzrlib/builtins.py:2146
 msgid "        bzr diff -c2"
 msgstr ""
 
-#: bzrlib/builtins.py:2093
+#: bzrlib/builtins.py:2148
 msgid ""
 "    To see the changes introduced by revision X::\n"
 "    \n"
 "        bzr diff -cX"
 msgstr ""
 
-#: bzrlib/builtins.py:2097
+#: bzrlib/builtins.py:2152
 msgid ""
 "    Note that in the case of a merge, the -c option shows the changes\n"
 "    compared to the left hand parent. To see the changes against\n"
 "    another parent, use::"
 msgstr ""
 
-#: bzrlib/builtins.py:2101
+#: bzrlib/builtins.py:2156
 msgid "        bzr diff -r<chosen_parent>..X"
 msgstr ""
 
-#: bzrlib/builtins.py:2103
+#: bzrlib/builtins.py:2158
 msgid ""
 "    The changes between the current revision and the previous revision\n"
 "    (equivalent to -c-1 and -r-2..-1)"
 msgstr ""
 
-#: bzrlib/builtins.py:2106
+#: bzrlib/builtins.py:2161
 msgid "        bzr diff -r-2.."
 msgstr ""
 
-#: bzrlib/builtins.py:2108
+#: bzrlib/builtins.py:2163
 msgid "    Show just the differences for file NEWS::"
 msgstr ""
 
-#: bzrlib/builtins.py:2110
+#: bzrlib/builtins.py:2165
 msgid "        bzr diff NEWS"
 msgstr ""
 
-#: bzrlib/builtins.py:2112
+#: bzrlib/builtins.py:2167
 msgid "    Show the differences in working tree xxx for file NEWS::"
 msgstr ""
 
-#: bzrlib/builtins.py:2114
+#: bzrlib/builtins.py:2169
 msgid "        bzr diff xxx/NEWS"
 msgstr ""
 
-#: bzrlib/builtins.py:2116
+#: bzrlib/builtins.py:2171
 msgid "    Show the differences from branch xxx to this working tree:"
 msgstr ""
 
-#: bzrlib/builtins.py:2118
+#: bzrlib/builtins.py:2173
 msgid "        bzr diff --old xxx"
 msgstr ""
 
-#: bzrlib/builtins.py:2120
+#: bzrlib/builtins.py:2175
 msgid "    Show the differences between two branches for file NEWS::"
 msgstr ""
 
-#: bzrlib/builtins.py:2122
+#: bzrlib/builtins.py:2177
 msgid "        bzr diff --old xxx --new yyy NEWS"
 msgstr ""
 
-#: bzrlib/builtins.py:2124
+#: bzrlib/builtins.py:2179
 msgid "    Same as 'bzr diff' but prefix paths with old/ and new/::"
 msgstr ""
 
-#: bzrlib/builtins.py:2126
+#: bzrlib/builtins.py:2181
 msgid ""
 "        bzr diff --prefix old/:new/\n"
 "        \n"
@@ -1328,84 +1372,84 @@
 msgstr ""
 
 # help of 'diff-options' option of 'diff' command
-#: bzrlib/builtins.py:2136
+#: bzrlib/builtins.py:2191
 msgid "Pass these options to the external diff program."
 msgstr ""
 
 # help of 'prefix' option of 'diff' command
-#: bzrlib/builtins.py:2139
+#: bzrlib/builtins.py:2194
 msgid ""
 "Set prefixes added to old and new filenames, as two values separated by a "
 "colon. (eg \"old/:new/\")."
 msgstr ""
 
 # help of 'old' option of 'diff' command
-#: bzrlib/builtins.py:2142
+#: bzrlib/builtins.py:2197
 msgid "Branch/tree to compare from."
 msgstr ""
 
 # help of 'new' option of 'diff' command
-#: bzrlib/builtins.py:2146
+#: bzrlib/builtins.py:2201
 msgid "Branch/tree to compare to."
 msgstr ""
 
 # help of 'using' option of 'diff' command
-#: bzrlib/builtins.py:2152
+#: bzrlib/builtins.py:2207
 msgid "Use this command to compare files."
 msgstr ""
 
 # help of 'format' option of 'diff' command
-#: bzrlib/builtins.py:2157
+#: bzrlib/builtins.py:2212
 msgid "Diff format to use."
 msgstr ""
 
 # title of 'format' option of 'diff' command
-#: bzrlib/builtins.py:2159
+#: bzrlib/builtins.py:2214
 msgid "Diff format"
 msgstr ""
 
-#: bzrlib/builtins.py:2181
+#: bzrlib/builtins.py:2236
 msgid "--prefix expects two values separated by a colon (eg \"old/:new/\")"
 msgstr ""
 
-#: bzrlib/builtins.py:2185
+#: bzrlib/builtins.py:2240
 msgid "bzr diff --revision takes exactly one or two revision specifiers"
 msgstr ""
 
-#: bzrlib/builtins.py:2190 bzrlib/builtins.py:2588 bzrlib/builtins.py:2601
-#: bzrlib/builtins.py:2609 bzrlib/builtins.py:4760
+#: bzrlib/builtins.py:2245 bzrlib/builtins.py:2643 bzrlib/builtins.py:2656
+#: bzrlib/builtins.py:2664 bzrlib/builtins.py:4826
 msgid "{0} and {1} are mutually exclusive"
 msgstr ""
 
-#: bzrlib/builtins.py:2210
+#: bzrlib/builtins.py:2265
 msgid ""
 "List files deleted in the working tree.\n"
 "    "
 msgstr ""
 
-#: bzrlib/builtins.py:2288
+#: bzrlib/builtins.py:2343
 msgid "Show the tree root directory."
 msgstr ""
 
-#: bzrlib/builtins.py:2290
+#: bzrlib/builtins.py:2345
 msgid ""
 "The root is the nearest enclosing directory with a .bzr control\n"
 "directory."
 msgstr ""
 
-#: bzrlib/builtins.py:2305
+#: bzrlib/builtins.py:2360
 msgid "The limit argument must be an integer."
 msgstr ""
 
-#: bzrlib/builtins.py:2313
+#: bzrlib/builtins.py:2368
 msgid "The levels argument must be an integer."
 msgstr ""
 
-#: bzrlib/builtins.py:2318
+#: bzrlib/builtins.py:2373
 msgid "Show historical log for a branch or subset of a branch."
 msgstr ""
 
-#: bzrlib/builtins.py:2320
+#: bzrlib/builtins.py:2375
 msgid ""
 "log is bzr's default tool for exploring the history of a branch.\n"
 "The branch to use is taken from the first parameter. If no parameters\n"
@@ -1413,14 +1457,14 @@
 "Here are some simple examples::"
 msgstr ""
 
-#: bzrlib/builtins.py:2325
+#: bzrlib/builtins.py:2380
 msgid ""
 "  bzr log                       log the current branch\n"
 "  bzr log foo.py                log a file in its branch\n"
 "  bzr log http://server/branch  log a branch on a server"
 msgstr ""
 
-#: bzrlib/builtins.py:2329
+#: bzrlib/builtins.py:2384
 msgid ""
 "The filtering, ordering and information shown for each revision can\n"
 "be controlled as explained below. By default, all revisions are\n"
@@ -1430,11 +1474,11 @@
 "were merged."
 msgstr ""
 
-#: bzrlib/builtins.py:2336
+#: bzrlib/builtins.py:2391
 msgid ":Output control:"
 msgstr ""
 
-#: bzrlib/builtins.py:2338
+#: bzrlib/builtins.py:2393
 msgid ""
 "  The log format controls how information about each revision is\n"
 "  displayed. The standard log formats are called ``long``, ``short``\n"
@@ -1442,13 +1486,13 @@
 "  for more details on log formats."
 msgstr ""
 
-#: bzrlib/builtins.py:2343
+#: bzrlib/builtins.py:2398
 msgid ""
 "  The following options can be used to control what information is\n"
 "  displayed::"
 msgstr ""
 
-#: bzrlib/builtins.py:2346
+#: bzrlib/builtins.py:2401
 msgid ""
 "    -l N        display a maximum of N revisions\n"
 "    -n N        display N levels of revisions (0 for all, 1 for collapsed)\n"
@@ -1457,25 +1501,25 @@
 "    --show-ids  display revision-ids (and file-ids), not just revnos"
 msgstr ""
 
-#: bzrlib/builtins.py:2352
+#: bzrlib/builtins.py:2407
 msgid ""
 "  Note that the default number of levels to display is a function of the\n"
 "  log format. If the -n option is not used, the standard log formats show\n"
 "  just the top level (mainline)."
 msgstr ""
 
-#: bzrlib/builtins.py:2356
+#: bzrlib/builtins.py:2411
 msgid ""
 "  Status summaries are shown using status flags like A, M, etc. To see\n"
 "  the changes explained using words like ``added`` and ``modified``\n"
 "  instead, use the -vv option."
 msgstr ""
 
-#: bzrlib/builtins.py:2360
+#: bzrlib/builtins.py:2415
 msgid ":Ordering control:"
 msgstr ""
 
-#: bzrlib/builtins.py:2362
+#: bzrlib/builtins.py:2417
 msgid ""
 "  To display revisions from oldest to newest, use the --forward option.\n"
 "  In most cases, using this option will have little impact on the total\n"
@@ -1483,17 +1527,17 @@
 "  display revisions like --reverse does when it can."
 msgstr ""
 
-#: bzrlib/builtins.py:2367
+#: bzrlib/builtins.py:2422
 msgid ":Revision filtering:"
 msgstr ""
 
-#: bzrlib/builtins.py:2369
+#: bzrlib/builtins.py:2424
 msgid ""
 "  The -r option can be used to specify what revision or range of revisions\n"
 "  to filter against. The various forms are shown below::"
 msgstr ""
 
-#: bzrlib/builtins.py:2372
+#: bzrlib/builtins.py:2427
 msgid ""
 "    -rX      display revision X\n"
 "    -rX..    display revision X and later\n"
@@ -1501,13 +1545,13 @@
 "    -rX..Y   display from X to Y inclusive"
 msgstr ""
 
-#: bzrlib/builtins.py:2377
+#: bzrlib/builtins.py:2432
 msgid ""
 "  See ``bzr help revisionspec`` for details on how to specify X and Y.\n"
 "  Some common examples are given below::"
 msgstr ""
 
-#: bzrlib/builtins.py:2380
+#: bzrlib/builtins.py:2435
 msgid ""
 "    -r-1                show just the tip\n"
 "    -r-10..             show the last 10 mainline revisions\n"
@@ -1517,7 +1561,7 @@
 "    -rdate:yesterday..  show changes since yesterday"
 msgstr ""
 
-#: bzrlib/builtins.py:2387
+#: bzrlib/builtins.py:2442
 msgid ""
 "  When logging a range of revisions using -rX..Y, log starts at\n"
 "  revision Y and searches back in history through the primary\n"
@@ -1527,73 +1571,73 @@
 "  a nested merge revision and the log will be truncated accordingly."
 msgstr ""
 
-#: bzrlib/builtins.py:2394
+#: bzrlib/builtins.py:2449
 msgid ":Path filtering:"
 msgstr ""
 
-#: bzrlib/builtins.py:2396
+#: bzrlib/builtins.py:2451
 msgid ""
 "  If parameters are given and the first one is not a branch, the log\n"
 "  will be filtered to show only those revisions that changed the\n"
 "  nominated files or directories."
 msgstr ""
 
-#: bzrlib/builtins.py:2400
+#: bzrlib/builtins.py:2455
 msgid ""
 "  Filenames are interpreted within their historical context. To log a\n"
 "  deleted file, specify a revision range so that the file existed at\n"
 "  the end or start of the range."
 msgstr ""
 
-#: bzrlib/builtins.py:2404
+#: bzrlib/builtins.py:2459
 msgid ""
 "  Historical context is also important when interpreting pathnames of\n"
 "  renamed files/directories. Consider the following example:"
 msgstr ""
 
-#: bzrlib/builtins.py:2407
+#: bzrlib/builtins.py:2462
 msgid ""
 "  * revision 1: add tutorial.txt\n"
 "  * revision 2: modify tutorial.txt\n"
 "  * revision 3: rename tutorial.txt to guide.txt; add tutorial.txt"
 msgstr ""
 
-#: bzrlib/builtins.py:2411
+#: bzrlib/builtins.py:2466
 msgid "  In this case:"
 msgstr ""
 
-#: bzrlib/builtins.py:2413
+#: bzrlib/builtins.py:2468
 msgid "  * ``bzr log guide.txt`` will log the file added in revision 1"
 msgstr ""
 
-#: bzrlib/builtins.py:2415
+#: bzrlib/builtins.py:2470
 msgid "  * ``bzr log tutorial.txt`` will log the new file added in revision 3"
 msgstr ""
 
-#: bzrlib/builtins.py:2417
+#: bzrlib/builtins.py:2472
 msgid ""
 "  * ``bzr log -r2 -p tutorial.txt`` will show the changes made to\n"
 "    the original file in revision 2."
 msgstr ""
 
-#: bzrlib/builtins.py:2420
+#: bzrlib/builtins.py:2475
 msgid ""
 "  * ``bzr log -r2 -p guide.txt`` will display an error message as there\n"
 "    was no file called guide.txt in revision 2."
 msgstr ""
 
-#: bzrlib/builtins.py:2423
+#: bzrlib/builtins.py:2478
 msgid ""
 "  Renames are always followed by log. By design, there is no need to\n"
 "  explicitly ask for this (and no way to stop logging a file back\n"
 "  until it was last renamed)."
 msgstr ""
 
-#: bzrlib/builtins.py:2427
+#: bzrlib/builtins.py:2482
 msgid ":Other filtering:"
 msgstr ""
 
-#: bzrlib/builtins.py:2429
+#: bzrlib/builtins.py:2484
 msgid ""
 "  The --match option can be used for finding revisions that match a\n"
 "  regular expression in a commit message, committer, author or bug.\n"
@@ -1602,11 +1646,11 @@
 "  --match-message can be used to only match a specific field."
 msgstr ""
 
-#: bzrlib/builtins.py:2435
+#: bzrlib/builtins.py:2490
 msgid ":Tips & tricks:"
 msgstr ""
 
-#: bzrlib/builtins.py:2437
+#: bzrlib/builtins.py:2492
 msgid ""
 "  GUI tools and IDEs are often better at exploring history than command\n"
 "  line tools: you may prefer qlog or viz from qbzr or bzr-gtk, the\n"
@@ -1615,11 +1659,11 @@
 "  <http://wiki.bazaar.canonical.com/IDEIntegration>.  "
 msgstr ""
 
-#: bzrlib/builtins.py:2443
+#: bzrlib/builtins.py:2498
 msgid "  You may find it useful to add the aliases below to ``bazaar.conf``::"
 msgstr ""
 
-#: bzrlib/builtins.py:2445
+#: bzrlib/builtins.py:2500
 msgid ""
 "    [ALIASES]\n"
 "    tip = log -r-1\n"
@@ -1627,20 +1671,20 @@
 "    show = log -v -p"
 msgstr ""
 
-#: bzrlib/builtins.py:2450
+#: bzrlib/builtins.py:2505
 msgid ""
 "  ``bzr tip`` will then show the latest revision while ``bzr top``\n"
 "  will show the last 10 mainline revisions. To see the details of a\n"
 "  particular revision X,  ``bzr show -rX``."
 msgstr ""
 
-#: bzrlib/builtins.py:2454
+#: bzrlib/builtins.py:2509
 msgid ""
 "  If you are interested in looking deeper into a particular merge X,\n"
 "  use ``bzr log -n0 -rX``."
 msgstr ""
 
-#: bzrlib/builtins.py:2457
+#: bzrlib/builtins.py:2512
 msgid ""
 "  ``bzr log -v`` on a branch with lots of history is currently\n"
 "  very slow. A fix for this issue is currently under development.\n"
@@ -1648,7 +1692,7 @@
 "  be given when using the -v option."
 msgstr ""
 
-#: bzrlib/builtins.py:2462
+#: bzrlib/builtins.py:2517
 msgid ""
 "  bzr has a generic full-text matching plugin, bzr-search, that can be\n"
 "  used to find revisions matching user names, commit messages, etc.\n"
@@ -1656,7 +1700,7 @@
 "  a list of words but not others."
 msgstr ""
 
-#: bzrlib/builtins.py:2467
+#: bzrlib/builtins.py:2522
 msgid ""
 "  When exploring non-mainline history on large projects with deep\n"
 "  history, the performance of log can be greatly improved by installing\n"
@@ -1665,168 +1709,168 @@
 msgstr ""
 
 # help of 'forward' option of 'log' command
-#: bzrlib/builtins.py:2476
+#: bzrlib/builtins.py:2531
 msgid "Show from oldest to newest."
 msgstr ""
 
 # help of 'verbose' option of 'log' command
-#: bzrlib/builtins.py:2479
+#: bzrlib/builtins.py:2534
 msgid "Show files changed in each revision."
 msgstr ""
 
 # help of 'change' option of 'log' command
-#: bzrlib/builtins.py:2485
+#: bzrlib/builtins.py:2540
 msgid "Show just the specified revision. See also \"help revisionspec\"."
 msgstr ""
 
 # help of 'authors' option of 'log' command
-#: bzrlib/builtins.py:2489
+#: bzrlib/builtins.py:2544
 msgid "What names to list as authors - first, all or committer."
 msgstr ""
 
 # title of 'authors' option of 'log' command
-#: bzrlib/builtins.py:2490
+#: bzrlib/builtins.py:2545
 msgid "Authors"
 msgstr ""
 
 # help of 'levels' option of 'log' command
-#: bzrlib/builtins.py:2495
+#: bzrlib/builtins.py:2550
 msgid "Number of levels to display - 0 for all, 1 for flat."
 msgstr ""
 
 # help of 'limit' option of 'log' command
-#: bzrlib/builtins.py:2505
+#: bzrlib/builtins.py:2560
 msgid "Limit the output to the first N revisions."
 msgstr ""
 
 # help of 'show-diff' option of 'log' command
-#: bzrlib/builtins.py:2510
+#: bzrlib/builtins.py:2565
 msgid "Show changes made in each revision as a patch."
 msgstr ""
 
 # help of 'include-merged' option of 'log' command
-#: bzrlib/builtins.py:2512
+#: bzrlib/builtins.py:2567
 msgid "Show merged revisions like --levels 0 does."
 msgstr ""
 
 # help of 'omit-merges' option of 'log' command
-#: bzrlib/builtins.py:2516
+#: bzrlib/builtins.py:2571
 msgid "Do not report commits with more than one parent."
 msgstr ""
 
 # help of 'exclude-common-ancestry' option of 'log' command
-#: bzrlib/builtins.py:2518
+#: bzrlib/builtins.py:2573
 msgid ""
 "Display only the revisions that are not part of both ancestries (require -"
 "rX..Y)."
 msgstr ""
 
 # help of 'signatures' option of 'log' command
-#: bzrlib/builtins.py:2522
+#: bzrlib/builtins.py:2577
 msgid "Show digital signature validity."
 msgstr ""
 
 # help of 'match' option of 'log' command
-#: bzrlib/builtins.py:2525
+#: bzrlib/builtins.py:2580
 msgid "Show revisions whose properties match this expression."
 msgstr ""
 
 # help of 'match-message' option of 'log' command
-#: bzrlib/builtins.py:2529
+#: bzrlib/builtins.py:2584
 msgid "Show revisions whose message matches this expression."
 msgstr ""
 
 # help of 'match-committer' option of 'log' command
-#: bzrlib/builtins.py:2533
+#: bzrlib/builtins.py:2588
 msgid "Show revisions whose committer matches this expression."
 msgstr ""
 
 # help of 'match-author' option of 'log' command
-#: bzrlib/builtins.py:2537
+#: bzrlib/builtins.py:2592
 msgid "Show revisions whose authors match this expression."
 msgstr ""
 
 # help of 'match-bugs' option of 'log' command
-#: bzrlib/builtins.py:2541
+#: bzrlib/builtins.py:2596
 msgid "Show revisions whose bugs match this expression."
 msgstr ""
 
-#: bzrlib/builtins.py:2595
+#: bzrlib/builtins.py:2650
 msgid "--exclude-common-ancestry requires -r with two revisions"
 msgstr ""
 
-#: bzrlib/builtins.py:2623
+#: bzrlib/builtins.py:2678
 #, python-format
 msgid "Path unknown at end or start of revision range: %s"
 msgstr ""
 
-#: bzrlib/builtins.py:2740
+#: bzrlib/builtins.py:2795
 #, python-format
 msgid "bzr %s doesn't accept two revisions in different branches."
 msgstr ""
 
-#: bzrlib/builtins.py:2756
+#: bzrlib/builtins.py:2811
 #, python-format
 msgid "bzr %s --revision takes one or two values."
 msgstr ""
 
-#: bzrlib/builtins.py:2801
+#: bzrlib/builtins.py:2856
 msgid ""
 "List files in a tree.\n"
 "    "
 msgstr ""
 
 # help of 'recursive' option of 'ls' command
-#: bzrlib/builtins.py:2810
+#: bzrlib/builtins.py:2865
 msgid "Recurse into subdirectories."
 msgstr ""
 
 # help of 'from-root' option of 'ls' command
-#: bzrlib/builtins.py:2812
+#: bzrlib/builtins.py:2867
 msgid "Print paths relative to the root of the branch."
 msgstr ""
 
 # help of 'unknown' option of 'ls' command
-#: bzrlib/builtins.py:2814
+#: bzrlib/builtins.py:2869
 msgid "Print unknown files."
 msgstr ""
 
 # help of 'versioned' option of 'ls' command
-#: bzrlib/builtins.py:2815
+#: bzrlib/builtins.py:2870
 msgid "Print versioned files."
 msgstr ""
 
 # help of 'ignored' option of 'ls' command
-#: bzrlib/builtins.py:2818
+#: bzrlib/builtins.py:2873
 msgid "Print ignored files."
 msgstr ""
 
 # help of 'kind' option of 'ls' command
-#: bzrlib/builtins.py:2820
+#: bzrlib/builtins.py:2875
 msgid "List entries of a particular kind: file, directory, symlink."
 msgstr ""
 
-#: bzrlib/builtins.py:2833
+#: bzrlib/builtins.py:2888
 msgid "invalid kind specified"
 msgstr ""
 
-#: bzrlib/builtins.py:2836
+#: bzrlib/builtins.py:2891
 msgid "Cannot set both --verbose and --null"
 msgstr ""
 
-#: bzrlib/builtins.py:2845
+#: bzrlib/builtins.py:2900
 msgid "cannot specify both --from-root and PATH"
 msgstr ""
 
-#: bzrlib/builtins.py:2932
+#: bzrlib/builtins.py:2987
 msgid "Ignore specified files or patterns."
 msgstr ""
 
-#: bzrlib/builtins.py:2934
+#: bzrlib/builtins.py:2989
 msgid "See ``bzr help patterns`` for details on the syntax of patterns."
 msgstr ""
 
-#: bzrlib/builtins.py:2936
+#: bzrlib/builtins.py:2991
 msgid ""
 "If a .bzrignore file does not exist, the ignore command\n"
 "will create one and add the specified files or patterns to the newly\n"
@@ -1835,7 +1879,7 @@
 "the use of the ignore command will require an explicit add command."
 msgstr ""
 
-#: bzrlib/builtins.py:2942
+#: bzrlib/builtins.py:2997
 msgid ""
 "To remove patterns from the ignore list, edit the .bzrignore file.\n"
 "After adding, editing or deleting that file either indirectly by\n"
@@ -1843,7 +1887,7 @@
 "it."
 msgstr ""
 
-#: bzrlib/builtins.py:2947
+#: bzrlib/builtins.py:3002
 msgid ""
 "Bazaar also supports a global ignore file ~/.bazaar/ignore. On Windows\n"
 "the global ignore file can be found in the application data directory as\n"
@@ -1852,20 +1896,20 @@
 "can be edited directly using an editor."
 msgstr ""
 
-#: bzrlib/builtins.py:2953
+#: bzrlib/builtins.py:3008
 msgid ""
 "Patterns prefixed with '!' are exceptions to ignore patterns and take\n"
 "precedence over regular ignores.  Such exceptions are used to specify\n"
 "files that should be versioned which would otherwise be ignored."
 msgstr ""
 
-#: bzrlib/builtins.py:2957
+#: bzrlib/builtins.py:3012
 msgid ""
 "Patterns prefixed with '!!' act as regular ignore patterns, but have\n"
 "precedence over the '!' exception patterns."
 msgstr ""
 
-#: bzrlib/builtins.py:2960
+#: bzrlib/builtins.py:3015
 msgid ""
 ":Notes: \n"
 "    \n"
@@ -1873,63 +1917,63 @@
 "  the shell on Unix."
 msgstr ""
 
-#: bzrlib/builtins.py:2965
+#: bzrlib/builtins.py:3020
 msgid ""
 "* Ignore patterns starting with \"#\" act as comments in the ignore file.\n"
 "  To ignore patterns that begin with that character, use the \"RE:\" prefix."
 msgstr ""
 
-#: bzrlib/builtins.py:2968
+#: bzrlib/builtins.py:3023
 msgid ""
 ":Examples:\n"
 "    Ignore the top level Makefile::"
 msgstr ""
 
-#: bzrlib/builtins.py:2971
+#: bzrlib/builtins.py:3026
 msgid "        bzr ignore ./Makefile"
 msgstr ""
 
-#: bzrlib/builtins.py:2973
+#: bzrlib/builtins.py:3028
 msgid "    Ignore .class files in all directories...::"
 msgstr ""
 
-#: bzrlib/builtins.py:2975
+#: bzrlib/builtins.py:3030
 msgid "        bzr ignore \"*.class\""
 msgstr ""
 
-#: bzrlib/builtins.py:2977
+#: bzrlib/builtins.py:3032
 msgid "    ...but do not ignore \"special.class\"::"
 msgstr ""
 
-#: bzrlib/builtins.py:2979
+#: bzrlib/builtins.py:3034
 msgid "        bzr ignore \"!special.class\""
 msgstr ""
 
-#: bzrlib/builtins.py:2981
+#: bzrlib/builtins.py:3036
 msgid "    Ignore files whose name begins with the \"#\" character::"
 msgstr ""
 
-#: bzrlib/builtins.py:2983
+#: bzrlib/builtins.py:3038
 msgid "        bzr ignore \"RE:^#\""
 msgstr ""
 
-#: bzrlib/builtins.py:2985
+#: bzrlib/builtins.py:3040 bzrlib/builtins.py:3044
 msgid "    Ignore .o files under the lib directory::"
 msgstr ""
 
-#: bzrlib/builtins.py:2987
+#: bzrlib/builtins.py:3042
 msgid "        bzr ignore \"lib/**/*.o\""
 msgstr ""
 
-#: bzrlib/builtins.py:2991
+#: bzrlib/builtins.py:3046
 msgid "        bzr ignore \"RE:lib/.*\\.o\""
 msgstr ""
 
-#: bzrlib/builtins.py:2993
+#: bzrlib/builtins.py:3048
 msgid "    Ignore everything but the \"debian\" toplevel directory::"
 msgstr ""
 
-#: bzrlib/builtins.py:2995
+#: bzrlib/builtins.py:3050
 msgid ""
 "        bzr ignore \"RE:(?!debian/).*\"\n"
 "    \n"
@@ -1942,26 +1986,26 @@
 msgstr ""
 
 # help of 'default-rules' option of 'ignore' command
-#: bzrlib/builtins.py:3009
+#: bzrlib/builtins.py:3064
 msgid "Display the default ignore rules that bzr uses."
 msgstr ""
 
-#: bzrlib/builtins.py:3021
+#: bzrlib/builtins.py:3076
 msgid "ignore requires at least one NAME_PATTERN or --default-rules."
 msgstr ""
 
-#: bzrlib/builtins.py:3032
+#: bzrlib/builtins.py:3087
 #, python-format
 msgid "Invalid ignore pattern found. %s"
 msgid_plural "Invalid ignore patterns found. %s"
 msgstr[0] ""
 msgstr[1] ""
 
-#: bzrlib/builtins.py:3041
+#: bzrlib/builtins.py:3096
 msgid "NAME_PATTERN should not be an absolute path"
 msgstr ""
 
-#: bzrlib/builtins.py:3054
+#: bzrlib/builtins.py:3109
 #, python-format
 msgid ""
 "Warning: the following files are version controlled and match your ignore "
@@ -1971,62 +2015,62 @@
 "them.\n"
 msgstr ""
 
-#: bzrlib/builtins.py:3061
+#: bzrlib/builtins.py:3116
 msgid "List ignored files and the patterns that matched them."
 msgstr ""
 
-#: bzrlib/builtins.py:3063
+#: bzrlib/builtins.py:3118
 msgid ""
 "List all the ignored files and the ignore pattern that caused the file to\n"
 "be ignored."
 msgstr ""
 
-#: bzrlib/builtins.py:3066
+#: bzrlib/builtins.py:3121
 msgid "Alternatively, to list just the files::"
 msgstr ""
 
-#: bzrlib/builtins.py:3068
+#: bzrlib/builtins.py:3123
 msgid "    bzr ls --ignored"
 msgstr ""
 
-#: bzrlib/builtins.py:3102
+#: bzrlib/builtins.py:3157
 #, python-format
 msgid "not a valid revision-number: %r"
 msgstr ""
 
-#: bzrlib/builtins.py:3109
+#: bzrlib/builtins.py:3164
 msgid "Export current or past revision to a destination directory or archive."
 msgstr ""
 
-#: bzrlib/builtins.py:3111
+#: bzrlib/builtins.py:3166
 msgid "If no revision is specified this exports the last committed revision."
 msgstr ""
 
-#: bzrlib/builtins.py:3113
+#: bzrlib/builtins.py:3168
 msgid ""
 "Format may be an \"exporter\" name, such as tar, tgz, tbz2.  If none is\n"
 "given, try to find the format with the extension. If no extension\n"
 "is found exports to a directory (equivalent to --format=dir)."
 msgstr ""
 
-#: bzrlib/builtins.py:3117
+#: bzrlib/builtins.py:3172
 msgid ""
 "If root is supplied, it will be used as the root directory inside\n"
 "container formats (tar, zip, etc). If it is not supplied it will default\n"
 "to the exported filename. The root option has no effect for 'dir' format."
 msgstr ""
 
-#: bzrlib/builtins.py:3121
+#: bzrlib/builtins.py:3176
 msgid ""
 "If branch is omitted then the branch containing the current working\n"
 "directory will be used."
 msgstr ""
 
-#: bzrlib/builtins.py:3124
+#: bzrlib/builtins.py:3179
 msgid "Note: Export of tree with non-ASCII filenames to zip is not supported."
 msgstr ""
 
-#: bzrlib/builtins.py:3126
+#: bzrlib/builtins.py:3181
 msgid ""
 "  =================       =========================\n"
 "  Supported formats       Autodetected by extension\n"
@@ -2040,78 +2084,78 @@
 msgstr ""
 
 # help of 'format' option of 'export' command
-#: bzrlib/builtins.py:3140
+#: bzrlib/builtins.py:3195
 msgid "Type of file to export to."
 msgstr ""
 
 # help of 'filters' option of 'export' command
-#: bzrlib/builtins.py:3143
+#: bzrlib/builtins.py:3198
 msgid "Apply content filters to export the convenient form."
 msgstr ""
 
 # help of 'root' option of 'export' command
-#: bzrlib/builtins.py:3147
+#: bzrlib/builtins.py:3202
 msgid "Name of the root directory inside the exported file."
 msgstr ""
 
 # help of 'per-file-timestamps' option of 'export' command
-#: bzrlib/builtins.py:3149
+#: bzrlib/builtins.py:3204
 msgid ""
 "Set modification time of files to that of the last revision in which it was "
 "changed."
 msgstr ""
 
 # help of 'uncommitted' option of 'export' command
-#: bzrlib/builtins.py:3152
+#: bzrlib/builtins.py:3207
 msgid "Export the working tree contents rather than that of the last revision."
 msgstr ""
 
-#: bzrlib/builtins.py:3171
+#: bzrlib/builtins.py:3226
 msgid "--uncommitted requires a working tree"
 msgstr ""
 
-#: bzrlib/builtins.py:3180
+#: bzrlib/builtins.py:3235
 #, python-format
 msgid "Unsupported export format: %s"
 msgstr ""
 
-#: bzrlib/builtins.py:3184
+#: bzrlib/builtins.py:3239
 msgid "Write the contents of a file as of a given revision to standard output."
 msgstr ""
 
-#: bzrlib/builtins.py:3186
+#: bzrlib/builtins.py:3241
 msgid "If no revision is nominated, the last revision is used."
 msgstr ""
 
-#: bzrlib/builtins.py:3188
+#: bzrlib/builtins.py:3243
 msgid ""
 "Note: Take care to redirect standard output when using this command on a\n"
 "binary file."
 msgstr ""
 
 # help of 'name-from-revision' option of 'cat' command
-#: bzrlib/builtins.py:3194
+#: bzrlib/builtins.py:3249
 msgid "The path name in the old tree."
 msgstr ""
 
 # help of 'filters' option of 'cat' command
-#: bzrlib/builtins.py:3195
+#: bzrlib/builtins.py:3250
 msgid "Apply content filters to display the convenience form."
 msgstr ""
 
-#: bzrlib/builtins.py:3206
+#: bzrlib/builtins.py:3261
 msgid "bzr cat --revision takes exactly one revision specifier"
 msgstr ""
 
-#: bzrlib/builtins.py:3231 bzrlib/builtins.py:3243
+#: bzrlib/builtins.py:3286 bzrlib/builtins.py:3298
 msgid "{0!r} is not present in revision {1}"
 msgstr ""
 
-#: bzrlib/builtins.py:3266
+#: bzrlib/builtins.py:3321
 msgid "Commit changes into a new revision."
 msgstr ""
 
-#: bzrlib/builtins.py:3268
+#: bzrlib/builtins.py:3323
 msgid ""
 "An explanatory message needs to be given for each commit. This is\n"
 "often done by using the --message option (getting the message from the\n"
@@ -2121,44 +2165,44 @@
 "boilerplate text loaded into the editor, use the --show-diff option."
 msgstr ""
 
-#: bzrlib/builtins.py:3275
+#: bzrlib/builtins.py:3330
 msgid ""
 "By default, the entire tree is committed and the person doing the\n"
 "commit is assumed to be the author. These defaults can be overridden\n"
 "as explained below."
 msgstr ""
 
-#: bzrlib/builtins.py:3279
+#: bzrlib/builtins.py:3334
 msgid ":Selective commits:"
 msgstr ""
 
-#: bzrlib/builtins.py:3281
+#: bzrlib/builtins.py:3336
 msgid ""
 "  If selected files are specified, only changes to those files are\n"
 "  committed.  If a directory is specified then the directory and\n"
 "  everything within it is committed."
 msgstr ""
 
-#: bzrlib/builtins.py:3285
+#: bzrlib/builtins.py:3340
 msgid ""
 "  When excludes are given, they take precedence over selected files.\n"
 "  For example, to commit only changes within foo, but not changes\n"
 "  within foo/bar::"
 msgstr ""
 
-#: bzrlib/builtins.py:3289
+#: bzrlib/builtins.py:3344
 msgid "    bzr commit foo -x foo/bar"
 msgstr ""
 
-#: bzrlib/builtins.py:3291
+#: bzrlib/builtins.py:3346
 msgid "  A selective commit after a merge is not yet supported."
 msgstr ""
 
-#: bzrlib/builtins.py:3293
+#: bzrlib/builtins.py:3348
 msgid ":Custom authors:"
 msgstr ""
 
-#: bzrlib/builtins.py:3295
+#: bzrlib/builtins.py:3350
 msgid ""
 "  If the author of the change is not the same person as the committer,\n"
 "  you can specify the author's name using the --author option. The\n"
@@ -2168,11 +2212,11 @@
 "  author."
 msgstr ""
 
-#: bzrlib/builtins.py:3302
+#: bzrlib/builtins.py:3357
 msgid ":Checks:"
 msgstr ""
 
-#: bzrlib/builtins.py:3304
+#: bzrlib/builtins.py:3359
 msgid ""
 "  A common mistake is to forget to add a new file or directory before\n"
 "  running the commit command. The --strict option checks for unknown\n"
@@ -2181,18 +2225,18 @@
 "  for details."
 msgstr ""
 
-#: bzrlib/builtins.py:3310
+#: bzrlib/builtins.py:3365
 msgid ":Things to note:"
 msgstr ""
 
-#: bzrlib/builtins.py:3312
+#: bzrlib/builtins.py:3367
 msgid ""
 "  If you accidentially commit the wrong changes or make a spelling\n"
 "  mistake in the commit message say, you can use the uncommit command\n"
 "  to undo it. See ``bzr help uncommit`` for details."
 msgstr ""
 
-#: bzrlib/builtins.py:3316
+#: bzrlib/builtins.py:3371
 msgid ""
 "  Hooks can also be configured to run after a commit. This allows you\n"
 "  to trigger updates to external systems like bug trackers. The --fixes\n"
@@ -2201,69 +2245,69 @@
 msgstr ""
 
 # help of 'exclude' option of 'commit' command
-#: bzrlib/builtins.py:3326
+#: bzrlib/builtins.py:3381
 msgid "Do not consider changes made to a given path."
 msgstr ""
 
 # help of 'message' option of 'commit' command
-#: bzrlib/builtins.py:3329
+#: bzrlib/builtins.py:3384
 msgid "Description of the new revision."
 msgstr ""
 
 # help of 'unchanged' option of 'commit' command
-#: bzrlib/builtins.py:3332
+#: bzrlib/builtins.py:3387
 msgid "Commit even if nothing has changed."
 msgstr ""
 
 # help of 'file' option of 'commit' command
-#: bzrlib/builtins.py:3336
+#: bzrlib/builtins.py:3391
 msgid "Take commit message from this file."
 msgstr ""
 
 # help of 'strict' option of 'commit' command
-#: bzrlib/builtins.py:3338
+#: bzrlib/builtins.py:3393
 msgid "Refuse to commit if there are unknown files in the working tree."
 msgstr ""
 
 # help of 'commit-time' option of 'commit' command
-#: bzrlib/builtins.py:3341
+#: bzrlib/builtins.py:3396
 msgid ""
 "Manually set a commit time using commit date format, e.g. '2009-10-10 "
 "08:00:00 +0100'."
 msgstr ""
 
 # help of 'fixes' option of 'commit' command
-#: bzrlib/builtins.py:3344
+#: bzrlib/builtins.py:3399
 msgid "Mark a bug as being fixed by this revision (see \"bzr help bugs\")."
 msgstr ""
 
 # help of 'author' option of 'commit' command
-#: bzrlib/builtins.py:3347
+#: bzrlib/builtins.py:3402
 msgid "Set the author's name, if it's different from the committer."
 msgstr ""
 
 # help of 'local' option of 'commit' command
-#: bzrlib/builtins.py:3350
+#: bzrlib/builtins.py:3405
 msgid ""
 "Perform a local commit in a bound branch.  Local commits are not pushed to "
 "the master branch until a normal commit is performed."
 msgstr ""
 
 # help of 'show-diff' option of 'commit' command
-#: bzrlib/builtins.py:3356
+#: bzrlib/builtins.py:3411
 msgid ""
 "When no message is supplied, show the diff along with the status summary in "
 "the message editor."
 msgstr ""
 
 # help of 'lossy' option of 'commit' command
-#: bzrlib/builtins.py:3359
+#: bzrlib/builtins.py:3414
 msgid ""
 "When committing to a foreign version control system do not push data that "
 "can not be natively represented."
 msgstr ""
 
-#: bzrlib/builtins.py:3377
+#: bzrlib/builtins.py:3432
 #, python-format
 msgid ""
 "No tracker specified for bug %s. Use the form 'tracker:id' or specify a "
@@ -2271,7 +2315,7 @@
 "See \"bzr help bugs\" for more information on this feature. Commit refused."
 msgstr ""
 
-#: bzrlib/builtins.py:3386
+#: bzrlib/builtins.py:3441
 #, python-format
 msgid ""
 "Invalid bug %s. Must be in the form of 'tracker:id'. See \"bzr help bugs\" "
@@ -2279,91 +2323,91 @@
 "Commit refused."
 msgstr ""
 
-#: bzrlib/builtins.py:3395
+#: bzrlib/builtins.py:3450
 #, python-format
 msgid "Unrecognized bug %s. Commit refused."
 msgstr ""
 
-#: bzrlib/builtins.py:3398
+#: bzrlib/builtins.py:3453
 #, python-format
 msgid ""
 "%s\n"
 "Commit refused."
 msgstr ""
 
-#: bzrlib/builtins.py:3422
+#: bzrlib/builtins.py:3477
 msgid "Could not parse --commit-time: "
 msgstr ""
 
-#: bzrlib/builtins.py:3462
+#: bzrlib/builtins.py:3517
 msgid "please specify either --message or --file"
 msgstr ""
 
-#: bzrlib/builtins.py:3491
+#: bzrlib/builtins.py:3546
 msgid "please specify a commit message with either --message or --file"
 msgstr ""
 
-#: bzrlib/builtins.py:3494
+#: bzrlib/builtins.py:3549
 msgid ""
 "Empty commit message specified. Please specify a commit message with either "
 "--message or --file or leave a blank message with --message \"\"."
 msgstr ""
 
-#: bzrlib/builtins.py:3514
+#: bzrlib/builtins.py:3569
 msgid ""
 "No changes to commit. Please 'bzr add' the files you want to commit, or use "
 "--unchanged to force an empty commit."
 msgstr ""
 
-#: bzrlib/builtins.py:3518
+#: bzrlib/builtins.py:3573
 msgid ""
 "Conflicts detected in working tree.  Use \"bzr conflicts\" to list, \"bzr "
 "resolve FILE\" to resolve."
 msgstr ""
 
-#: bzrlib/builtins.py:3522
+#: bzrlib/builtins.py:3577
 msgid "Commit refused because there are unknown files in the working tree."
 msgstr ""
 
-#: bzrlib/builtins.py:3525
+#: bzrlib/builtins.py:3580
 msgid ""
 "\n"
 "To commit to master branch, run update and then commit.\n"
 "You can also pass --local to commit to continue working disconnected."
 msgstr ""
 
-#: bzrlib/builtins.py:3533
+#: bzrlib/builtins.py:3588
 msgid ""
 "Validate working tree structure, branch consistency and repository history."
 msgstr ""
 
-#: bzrlib/builtins.py:3535
+#: bzrlib/builtins.py:3590
 msgid ""
 "This command checks various invariants about branch and repository storage\n"
 "to detect data corruption or bzr bugs."
 msgstr ""
 
-#: bzrlib/builtins.py:3538
+#: bzrlib/builtins.py:3593
 msgid ""
 "The working tree and branch checks will only give output if a problem is\n"
 "detected. The output fields of the repository check are:"
 msgstr ""
 
-#: bzrlib/builtins.py:3541
+#: bzrlib/builtins.py:3596
 msgid ""
 "revisions\n"
 "    This is just the number of revisions checked.  It doesn't\n"
 "    indicate a problem."
 msgstr ""
 
-#: bzrlib/builtins.py:3545
+#: bzrlib/builtins.py:3600
 msgid ""
 "versionedfiles\n"
 "    This is just the number of versionedfiles checked.  It\n"
 "    doesn't indicate a problem."
 msgstr ""
 
-#: bzrlib/builtins.py:3549
+#: bzrlib/builtins.py:3604
 msgid ""
 "unreferenced ancestors\n"
 "    Texts that are ancestors of other texts, but\n"
@@ -2371,14 +2415,14 @@
 "    subtle problem that Bazaar can work around."
 msgstr ""
 
-#: bzrlib/builtins.py:3554
+#: bzrlib/builtins.py:3609
 msgid ""
 "unique file texts\n"
 "    This is the total number of unique file contents\n"
 "    seen in the checked revisions.  It does not indicate a problem."
 msgstr ""
 
-#: bzrlib/builtins.py:3558
+#: bzrlib/builtins.py:3613
 msgid ""
 "repeated file texts\n"
 "    This is the total number of repeated texts seen\n"
@@ -2387,61 +2431,57 @@
 "    indicate a problem."
 msgstr ""
 
-#: bzrlib/builtins.py:3564
+#: bzrlib/builtins.py:3619
 msgid ""
 "If no restrictions are specified, all Bazaar data that is found at the "
 "given\n"
 "location will be checked."
 msgstr ""
 
-#: bzrlib/builtins.py:3567
-msgid ":Examples:"
-msgstr ""
-
-#: bzrlib/builtins.py:3569
+#: bzrlib/builtins.py:3624
 msgid "    Check the tree and branch at 'foo'::"
 msgstr ""
 
-#: bzrlib/builtins.py:3571
+#: bzrlib/builtins.py:3626
 msgid "        bzr check --tree --branch foo"
 msgstr ""
 
-#: bzrlib/builtins.py:3573
+#: bzrlib/builtins.py:3628
 msgid "    Check only the repository at 'bar'::"
 msgstr ""
 
-#: bzrlib/builtins.py:3575
+#: bzrlib/builtins.py:3630
 msgid "        bzr check --repo bar"
 msgstr ""
 
-#: bzrlib/builtins.py:3577
+#: bzrlib/builtins.py:3632
 msgid "    Check everything at 'baz'::"
 msgstr ""
 
-#: bzrlib/builtins.py:3579
+#: bzrlib/builtins.py:3634
 msgid "        bzr check baz"
 msgstr ""
 
 # help of 'branch' option of 'check' command
-#: bzrlib/builtins.py:3585
+#: bzrlib/builtins.py:3640
 msgid "Check the branch related to the current directory."
 msgstr ""
 
 # help of 'repo' option of 'check' command
-#: bzrlib/builtins.py:3587
+#: bzrlib/builtins.py:3642
 msgid "Check the repository related to the current directory."
 msgstr ""
 
 # help of 'tree' option of 'check' command
-#: bzrlib/builtins.py:3589
+#: bzrlib/builtins.py:3644
 msgid "Check the working tree related to the current directory."
 msgstr ""
 
-#: bzrlib/builtins.py:3603
+#: bzrlib/builtins.py:3658
 msgid "Upgrade a repository, branch or working tree to a newer format."
 msgstr ""
 
-#: bzrlib/builtins.py:3605
+#: bzrlib/builtins.py:3660
 msgid ""
 "When the default format has changed after a major new release of\n"
 "Bazaar, you may be informed during certain operations that you\n"
@@ -2450,7 +2490,7 @@
 "with older repositories or with older versions of Bazaar."
 msgstr ""
 
-#: bzrlib/builtins.py:3611
+#: bzrlib/builtins.py:3666
 msgid ""
 "If you wish to upgrade to a particular format rather than the\n"
 "current default, that can be specified using the --format option.\n"
@@ -2460,7 +2500,7 @@
 "2.x default) so downgrading is not always possible."
 msgstr ""
 
-#: bzrlib/builtins.py:3618
+#: bzrlib/builtins.py:3673
 msgid ""
 "A backup.bzr.~#~ directory is created at the start of the conversion\n"
 "process (where # is a number). By default, this is left there on\n"
@@ -2471,7 +2511,7 @@
 "afterwards."
 msgstr ""
 
-#: bzrlib/builtins.py:3626
+#: bzrlib/builtins.py:3681
 msgid ""
 "If the location given is a shared repository, dependent branches\n"
 "are also converted provided the repository converts successfully.\n"
@@ -2479,163 +2519,165 @@
 "tried."
 msgstr ""
 
-#: bzrlib/builtins.py:3631
+#: bzrlib/builtins.py:3686
 msgid ""
 "For more information on upgrades, see the Bazaar Upgrade Guide,\n"
 "http://doc.bazaar.canonical.com/latest/en/upgrade-guide/."
 msgstr ""
 
 # help of 'format' option of 'upgrade' command
-#: bzrlib/builtins.py:3639
+#: bzrlib/builtins.py:3694
 msgid "Upgrade to a specific format.  See \"bzr help formats\" for details."
 msgstr ""
 
 # title of 'format' option of 'init' command
-#: bzrlib/builtins.py:3643
+# title of 'format' option of 'upgrade' command
+#: bzrlib/builtins.py:3698
 msgid "Branch format"
 msgstr ""
 
 # help of 'clean' option of 'upgrade' command
-#: bzrlib/builtins.py:3645
+#: bzrlib/builtins.py:3700
 msgid "Remove the backup.bzr directory if successful."
 msgstr ""
 
 # help of 'dry-run' option of 'add' command
-#: bzrlib/builtins.py:3647
+# help of 'dry-run' option of 'upgrade' command
+#: bzrlib/builtins.py:3702
 msgid "Show what would be done, but don't actually do anything."
 msgstr ""
 
-#: bzrlib/builtins.py:3662
+#: bzrlib/builtins.py:3717
 msgid "Show or set bzr user id."
 msgstr ""
 
-#: bzrlib/builtins.py:3664
+#: bzrlib/builtins.py:3719
 msgid ""
 ":Examples:\n"
 "    Show the email of the current user::"
 msgstr ""
 
-#: bzrlib/builtins.py:3667
+#: bzrlib/builtins.py:3722
 msgid "        bzr whoami --email"
 msgstr ""
 
-#: bzrlib/builtins.py:3669
+#: bzrlib/builtins.py:3724
 msgid "    Set the current user::"
 msgstr ""
 
-#: bzrlib/builtins.py:3671
+#: bzrlib/builtins.py:3726
 msgid "        bzr whoami \"Frank Chu <fchu@example.com>\""
 msgstr ""
 
 # help of 'email' option of 'whoami' command
-#: bzrlib/builtins.py:3675
+#: bzrlib/builtins.py:3730
 msgid "Display email address only."
 msgstr ""
 
 # help of 'branch' option of 'whoami' command
-#: bzrlib/builtins.py:3677
+#: bzrlib/builtins.py:3732
 msgid "Set identity for the current branch instead of globally."
 msgstr ""
 
-#: bzrlib/builtins.py:3701
+#: bzrlib/builtins.py:3758
 msgid "--email can only be used to display existing identity"
 msgstr ""
 
-#: bzrlib/builtins.py:3723
+#: bzrlib/builtins.py:3780
 msgid "Print or set the branch nickname."
 msgstr ""
 
-#: bzrlib/builtins.py:3725
+#: bzrlib/builtins.py:3782
 msgid ""
 "If unset, the tree root directory name is used as the nickname.\n"
 "To print the current nickname, execute with no argument."
 msgstr ""
 
-#: bzrlib/builtins.py:3728
+#: bzrlib/builtins.py:3785
 msgid ""
 "Bound branches use the nickname of its master branch unless it is set\n"
 "locally."
 msgstr ""
 
-#: bzrlib/builtins.py:3748
+#: bzrlib/builtins.py:3805
 msgid "Set/unset and display aliases."
 msgstr ""
 
-#: bzrlib/builtins.py:3750
+#: bzrlib/builtins.py:3807
 msgid ""
 ":Examples:\n"
 "    Show the current aliases::"
 msgstr ""
 
-#: bzrlib/builtins.py:3753
+#: bzrlib/builtins.py:3810
 msgid "        bzr alias"
 msgstr ""
 
-#: bzrlib/builtins.py:3755
+#: bzrlib/builtins.py:3812
 msgid "    Show the alias specified for 'll'::"
 msgstr ""
 
-#: bzrlib/builtins.py:3757
+#: bzrlib/builtins.py:3814
 msgid "        bzr alias ll"
 msgstr ""
 
-#: bzrlib/builtins.py:3759
+#: bzrlib/builtins.py:3816
 msgid "    Set an alias for 'll'::"
 msgstr ""
 
-#: bzrlib/builtins.py:3761
+#: bzrlib/builtins.py:3818
 msgid "        bzr alias ll=\"log --line -r-10..-1\""
 msgstr ""
 
-#: bzrlib/builtins.py:3763
+#: bzrlib/builtins.py:3820
 msgid "    To remove an alias for 'll'::"
 msgstr ""
 
-#: bzrlib/builtins.py:3765
+#: bzrlib/builtins.py:3822
 msgid "        bzr alias --remove ll"
 msgstr ""
 
 # help of 'remove' option of 'alias' command
-#: bzrlib/builtins.py:3770
+#: bzrlib/builtins.py:3827
 msgid "Remove the alias."
 msgstr ""
 
-#: bzrlib/builtins.py:3788
+#: bzrlib/builtins.py:3845
 msgid "bzr alias --remove expects an alias to remove."
 msgstr ""
 
-#: bzrlib/builtins.py:3960
+#: bzrlib/builtins.py:4026
 msgid "subunit not available. subunit needs to be installed to use --subunit."
 msgstr ""
 
-#: bzrlib/builtins.py:3977
+#: bzrlib/builtins.py:4043
 msgid ""
 "--benchmark is no longer supported from bzr 2.2; use bzr-usertest instead"
 msgstr ""
 
-#: bzrlib/builtins.py:4024
+#: bzrlib/builtins.py:4090
 msgid "Show version of bzr."
 msgstr ""
 
 # help of 'short' option of 'version' command
-#: bzrlib/builtins.py:4028
+#: bzrlib/builtins.py:4094
 msgid "Print just the version number."
 msgstr ""
 
-#: bzrlib/builtins.py:4047
+#: bzrlib/builtins.py:4113
 msgid "It sure does!\n"
 msgstr ""
 
-#: bzrlib/builtins.py:4071
+#: bzrlib/builtins.py:4137
 #, python-format
 msgid "merge base is revision %s\n"
 msgstr ""
 
-#: bzrlib/builtins.py:4075
+#: bzrlib/builtins.py:4141
 msgid "Perform a three-way merge."
 msgstr ""
 
-#: bzrlib/builtins.py:4077
+#: bzrlib/builtins.py:4143
 msgid ""
 "The source of the merge can be specified either in the form of a branch,\n"
 "or in the form of a path to a file containing a merge directive generated\n"
@@ -2646,20 +2688,20 @@
 "the current working tree."
 msgstr ""
 
-#: bzrlib/builtins.py:4085
+#: bzrlib/builtins.py:4151
 msgid ""
 "When merging from a branch, by default bzr will try to merge in all new\n"
 "work from the other branch, automatically determining an appropriate base\n"
 "revision.  If this fails, you may need to give an explicit base."
 msgstr ""
 
-#: bzrlib/builtins.py:4089
+#: bzrlib/builtins.py:4155
 msgid ""
 "To pick a different ending revision, pass \"--revision OTHER\".  bzr will\n"
 "try to merge in all new work up to and including revision OTHER."
 msgstr ""
 
-#: bzrlib/builtins.py:4092
+#: bzrlib/builtins.py:4158
 msgid ""
 "If you specify two values, \"--revision BASE..OTHER\", only revisions BASE\n"
 "through OTHER, excluding BASE but including OTHER, will be merged.  If this\n"
@@ -2670,15 +2712,23 @@
 "changes from the other branch is not stored in the commit."
 msgstr ""
 
-#: bzrlib/builtins.py:4100
+#: bzrlib/builtins.py:4166
 msgid "Revision numbers are always relative to the source branch."
 msgstr ""
 
-#: bzrlib/builtins.py:4107
+#: bzrlib/builtins.py:4168 bzrlib/conflicts.py:52 bzrlib/conflicts.py:106
+msgid ""
+"Merge will do its best to combine the changes in two branches, but there\n"
+"are some kinds of problems only a human can fix.  When it encounters those,\n"
+"it will mark a conflict.  A conflict means that you need to fix something,\n"
+"before you should commit."
+msgstr ""
+
+#: bzrlib/builtins.py:4173
 msgid "Use bzr resolve when you have fixed a problem.  See also bzr conflicts."
 msgstr ""
 
-#: bzrlib/builtins.py:4109
+#: bzrlib/builtins.py:4175
 msgid ""
 "If there is no default branch set, the first merge will set it (use\n"
 "--no-remember to avoid setting it). After that, you can omit the branch\n"
@@ -2686,14 +2736,14 @@
 "only be saved if the remote location can be accessed."
 msgstr ""
 
-#: bzrlib/builtins.py:4114
+#: bzrlib/builtins.py:4180
 msgid ""
 "The results of the merge are placed into the destination working\n"
 "directory, where they can be reviewed (with bzr diff), tested, and then\n"
 "committed to record the result of the merge."
 msgstr ""
 
-#: bzrlib/builtins.py:4118
+#: bzrlib/builtins.py:4184
 msgid ""
 "merge refuses to run if there are any uncommitted changes, unless\n"
 "--force is given.  If --force is given, then the changes from the source \n"
@@ -2702,60 +2752,60 @@
 "merge revision which has more than two parents."
 msgstr ""
 
-#: bzrlib/builtins.py:4124
+#: bzrlib/builtins.py:4190
 msgid ""
 "If one would like to merge changes from the working tree of the other\n"
 "branch without merging any committed revisions, the --uncommitted option\n"
 "can be given."
 msgstr ""
 
-#: bzrlib/builtins.py:4128
+#: bzrlib/builtins.py:4194
 msgid ""
 "To select only some changes to merge, use \"merge -i\", which will prompt\n"
 "you to apply each diff hunk and file change, similar to \"shelve\"."
 msgstr ""
 
-#: bzrlib/builtins.py:4131
+#: bzrlib/builtins.py:4197
 msgid ""
 ":Examples:\n"
 "    To merge all new revisions from bzr.dev::"
 msgstr ""
 
-#: bzrlib/builtins.py:4134
+#: bzrlib/builtins.py:4200
 msgid "        bzr merge ../bzr.dev"
 msgstr ""
 
-#: bzrlib/builtins.py:4136
+#: bzrlib/builtins.py:4202
 msgid "    To merge changes up to and including revision 82 from bzr.dev::"
 msgstr ""
 
-#: bzrlib/builtins.py:4138
+#: bzrlib/builtins.py:4204
 msgid "        bzr merge -r 82 ../bzr.dev"
 msgstr ""
 
-#: bzrlib/builtins.py:4140
+#: bzrlib/builtins.py:4206
 msgid "    To merge the changes introduced by 82, without previous changes::"
 msgstr ""
 
-#: bzrlib/builtins.py:4142
+#: bzrlib/builtins.py:4208
 msgid "        bzr merge -r 81..82 ../bzr.dev"
 msgstr ""
 
-#: bzrlib/builtins.py:4144
+#: bzrlib/builtins.py:4210
 msgid "    To apply a merge directive contained in /tmp/merge::"
 msgstr ""
 
-#: bzrlib/builtins.py:4146
+#: bzrlib/builtins.py:4212
 msgid "        bzr merge /tmp/merge"
 msgstr ""
 
-#: bzrlib/builtins.py:4148
+#: bzrlib/builtins.py:4214
 msgid ""
 "    To create a merge revision with three parents from two branches\n"
 "    feature1a and feature1b:"
 msgstr ""
 
-#: bzrlib/builtins.py:4151
+#: bzrlib/builtins.py:4217
 msgid ""
 "        bzr merge ../feature1a\n"
 "        bzr merge ../feature1b --force\n"
@@ -2763,18 +2813,18 @@
 msgstr ""
 
 # help of 'force' option of 'merge' command
-#: bzrlib/builtins.py:4163
+#: bzrlib/builtins.py:4229
 msgid "Merge even if the destination tree has uncommitted changes."
 msgstr ""
 
 # help of 'uncommitted' option of 'merge' command
-#: bzrlib/builtins.py:4169
+#: bzrlib/builtins.py:4235
 msgid ""
 "Apply uncommitted changes from a working copy, instead of branch changes."
 msgstr ""
 
 # help of 'pull' option of 'merge' command
-#: bzrlib/builtins.py:4171
+#: bzrlib/builtins.py:4237
 msgid ""
 "If the destination is already completely merged into the source, pull from "
 "the source rather than merging.  When this happens, you do not need to "
@@ -2782,135 +2832,138 @@
 msgstr ""
 
 # help of 'directory' option of 'merge' command
-#: bzrlib/builtins.py:4176
+#: bzrlib/builtins.py:4242
 msgid ""
 "Branch to merge into, rather than the one containing the working directory."
 msgstr ""
 
 # help of 'preview' option of 'merge' command
-#: bzrlib/builtins.py:4178
+#: bzrlib/builtins.py:4244
 msgid "Instead of merging, show a diff of the merge."
 msgstr ""
 
 # help of 'interactive' option of 'merge' command
-#: bzrlib/builtins.py:4180
+#: bzrlib/builtins.py:4246
 msgid "Select changes interactively."
 msgstr ""
 
-#: bzrlib/builtins.py:4202
+#: bzrlib/builtins.py:4268
 msgid ""
 "Merging into empty branches not currently supported, https://bugs.launchpad."
 "net/bzr/+bug/308562"
 msgstr ""
 
-#: bzrlib/builtins.py:4229
+#: bzrlib/builtins.py:4295
 msgid "Cannot use --uncommitted with bundles or merge directives."
 msgstr ""
 
-#: bzrlib/builtins.py:4240
+#: bzrlib/builtins.py:4306
 msgid "Cannot use --uncommitted and --revision at the same time."
 msgstr ""
 
-#: bzrlib/builtins.py:4260
+#: bzrlib/builtins.py:4326
 msgid "merger: "
 msgstr ""
 
-#: bzrlib/builtins.py:4262 bzrlib/bundle/apply_bundle.py:68
+#: bzrlib/builtins.py:4328 bzrlib/bundle/apply_bundle.py:71
 msgid "Nothing to do."
 msgstr ""
 
-#: bzrlib/builtins.py:4266
+#: bzrlib/builtins.py:4332
 msgid "Cannot pull individual files"
 msgstr ""
 
-#: bzrlib/builtins.py:4274
+#: bzrlib/builtins.py:4340
 msgid "This branch has no commits. (perhaps you would prefer 'bzr pull')"
 msgstr ""
 
-#: bzrlib/builtins.py:4332
+#: bzrlib/builtins.py:4398
 #, python-format
 msgid "Show-base is not supported for this merge type. %s"
 msgstr ""
 
-#: bzrlib/builtins.py:4341
+#: bzrlib/builtins.py:4407
 #, python-format
 msgid "Conflict reduction is not supported for merge type %s."
 msgstr ""
 
-#: bzrlib/builtins.py:4345
+#: bzrlib/builtins.py:4411
 msgid "Cannot do conflict reduction and show base."
 msgstr ""
 
-#: bzrlib/builtins.py:4456
+#: bzrlib/builtins.py:4522
 msgid "No location specified or remembered"
 msgstr ""
 
-#: bzrlib/builtins.py:4458
+#: bzrlib/builtins.py:4524
 msgid "{0} remembered {1} location {2}"
 msgstr ""
 
-#: bzrlib/builtins.py:4464
+#: bzrlib/builtins.py:4530
 msgid "Redo a merge."
 msgstr ""
 
-#: bzrlib/builtins.py:4466
+#: bzrlib/builtins.py:4532
 msgid ""
 "Use this if you want to try a different merge technique while resolving\n"
 "conflicts.  Some merge techniques are better than others, and remerge\n"
 "lets you try different ones on different files."
 msgstr ""
 
-#: bzrlib/builtins.py:4470
+#: bzrlib/builtins.py:4536
 msgid ""
 "The options for remerge have the same meaning and defaults as the ones for\n"
 "merge.  The difference is that remerge can (only) be run when there is a\n"
 "pending merge, and it lets you specify particular files."
 msgstr ""
 
-#: bzrlib/builtins.py:4474
+#: bzrlib/builtins.py:4540
 msgid ""
 ":Examples:\n"
 "    Re-do the merge of all conflicted files, and show the base text in\n"
 "    conflict regions, in addition to the usual THIS and OTHER texts::"
 msgstr ""
 
-#: bzrlib/builtins.py:4478
+#: bzrlib/builtins.py:4544
 msgid "        bzr remerge --show-base"
 msgstr ""
 
-#: bzrlib/builtins.py:4480
+#: bzrlib/builtins.py:4546
 msgid ""
 "    Re-do the merge of \"foobar\", using the weave merge algorithm, with\n"
 "    additional processing to reduce the size of conflict regions::"
 msgstr ""
 
-#: bzrlib/builtins.py:4483
+#: bzrlib/builtins.py:4549
 msgid "        bzr remerge --merge-type weave --reprocess foobar"
 msgstr ""
 
 # help of 'show-base' option of 'merge' command
-#: bzrlib/builtins.py:4490
+# help of 'show-base' option of 'pull' command
+# help of 'show-base' option of 'remerge' command
+# help of 'show-base' option of 'update' command
+#: bzrlib/builtins.py:4556
 msgid "Show base revision text in conflicts."
 msgstr ""
 
-#: bzrlib/builtins.py:4502
+#: bzrlib/builtins.py:4568
 msgid ""
 "Sorry, remerge only works after normal merges.  Not cherrypicking or multi-"
 "merges."
 msgstr ""
 
-#: bzrlib/builtins.py:4558
+#: bzrlib/builtins.py:4624
 msgid "Revert files to a previous revision."
 msgstr ""
 
-#: bzrlib/builtins.py:4560
+#: bzrlib/builtins.py:4626
 msgid ""
 "Giving a list of files will revert only those files.  Otherwise, all files\n"
 "will be reverted.  If the revision is not specified with '--revision', the\n"
 "last committed revision is used."
 msgstr ""
 
-#: bzrlib/builtins.py:4564
+#: bzrlib/builtins.py:4630
 msgid ""
 "To remove only some changes, without reverting to a prior version, use\n"
 "merge instead.  For example, \"merge . -r -2..-3\" (don't forget the \".\")\n"
@@ -2919,14 +2972,14 @@
 "certain changes on a hunk-by-hunk basis, see the shelve command."
 msgstr ""
 
-#: bzrlib/builtins.py:4570
+#: bzrlib/builtins.py:4636
 msgid ""
 "By default, any files that have been manually changed will be backed up\n"
 "first.  (Files changed only by merge are not backed up.)  Backup files have\n"
 "'.~#~' appended to their name, where # is a number."
 msgstr ""
 
-#: bzrlib/builtins.py:4574
+#: bzrlib/builtins.py:4640
 msgid ""
 "When you provide files, you can use their current pathname or the pathname\n"
 "from the target revision.  So you can use revert to \"undelete\" a file by\n"
@@ -2934,7 +2987,7 @@
 "reverted."
 msgstr ""
 
-#: bzrlib/builtins.py:4579
+#: bzrlib/builtins.py:4645
 msgid ""
 "If you have newly added files since the target revision, they will be\n"
 "removed.  If the files to be removed have been changed, backups will be\n"
@@ -2942,7 +2995,7 @@
 "deleted."
 msgstr ""
 
-#: bzrlib/builtins.py:4584
+#: bzrlib/builtins.py:4650
 msgid ""
 "The working tree contains a list of revisions that have been merged but\n"
 "not yet committed. These revisions will be included as additional parents\n"
@@ -2954,7 +3007,7 @@
 "reverting any files."
 msgstr ""
 
-#: bzrlib/builtins.py:4593
+#: bzrlib/builtins.py:4659
 msgid ""
 "Using \"bzr revert --forget-merges\", it is possible to apply all of the\n"
 "changes from a branch in a single revision.  To do this, perform the merge\n"
@@ -2969,35 +3022,35 @@
 msgstr ""
 
 # help of 'no-backup' option of 'revert' command
-#: bzrlib/builtins.py:4607
+#: bzrlib/builtins.py:4673
 msgid "Do not save backups of reverted files."
 msgstr ""
 
 # help of 'forget-merges' option of 'revert' command
-#: bzrlib/builtins.py:4609
+#: bzrlib/builtins.py:4675
 msgid "Remove pending merge marker, without changing any files."
 msgstr ""
 
-#: bzrlib/builtins.py:4640
+#: bzrlib/builtins.py:4706
 msgid ""
 "Show help on a command or other topic.\n"
 "    "
 msgstr ""
 
 # help of 'long' option of 'help' command
-#: bzrlib/builtins.py:4645
+#: bzrlib/builtins.py:4711
 msgid "Show help on all commands."
 msgstr ""
 
-#: bzrlib/builtins.py:4674
+#: bzrlib/builtins.py:4740
 msgid "Show unmerged/unpulled revisions between two branches."
 msgstr ""
 
-#: bzrlib/builtins.py:4676
+#: bzrlib/builtins.py:4742
 msgid "OTHER_BRANCH may be local or remote."
 msgstr ""
 
-#: bzrlib/builtins.py:4678
+#: bzrlib/builtins.py:4744
 msgid ""
 "To filter on a range of revisions, you can use the command -r begin..end\n"
 "-r revision requests a specific revision, -r ..end or -r begin.. are\n"
@@ -3008,134 +3061,134 @@
 "    0 - no missing revisions"
 msgstr ""
 
-#: bzrlib/builtins.py:4688
+#: bzrlib/builtins.py:4754
 msgid ""
 "    Determine the missing revisions between this and the branch at the\n"
 "    remembered pull location::"
 msgstr ""
 
-#: bzrlib/builtins.py:4691
+#: bzrlib/builtins.py:4757
 msgid "        bzr missing"
 msgstr ""
 
-#: bzrlib/builtins.py:4693
+#: bzrlib/builtins.py:4759
 msgid "    Determine the missing revisions between this and another branch::"
 msgstr ""
 
-#: bzrlib/builtins.py:4695
+#: bzrlib/builtins.py:4761
 msgid "        bzr missing http://server/branch"
 msgstr ""
 
-#: bzrlib/builtins.py:4697
+#: bzrlib/builtins.py:4763
 msgid ""
 "    Determine the missing revisions up to a specific revision on the other\n"
 "    branch::"
 msgstr ""
 
-#: bzrlib/builtins.py:4700
+#: bzrlib/builtins.py:4766
 msgid "        bzr missing -r ..-10"
 msgstr ""
 
-#: bzrlib/builtins.py:4702
+#: bzrlib/builtins.py:4768
 msgid ""
 "    Determine the missing revisions up to a specific revision on this\n"
 "    branch::"
 msgstr ""
 
-#: bzrlib/builtins.py:4705
+#: bzrlib/builtins.py:4771
 msgid "        bzr missing --my-revision ..-10"
 msgstr ""
 
 # help of 'reverse' option of 'missing' command
-#: bzrlib/builtins.py:4712
+#: bzrlib/builtins.py:4778
 msgid "Reverse the order of revisions."
 msgstr ""
 
 # help of 'mine-only' option of 'missing' command
-#: bzrlib/builtins.py:4714
+#: bzrlib/builtins.py:4780
 msgid "Display changes in the local branch only."
 msgstr ""
 
 # help of 'this' option of 'missing' command
-#: bzrlib/builtins.py:4715
+#: bzrlib/builtins.py:4781
 msgid "Same as --mine-only."
 msgstr ""
 
 # help of 'theirs-only' option of 'missing' command
-#: bzrlib/builtins.py:4717
+#: bzrlib/builtins.py:4783
 msgid "Display changes in the remote branch only."
 msgstr ""
 
 # help of 'other' option of 'missing' command
-#: bzrlib/builtins.py:4718
+#: bzrlib/builtins.py:4784
 msgid "Same as --theirs-only."
 msgstr ""
 
 # help of 'revision' option of 'missing' command
-#: bzrlib/builtins.py:4723
+#: bzrlib/builtins.py:4789
 msgid ""
 "Filter on other branch revisions (inclusive). See \"help revisionspec\" for "
 "details."
 msgstr ""
 
 # help of 'my-revision' option of 'missing' command
-#: bzrlib/builtins.py:4727
+#: bzrlib/builtins.py:4793
 msgid ""
 "Filter on local branch revisions (inclusive). See \"help revisionspec\" for "
 "details."
 msgstr ""
 
 # help of 'include-merged' option of 'missing' command
-#: bzrlib/builtins.py:4730
+#: bzrlib/builtins.py:4796
 msgid "Show all revisions in addition to the mainline ones."
 msgstr ""
 
-#: bzrlib/builtins.py:4784
+#: bzrlib/builtins.py:4850
 msgid "No peer location known or specified."
 msgstr ""
 
-#: bzrlib/builtins.py:4788
+#: bzrlib/builtins.py:4854
 msgid "Using saved parent location: {0}\n"
 msgstr ""
 
-#: bzrlib/builtins.py:4821
+#: bzrlib/builtins.py:4887
 #, python-format
 msgid "You have %d extra revision:\n"
 msgid_plural "You have %d extra revisions:\n"
 msgstr[0] ""
 msgstr[1] ""
 
-#: bzrlib/builtins.py:4837
+#: bzrlib/builtins.py:4903
 #, python-format
 msgid "You are missing %d revision:\n"
 msgid_plural "You are missing %d revisions:\n"
 msgstr[0] ""
 msgstr[1] ""
 
-#: bzrlib/builtins.py:4849
+#: bzrlib/builtins.py:4915
 msgid "This branch has no new revisions.\n"
 msgstr ""
 
-#: bzrlib/builtins.py:4852
+#: bzrlib/builtins.py:4918
 msgid "Other branch has no new revisions.\n"
 msgstr ""
 
-#: bzrlib/builtins.py:4857
+#: bzrlib/builtins.py:4923
 msgid "Branches are up to date.\n"
 msgstr ""
 
-#: bzrlib/builtins.py:4868
+#: bzrlib/builtins.py:4934
 msgid "Compress the data within a repository."
 msgstr ""
 
-#: bzrlib/builtins.py:4870
+#: bzrlib/builtins.py:4936
 msgid ""
 "This operation compresses the data within a bazaar repository. As\n"
 "bazaar supports automatic packing of repository, this operation is\n"
 "normally not required to be done manually."
 msgstr ""
 
-#: bzrlib/builtins.py:4874
+#: bzrlib/builtins.py:4940
 msgid ""
 "During the pack operation, bazaar takes a backup of existing repository\n"
 "data, i.e. pack files. This backup is eventually removed by bazaar\n"
@@ -3144,7 +3197,7 @@
 "used."
 msgstr ""
 
-#: bzrlib/builtins.py:4880
+#: bzrlib/builtins.py:4946
 msgid ""
 "Warning: If you use --clean-obsolete-packs and your machine crashes\n"
 "during or immediately after repacking, you may be left with a state\n"
@@ -3153,25 +3206,25 @@
 msgstr ""
 
 # help of 'clean-obsolete-packs' option of 'pack' command
-#: bzrlib/builtins.py:4889
+#: bzrlib/builtins.py:4955
 msgid "Delete obsolete packs to save disk space."
 msgstr ""
 
-#: bzrlib/builtins.py:4903
+#: bzrlib/builtins.py:4969
 msgid "List the installed plugins."
 msgstr ""
 
-#: bzrlib/builtins.py:4905
+#: bzrlib/builtins.py:4971
 msgid ""
 "This command displays the list of installed plugins including\n"
 "version of plugin and a short description of each."
 msgstr ""
 
-#: bzrlib/builtins.py:4908
+#: bzrlib/builtins.py:4974
 msgid "--verbose shows the path where each plugin is located."
 msgstr ""
 
-#: bzrlib/builtins.py:4910
+#: bzrlib/builtins.py:4976
 msgid ""
 "A plugin is an external component for Bazaar that extends the\n"
 "revision control system, by adding or replacing code in Bazaar.\n"
@@ -3180,7 +3233,7 @@
 "customizing log output."
 msgstr ""
 
-#: bzrlib/builtins.py:4916
+#: bzrlib/builtins.py:4982
 msgid ""
 "See the Bazaar Plugin Guide <http://doc.bazaar.canonical.com/plugins/en/>\n"
 "for further information on plugins including where to find them and how to\n"
@@ -3188,122 +3241,122 @@
 "plugins using the Python programming language."
 msgstr ""
 
-#: bzrlib/builtins.py:4932
+#: bzrlib/builtins.py:4998
 msgid "Show testament (signing-form) of a revision."
 msgstr ""
 
 # help of 'long' option of 'testament' command
-#: bzrlib/builtins.py:4935
+#: bzrlib/builtins.py:5001
 msgid "Produce long-format testament."
 msgstr ""
 
 # help of 'strict' option of 'testament' command
-#: bzrlib/builtins.py:4937
+#: bzrlib/builtins.py:5003
 msgid "Produce a strict-format testament."
 msgstr ""
 
-#: bzrlib/builtins.py:4963
+#: bzrlib/builtins.py:5029
 msgid "Show the origin of each line in a file."
 msgstr ""
 
-#: bzrlib/builtins.py:4965
+#: bzrlib/builtins.py:5031
 msgid ""
 "This prints out the given file with an annotation on the left side\n"
 "indicating which revision, author and date introduced the change."
 msgstr ""
 
-#: bzrlib/builtins.py:4968
+#: bzrlib/builtins.py:5034
 msgid ""
 "If the origin is the same for a run of consecutive lines, it is\n"
 "shown only at the top, unless the --all option is given."
 msgstr ""
 
 # help of 'all' option of 'annotate' command
-#: bzrlib/builtins.py:4976
+#: bzrlib/builtins.py:5042
 msgid "Show annotations on all lines."
 msgstr ""
 
 # help of 'long' option of 'annotate' command
-#: bzrlib/builtins.py:4977
+#: bzrlib/builtins.py:5043
 msgid "Show commit date in annotations."
 msgstr ""
 
-#: bzrlib/builtins.py:5064
+#: bzrlib/builtins.py:5130
 msgid "Cannot sign a range of non-revision-history revisions"
 msgstr ""
 
-#: bzrlib/builtins.py:5076
+#: bzrlib/builtins.py:5142
 msgid "Please supply either one revision, or a range."
 msgstr ""
 
-#: bzrlib/builtins.py:5080
+#: bzrlib/builtins.py:5146
 msgid ""
 "Convert the current branch into a checkout of the supplied branch.\n"
 "If no branch is supplied, rebind to the last bound location."
 msgstr ""
 
-#: bzrlib/builtins.py:5083
+#: bzrlib/builtins.py:5149
 msgid ""
 "Once converted into a checkout, commits must succeed on the master branch\n"
 "before they will be applied to the local branch."
 msgstr ""
 
-#: bzrlib/builtins.py:5086
+#: bzrlib/builtins.py:5152
 msgid ""
 "Bound branches use the nickname of its master branch unless it is set\n"
 "locally, in which case binding will update the local nickname to be\n"
 "that of the master."
 msgstr ""
 
-#: bzrlib/builtins.py:5101
+#: bzrlib/builtins.py:5167
 msgid "No location supplied.  This format does not remember old locations."
 msgstr ""
 
-#: bzrlib/builtins.py:5106
+#: bzrlib/builtins.py:5172
 msgid "Branch is already bound"
 msgstr ""
 
-#: bzrlib/builtins.py:5108
+#: bzrlib/builtins.py:5174
 msgid "No location supplied and no previous location known"
 msgstr ""
 
-#: bzrlib/builtins.py:5114
+#: bzrlib/builtins.py:5180
 msgid "These branches have diverged. Try merging, and then bind again."
 msgstr ""
 
-#: bzrlib/builtins.py:5121
+#: bzrlib/builtins.py:5187
 msgid "Convert the current checkout into a regular branch."
 msgstr ""
 
-#: bzrlib/builtins.py:5123
+#: bzrlib/builtins.py:5189
 msgid ""
 "After unbinding, the local branch is considered independent and subsequent\n"
 "commits will be local only."
 msgstr ""
 
-#: bzrlib/builtins.py:5134
+#: bzrlib/builtins.py:5200
 msgid "Local branch is not bound"
 msgstr ""
 
-#: bzrlib/builtins.py:5138
+#: bzrlib/builtins.py:5204
 msgid "Remove the last committed revision."
 msgstr ""
 
-#: bzrlib/builtins.py:5140
+#: bzrlib/builtins.py:5206
 msgid ""
 "--verbose will print out what is being removed.\n"
 "--dry-run will go through all the motions, but not actually\n"
 "remove anything."
 msgstr ""
 
-#: bzrlib/builtins.py:5144
+#: bzrlib/builtins.py:5210
 msgid ""
 "If --revision is specified, uncommit revisions to leave the branch at the\n"
 "specified revision.  For example, \"bzr uncommit -r 15\" will leave the\n"
 "branch at revision 15."
 msgstr ""
 
-#: bzrlib/builtins.py:5148
+#: bzrlib/builtins.py:5214
 msgid ""
 "Uncommit leaves the working tree ready for a new commit.  The only change\n"
 "it may make is to restore any pending merges that were present before\n"
@@ -3311,75 +3364,75 @@
 msgstr ""
 
 # help of 'dry-run' option of 'uncommit' command
-#: bzrlib/builtins.py:5159
+#: bzrlib/builtins.py:5225
 msgid "Don't actually make changes."
 msgstr ""
 
 # help of 'force' option of 'uncommit' command
-#: bzrlib/builtins.py:5160
+#: bzrlib/builtins.py:5226
 msgid "Say yes to all questions."
 msgstr ""
 
 # help of 'keep-tags' option of 'uncommit' command
-#: bzrlib/builtins.py:5162
+#: bzrlib/builtins.py:5228
 msgid "Keep tags that point to removed revisions."
 msgstr ""
 
 # help of 'local' option of 'uncommit' command
-#: bzrlib/builtins.py:5164
+#: bzrlib/builtins.py:5230
 msgid "Only remove the commits from the local branch when in a checkout."
 msgstr ""
 
-#: bzrlib/builtins.py:5213
+#: bzrlib/builtins.py:5279
 msgid "No revisions to uncommit.\n"
 msgstr ""
 
-#: bzrlib/builtins.py:5228
+#: bzrlib/builtins.py:5294
 msgid "Dry-run, pretending to remove the above revisions.\n"
 msgstr ""
 
-#: bzrlib/builtins.py:5231
+#: bzrlib/builtins.py:5297
 msgid "The above revision(s) will be removed.\n"
 msgstr ""
 
-#: bzrlib/builtins.py:5235
+#: bzrlib/builtins.py:5301
 msgid "Uncommit these revisions"
 msgstr ""
 
-#: bzrlib/builtins.py:5238
+#: bzrlib/builtins.py:5304
 msgid "Canceled\n"
 msgstr ""
 
-#: bzrlib/builtins.py:5245
+#: bzrlib/builtins.py:5311
 #, python-format
 msgid ""
 "You can restore the old tip by running:\n"
 "  bzr pull . -r revid:%s\n"
 msgstr ""
 
-#: bzrlib/builtins.py:5250
+#: bzrlib/builtins.py:5316
 msgid "Break a dead lock."
 msgstr ""
 
-#: bzrlib/builtins.py:5252
+#: bzrlib/builtins.py:5318
 msgid ""
 "This command breaks a lock on a repository, branch, working directory or\n"
 "config file."
 msgstr ""
 
-#: bzrlib/builtins.py:5255
+#: bzrlib/builtins.py:5321
 msgid ""
 "CAUTION: Locks should only be broken when you are sure that the process\n"
 "holding the lock has been stopped."
 msgstr ""
 
-#: bzrlib/builtins.py:5258
+#: bzrlib/builtins.py:5324
 msgid ""
 "You can get information on what locks are open via the 'bzr info\n"
 "[location]' command."
 msgstr ""
 
-#: bzrlib/builtins.py:5261
+#: bzrlib/builtins.py:5327
 msgid ""
 ":Examples:\n"
 "    bzr break-lock\n"
@@ -3388,41 +3441,41 @@
 msgstr ""
 
 # help of 'config' option of 'break-lock' command
-#: bzrlib/builtins.py:5270
+#: bzrlib/builtins.py:5336
 msgid "LOCATION is the directory where the config lock is."
 msgstr ""
 
 # help of 'force' option of 'break-lock' command
-#: bzrlib/builtins.py:5272
+#: bzrlib/builtins.py:5338
 msgid "Do not ask for confirmation before breaking the lock."
 msgstr ""
 
 # help of 'protocol=bzr' option of 'serve' command
-#: bzrlib/builtins.py:5307
+#: bzrlib/builtins.py:5373
 msgid "The Bazaar smart server protocol over TCP. (default port: 4155)"
 msgstr ""
 
-#: bzrlib/builtins.py:5308
+#: bzrlib/builtins.py:5374
 msgid "Run the bzr server."
 msgstr ""
 
 # help of 'inet' option of 'serve' command
-#: bzrlib/builtins.py:5314
+#: bzrlib/builtins.py:5380
 msgid "Serve on stdin/out for use from inetd or sshd."
 msgstr ""
 
 # title of 'protocol' option of 'serve' command
-#: bzrlib/builtins.py:5315
+#: bzrlib/builtins.py:5381
 msgid "protocol"
 msgstr ""
 
 # help of 'protocol' option of 'serve' command
-#: bzrlib/builtins.py:5316
+#: bzrlib/builtins.py:5382
 msgid "Protocol to serve."
 msgstr ""
 
 # help of 'port' option of 'serve' command
-#: bzrlib/builtins.py:5320
+#: bzrlib/builtins.py:5386
 msgid ""
 "Listen for connections on nominated port of the form [hostname:]portnumber.  "
 "Passing 0 as the port number will result in a dynamically allocated port.  "
@@ -3430,12 +3483,12 @@
 msgstr ""
 
 # help of 'directory' option of 'serve' command
-#: bzrlib/builtins.py:5326
+#: bzrlib/builtins.py:5392
 msgid "Serve contents of this directory."
 msgstr ""
 
 # help of 'allow-writes' option of 'serve' command
-#: bzrlib/builtins.py:5328
+#: bzrlib/builtins.py:5394
 msgid ""
 "By default the server is a readonly server.  Supplying --allow-writes "
 "enables write access to the contents of the served directory and below.  "
@@ -3445,114 +3498,114 @@
 msgstr ""
 
 # help of 'client-timeout' option of 'serve' command
-#: bzrlib/builtins.py:5337
+#: bzrlib/builtins.py:5403
 msgid "Override the default idle client timeout (5min)."
 msgstr ""
 
-#: bzrlib/builtins.py:5387
+#: bzrlib/builtins.py:5453
 msgid "Combine a tree into its containing tree."
 msgstr ""
 
-#: bzrlib/builtins.py:5389
+#: bzrlib/builtins.py:5455
 msgid "This command requires the target tree to be in a rich-root format."
 msgstr ""
 
-#: bzrlib/builtins.py:5391
+#: bzrlib/builtins.py:5457
 msgid ""
 "The TREE argument should be an independent tree, inside another tree, but\n"
 "not part of it.  (Such trees can be produced by \"bzr split\", but also by\n"
 "running \"bzr branch\" with the target inside a tree.)"
 msgstr ""
 
-#: bzrlib/builtins.py:5395
+#: bzrlib/builtins.py:5461
 msgid ""
 "The result is a combined tree, with the subtree no longer an independent\n"
 "part.  This is marked as a merge of the subtree into the containing tree,\n"
 "and all history is preserved."
 msgstr ""
 
-#: bzrlib/builtins.py:5413
+#: bzrlib/builtins.py:5479
 #, python-format
 msgid ""
 "Can't join trees because %s doesn't support rich root data.\n"
 "You can use bzr upgrade on the repository."
 msgstr ""
 
-#: bzrlib/builtins.py:5423 bzrlib/builtins.py:5429
+#: bzrlib/builtins.py:5489 bzrlib/builtins.py:5495
 msgid "Cannot join {0}.  {1}"
 msgstr ""
 
-#: bzrlib/builtins.py:5433
+#: bzrlib/builtins.py:5499
 msgid "Split a subdirectory of a tree into a separate tree."
 msgstr ""
 
-#: bzrlib/builtins.py:5435
+#: bzrlib/builtins.py:5501
 msgid ""
 "This command will produce a target tree in a format that supports\n"
 "rich roots, like 'rich-root' or 'rich-root-pack'.  These formats cannot be\n"
 "converted into earlier formats like 'dirstate-tags'."
 msgstr ""
 
-#: bzrlib/builtins.py:5439
+#: bzrlib/builtins.py:5505
 msgid ""
 "The TREE argument should be a subdirectory of a working tree.  That\n"
 "subdirectory will be converted into an independent tree, with its own\n"
 "branch.  Commits in the top-level tree will not apply to the new subtree."
 msgstr ""
 
-#: bzrlib/builtins.py:5519
+#: bzrlib/builtins.py:5585
 msgid "No submit branch specified or known"
 msgstr ""
 
-#: bzrlib/builtins.py:5527 bzrlib/send.py:106
+#: bzrlib/builtins.py:5593 bzrlib/send.py:108
 msgid "No public branch specified or known"
 msgstr ""
 
-#: bzrlib/builtins.py:5532
+#: bzrlib/builtins.py:5598
 msgid "bzr merge-directive takes at most two one revision identifiers"
 msgstr ""
 
-#: bzrlib/builtins.py:5541
+#: bzrlib/builtins.py:5607
 msgid "No revisions to bundle."
 msgstr ""
 
-#: bzrlib/builtins.py:5560
+#: bzrlib/builtins.py:5626
 msgid "Mail or create a merge-directive for submitting changes."
 msgstr ""
 
-#: bzrlib/builtins.py:5562
+#: bzrlib/builtins.py:5628
 msgid "A merge directive provides many things needed for requesting merges:"
 msgstr ""
 
-#: bzrlib/builtins.py:5564
+#: bzrlib/builtins.py:5630
 msgid "* A machine-readable description of the merge to perform"
 msgstr ""
 
-#: bzrlib/builtins.py:5566
+#: bzrlib/builtins.py:5632
 msgid "* An optional patch that is a preview of the changes requested"
 msgstr ""
 
-#: bzrlib/builtins.py:5568
+#: bzrlib/builtins.py:5634
 msgid ""
 "* An optional bundle of revision data, so that the changes can be applied\n"
 "  directly from the merge directive, without retrieving data from a\n"
 "  branch."
 msgstr ""
 
-#: bzrlib/builtins.py:5572
+#: bzrlib/builtins.py:5638
 msgid ""
 "`bzr send` creates a compact data set that, when applied using bzr\n"
 "merge, has the same effect as merging from the source branch.  "
 msgstr ""
 
-#: bzrlib/builtins.py:5575
+#: bzrlib/builtins.py:5641
 msgid ""
 "By default the merge directive is self-contained and can be applied to any\n"
 "branch containing submit_branch in its ancestory without needing access to\n"
 "the source branch."
 msgstr ""
 
-#: bzrlib/builtins.py:5579
+#: bzrlib/builtins.py:5645
 msgid ""
 "If --no-bundle is specified, then Bazaar doesn't send the contents of the\n"
 "revisions, but only a structured request to merge from the\n"
@@ -3561,7 +3614,7 @@
 "included if known, so that people can check it later."
 msgstr ""
 
-#: bzrlib/builtins.py:5585
+#: bzrlib/builtins.py:5651
 msgid ""
 "The submit branch defaults to the parent of the source branch, but can be\n"
 "overridden.  Both submit branch and public branch will be remembered in\n"
@@ -3570,7 +3623,7 @@
 "be changed using --from."
 msgstr ""
 
-#: bzrlib/builtins.py:5591
+#: bzrlib/builtins.py:5657
 msgid ""
 "Both the submit branch and the public branch follow the usual behavior with\n"
 "respect to --remember: If there is no default location set, the first send\n"
@@ -3579,7 +3632,7 @@
 "--remember. The value will only be saved if the location can be accessed."
 msgstr ""
 
-#: bzrlib/builtins.py:5597
+#: bzrlib/builtins.py:5663
 msgid ""
 "In order to calculate those changes, bzr must analyse the submit branch.\n"
 "Therefore it is most efficient for the submit branch to be a local mirror.\n"
@@ -3587,20 +3640,20 @@
 "in the merge directive."
 msgstr ""
 
-#: bzrlib/builtins.py:5602
+#: bzrlib/builtins.py:5668
 msgid ""
 "The default behaviour is to send the merge directive by mail, unless -o is\n"
 "given, in which case it is sent to a file."
 msgstr ""
 
-#: bzrlib/builtins.py:5605
+#: bzrlib/builtins.py:5671
 msgid ""
 "Mail is sent using your preferred mail program.  This should be transparent\n"
 "on Windows (it uses MAPI).  On Unix, it requires the xdg-email utility.\n"
 "If the preferred client can't be found (or used), your editor will be used."
 msgstr ""
 
-#: bzrlib/builtins.py:5609
+#: bzrlib/builtins.py:5675
 msgid ""
 "To use a specific mail program, set the mail_client configuration option.\n"
 "(For Thunderbird 1.5, this works around some bugs.)  Supported values for\n"
@@ -3612,7 +3665,7 @@
 "supported clients."
 msgstr ""
 
-#: bzrlib/builtins.py:5616
+#: bzrlib/builtins.py:5682
 msgid ""
 "If mail is being sent, a to address is required.  This can be supplied\n"
 "either on the commandline, by setting the submit_to configuration\n"
@@ -3620,7 +3673,7 @@
 "in the submit branch."
 msgstr ""
 
-#: bzrlib/builtins.py:5621
+#: bzrlib/builtins.py:5687
 msgid ""
 "Two formats are currently supported: \"4\" uses revision bundle format 4 "
 "and\n"
@@ -3630,13 +3683,13 @@
 "format 1.  It is compatible with Bazaar 0.12 - 0.18."
 msgstr ""
 
-#: bzrlib/builtins.py:5627
+#: bzrlib/builtins.py:5693
 msgid ""
 "The merge directives created by bzr send may be applied using bzr merge or\n"
 "bzr pull by specifying a file containing a merge directive as the location."
 msgstr ""
 
-#: bzrlib/builtins.py:5630
+#: bzrlib/builtins.py:5696
 msgid ""
 "bzr send makes extensive use of public locations to map local locations "
 "into\n"
@@ -3645,90 +3698,91 @@
 msgstr ""
 
 # help of 'output' option of 'send' command
-#: bzrlib/builtins.py:5654
+#: bzrlib/builtins.py:5720
 msgid "Write merge directive to this file or directory; use - for stdout."
 msgstr ""
 
 # help of 'strict' option of 'send' command
-#: bzrlib/builtins.py:5658
+#: bzrlib/builtins.py:5724
 msgid ""
 "Refuse to send if there are uncommitted changes in the working tree, --no-"
 "strict disables the check."
 msgstr ""
 
 # help of 'mail-to' option of 'send' command
-#: bzrlib/builtins.py:5660
+#: bzrlib/builtins.py:5726
 msgid "Mail the request to this address."
 msgstr ""
 
 # help of 'body' option of 'send' command
-#: bzrlib/builtins.py:5664
+#: bzrlib/builtins.py:5730
 msgid "Body for the email."
 msgstr ""
 
 # help of 'no-bundle' option of 'send' command
-#: bzrlib/builtins.py:5717
+#: bzrlib/builtins.py:5783
 msgid "Do not include a bundle in the merge directive."
 msgstr ""
 
 # help of 'no-patch' option of 'send' command
-#: bzrlib/builtins.py:5718
+#: bzrlib/builtins.py:5784
 msgid "Do not include a preview patch in the merge directive."
 msgstr ""
 
 # help of 'remember' option of 'send' command
-#: bzrlib/builtins.py:5721
+#: bzrlib/builtins.py:5787
 msgid "Remember submit and public branch."
 msgstr ""
 
 # help of 'from' option of 'send' command
-#: bzrlib/builtins.py:5723
+#: bzrlib/builtins.py:5789
 msgid ""
 "Branch to generate the submission from, rather than the one containing the "
 "working directory."
 msgstr ""
 
 # title of 'format' option of 'send' command
-#: bzrlib/builtins.py:5733
+# title of 'format' option of 'version-info' command
+#: bzrlib/builtins.py:5799 bzrlib/cmd_version_info.py:76
 msgid "format"
 msgstr ""
 
 # help of 'format' option of 'send' command
-#: bzrlib/builtins.py:5734
+#: bzrlib/builtins.py:5800
 msgid "Use the specified output format."
 msgstr ""
 
-#: bzrlib/builtins.py:5756
+#: bzrlib/builtins.py:5822
 msgid "Create, remove or modify a tag naming a revision."
 msgstr ""
 
-#: bzrlib/builtins.py:5758
+#: bzrlib/builtins.py:5824
 msgid ""
 "Tags give human-meaningful names to revisions.  Commands that take a -r\n"
 "(--revision) option can be given -rtag:X, where X is any previously\n"
 "created tag."
 msgstr ""
 
-#: bzrlib/builtins.py:5762
+#: bzrlib/builtins.py:5828
 msgid ""
 "Tags are stored in the branch.  Tags are copied from one branch to another\n"
 "along when you branch, push, pull or merge."
 msgstr ""
 
-#: bzrlib/builtins.py:5765
+#: bzrlib/builtins.py:5831
 msgid ""
 "It is an error to give a tag name that already exists unless you pass\n"
 "--force, in which case the tag is moved to point to the new revision."
 msgstr ""
 
-#: bzrlib/builtins.py:5768
+#: bzrlib/builtins.py:5834
 msgid ""
 "To rename a tag (change the name but keep it on the same revsion), run "
 "``bzr\n"
 "tag new-name -r tag:old-name`` and then ``bzr tag --delete oldname``."
 msgstr ""
 
-#: bzrlib/builtins.py:5771
+#: bzrlib/builtins.py:5837
 msgid ""
 "If no tag name is specified it will be determined through the \n"
 "'automatic_tag_name' hook. This can e.g. be used to automatically tag\n"
@@ -3737,81 +3791,81 @@
 msgstr ""
 
 # help of 'delete' option of 'tag' command
-#: bzrlib/builtins.py:5781
+#: bzrlib/builtins.py:5847
 msgid "Delete this tag rather than placing it."
 msgstr ""
 
 # help of 'directory' option of 'tag' command
-#: bzrlib/builtins.py:5784
+#: bzrlib/builtins.py:5850
 msgid "Branch in which to place the tag."
 msgstr ""
 
 # help of 'force' option of 'tag' command
-#: bzrlib/builtins.py:5786
+#: bzrlib/builtins.py:5852
 msgid "Replace existing tags."
 msgstr ""
 
-#: bzrlib/builtins.py:5801
+#: bzrlib/builtins.py:5867
 msgid "No tag specified to delete."
 msgstr ""
 
-#: bzrlib/builtins.py:5803
+#: bzrlib/builtins.py:5869
 #, python-format
 msgid "Deleted tag %s."
 msgstr ""
 
-#: bzrlib/builtins.py:5817
+#: bzrlib/builtins.py:5883
 msgid "Please specify a tag name."
 msgstr ""
 
-#: bzrlib/builtins.py:5825
+#: bzrlib/builtins.py:5891
 #, python-format
 msgid "Tag %s already exists for that revision."
 msgstr ""
 
-#: bzrlib/builtins.py:5829
+#: bzrlib/builtins.py:5895
 #, python-format
 msgid "Created tag %s."
 msgstr ""
 
-#: bzrlib/builtins.py:5831
+#: bzrlib/builtins.py:5897
 #, python-format
 msgid "Updated tag %s."
 msgstr ""
 
-#: bzrlib/builtins.py:5835
+#: bzrlib/builtins.py:5901
 msgid "List tags."
 msgstr ""
 
-#: bzrlib/builtins.py:5837
+#: bzrlib/builtins.py:5903
 msgid ""
 "This command shows a table of tag names and the revisions they reference."
 msgstr ""
 
 # help of 'directory' option of 'tags' command
-#: bzrlib/builtins.py:5843
+#: bzrlib/builtins.py:5909
 msgid "Branch whose tags should be displayed."
 msgstr ""
 
 # help of 'sort' option of 'tags' command
-#: bzrlib/builtins.py:5845
+#: bzrlib/builtins.py:5911
 msgid "Sort tags by different criteria."
 msgstr ""
 
 # title of 'sort' option of 'tags' command
-#: bzrlib/builtins.py:5845
+#: bzrlib/builtins.py:5911
 msgid "Sorting"
 msgstr ""
 
-#: bzrlib/builtins.py:5914
+#: bzrlib/builtins.py:5980
 msgid "Reconfigure the type of a bzr directory."
 msgstr ""
 
-#: bzrlib/builtins.py:5916
+#: bzrlib/builtins.py:5982
 msgid "A target configuration must be specified."
 msgstr ""
 
-#: bzrlib/builtins.py:5918
+#: bzrlib/builtins.py:5984
 msgid ""
 "For checkouts, the bind-to location will be auto-detected if not specified.\n"
 "The order of preference is\n"
@@ -3823,112 +3877,112 @@
 msgstr ""
 
 # title of 'tree_type' option of 'reconfigure' command
-#: bzrlib/builtins.py:5932
+#: bzrlib/builtins.py:5998
 msgid "Tree type"
 msgstr ""
 
 # help of 'tree_type' option of 'reconfigure' command
-#: bzrlib/builtins.py:5933
+#: bzrlib/builtins.py:5999
 msgid "The relation between branch and tree."
 msgstr ""
 
 # help of 'tree_type=branch' option of 'reconfigure' command
-#: bzrlib/builtins.py:5935
+#: bzrlib/builtins.py:6001
 msgid "Reconfigure to be an unbound branch with no working tree."
 msgstr ""
 
 # help of 'tree_type=tree' option of 'reconfigure' command
-#: bzrlib/builtins.py:5936
+#: bzrlib/builtins.py:6002
 msgid "Reconfigure to be an unbound branch with a working tree."
 msgstr ""
 
 # help of 'tree_type=checkout' option of 'reconfigure' command
-#: bzrlib/builtins.py:5937
+#: bzrlib/builtins.py:6003
 msgid "Reconfigure to be a bound branch with a working tree."
 msgstr ""
 
 # help of 'tree_type=lightweight-checkout' option of 'reconfigure' command
-#: bzrlib/builtins.py:5938
+#: bzrlib/builtins.py:6004
 msgid "Reconfigure to be a lightweight checkout (with no local history)."
 msgstr ""
 
 # title of 'repository_type' option of 'reconfigure' command
-#: bzrlib/builtins.py:5943
+#: bzrlib/builtins.py:6009
 msgid "Repository type"
 msgstr ""
 
 # help of 'repository_type' option of 'reconfigure' command
-#: bzrlib/builtins.py:5944
+#: bzrlib/builtins.py:6010
 msgid "Location fo the repository."
 msgstr ""
 
 # help of 'repository_type=standalone' option of 'reconfigure' command
-#: bzrlib/builtins.py:5946
+#: bzrlib/builtins.py:6012
 msgid ""
 "Reconfigure to be a standalone branch (i.e. stop using shared repository)."
 msgstr ""
 
 # help of 'repository_type=use-shared' option of 'reconfigure' command
-#: bzrlib/builtins.py:5948
+#: bzrlib/builtins.py:6014
 msgid "Reconfigure to use a shared repository."
 msgstr ""
 
 # title of 'repository_trees' option of 'reconfigure' command
-#: bzrlib/builtins.py:5952
+#: bzrlib/builtins.py:6018
 msgid "Trees in Repository"
 msgstr ""
 
 # help of 'repository_trees' option of 'reconfigure' command
-#: bzrlib/builtins.py:5953
+#: bzrlib/builtins.py:6019
 msgid "Whether new branches in the repository have trees."
 msgstr ""
 
 # help of 'repository_trees=with-trees' option of 'reconfigure' command
-#: bzrlib/builtins.py:5955
+#: bzrlib/builtins.py:6021
 msgid "Reconfigure repository to create working trees on branches by default."
 msgstr ""
 
 # help of 'repository_trees=with-no-trees' option of 'reconfigure' command
-#: bzrlib/builtins.py:5957
+#: bzrlib/builtins.py:6023
 msgid ""
 "Reconfigure repository to not create working trees on branches by default."
 msgstr ""
 
 # help of 'bind-to' option of 'reconfigure' command
-#: bzrlib/builtins.py:5960
+#: bzrlib/builtins.py:6026
 msgid "Branch to bind checkout to."
 msgstr ""
 
 # help of 'force' option of 'reconfigure' command
-#: bzrlib/builtins.py:5962
+#: bzrlib/builtins.py:6028
 msgid "Perform reconfiguration even if local changes will be lost."
 msgstr ""
 
 # help of 'stacked-on' option of 'reconfigure' command
-#: bzrlib/builtins.py:5965
+#: bzrlib/builtins.py:6031
 msgid "Reconfigure a branch to be stacked on another branch."
 msgstr ""
 
 # help of 'unstacked' option of 'reconfigure' command
-#: bzrlib/builtins.py:5969
+#: bzrlib/builtins.py:6035
 msgid ""
 "Reconfigure a branch to be unstacked.  This may require copying substantial "
 "data into it."
 msgstr ""
 
-#: bzrlib/builtins.py:5979
+#: bzrlib/builtins.py:6045
 msgid "Can't use both --stacked-on and --unstacked"
 msgstr ""
 
-#: bzrlib/builtins.py:5993
+#: bzrlib/builtins.py:6059
 msgid "No target configuration specified"
 msgstr ""
 
-#: bzrlib/builtins.py:6028
+#: bzrlib/builtins.py:6094
 msgid "Set the branch of a checkout and update."
 msgstr ""
 
-#: bzrlib/builtins.py:6030
+#: bzrlib/builtins.py:6096
 msgid ""
 "For lightweight checkouts, this changes the branch being referenced.\n"
 "For heavyweight checkouts, this checks that there are no local commits\n"
@@ -3936,17 +3990,17 @@
 "of the new location and binds to it."
 msgstr ""
 
-#: bzrlib/builtins.py:6035
+#: bzrlib/builtins.py:6101
 msgid ""
 "In both cases, the working tree is updated and uncommitted changes\n"
 "are merged. The user can commit or revert these as they desire."
 msgstr ""
 
-#: bzrlib/builtins.py:6038
+#: bzrlib/builtins.py:6104
 msgid "Pending merges need to be committed or reverted before using switch."
 msgstr ""
 
-#: bzrlib/builtins.py:6040
+#: bzrlib/builtins.py:6106
 msgid ""
 "The path to the branch to switch to can be specified relative to the parent\n"
 "directory of the current branch. For example, if you are currently in a\n"
@@ -3954,7 +4008,7 @@
 "/path/to/newbranch."
 msgstr ""
 
-#: bzrlib/builtins.py:6045
+#: bzrlib/builtins.py:6111
 msgid ""
 "Bound branches use the nickname of its master branch unless it is set\n"
 "locally, in which case switching will update the local nickname to be\n"
@@ -3962,28 +4016,28 @@
 msgstr ""
 
 # help of 'force' option of 'switch' command
-#: bzrlib/builtins.py:6053
+#: bzrlib/builtins.py:6119
 msgid "Switch even if local commits will be lost."
 msgstr ""
 
 # help of 'create-branch' option of 'switch' command
-#: bzrlib/builtins.py:6056
+#: bzrlib/builtins.py:6122
 msgid "Create the target branch from this one before switching to it."
 msgstr ""
 
-#: bzrlib/builtins.py:6068
+#: bzrlib/builtins.py:6134
 msgid "You must supply either a revision or a location"
 msgstr ""
 
-#: bzrlib/builtins.py:6079
+#: bzrlib/builtins.py:6145
 msgid "cannot create branch without source branch"
 msgstr ""
 
-#: bzrlib/builtins.py:6143
+#: bzrlib/builtins.py:6209
 msgid "Manage filtered views."
 msgstr ""
 
-#: bzrlib/builtins.py:6145
+#: bzrlib/builtins.py:6211
 msgid ""
 "Views provide a mask over the tree so that users can focus on\n"
 "a subset of a tree when doing their work. After creating a view,\n"
@@ -3993,7 +4047,7 @@
 "must be within the current view."
 msgstr ""
 
-#: bzrlib/builtins.py:6152
+#: bzrlib/builtins.py:6218
 msgid ""
 "In most cases, a view has a short life-span: it is created to make\n"
 "a selected change and is deleted once that change is committed.\n"
@@ -4001,7 +4055,7 @@
 "and switch between them."
 msgstr ""
 
-#: bzrlib/builtins.py:6157
+#: bzrlib/builtins.py:6223
 msgid ""
 "To disable the current view without deleting it, you can switch to\n"
 "the pseudo view called ``off``. This can be useful when you need\n"
@@ -4009,202 +4063,202 @@
 "want to switch back to your view after that."
 msgstr ""
 
-#: bzrlib/builtins.py:6162
+#: bzrlib/builtins.py:6228
 msgid ""
 ":Examples:\n"
 "  To define the current view::"
 msgstr ""
 
-#: bzrlib/builtins.py:6165
+#: bzrlib/builtins.py:6231
 msgid "    bzr view file1 dir1 ..."
 msgstr ""
 
-#: bzrlib/builtins.py:6167
+#: bzrlib/builtins.py:6233
 msgid "  To list the current view::"
 msgstr ""
 
-#: bzrlib/builtins.py:6169
+#: bzrlib/builtins.py:6235
 msgid "    bzr view"
 msgstr ""
 
-#: bzrlib/builtins.py:6171
+#: bzrlib/builtins.py:6237
 msgid "  To delete the current view::"
 msgstr ""
 
-#: bzrlib/builtins.py:6173
+#: bzrlib/builtins.py:6239
 msgid "    bzr view --delete"
 msgstr ""
 
-#: bzrlib/builtins.py:6175
+#: bzrlib/builtins.py:6241
 msgid "  To disable the current view without deleting it::"
 msgstr ""
 
-#: bzrlib/builtins.py:6177
+#: bzrlib/builtins.py:6243
 msgid "    bzr view --switch off"
 msgstr ""
 
-#: bzrlib/builtins.py:6179
+#: bzrlib/builtins.py:6245
 msgid "  To define a named view and switch to it::"
 msgstr ""
 
-#: bzrlib/builtins.py:6181
+#: bzrlib/builtins.py:6247
 msgid "    bzr view --name view-name file1 dir1 ..."
 msgstr ""
 
-#: bzrlib/builtins.py:6183
+#: bzrlib/builtins.py:6249
 msgid "  To list a named view::"
 msgstr ""
 
-#: bzrlib/builtins.py:6185
+#: bzrlib/builtins.py:6251
 msgid "    bzr view --name view-name"
 msgstr ""
 
-#: bzrlib/builtins.py:6187
+#: bzrlib/builtins.py:6253
 msgid "  To delete a named view::"
 msgstr ""
 
-#: bzrlib/builtins.py:6189
+#: bzrlib/builtins.py:6255
 msgid "    bzr view --name view-name --delete"
 msgstr ""
 
-#: bzrlib/builtins.py:6191
+#: bzrlib/builtins.py:6257
 msgid "  To switch to a named view::"
 msgstr ""
 
-#: bzrlib/builtins.py:6193
+#: bzrlib/builtins.py:6259
 msgid "    bzr view --switch view-name"
 msgstr ""
 
-#: bzrlib/builtins.py:6195
+#: bzrlib/builtins.py:6261
 msgid "  To list all views defined::"
 msgstr ""
 
-#: bzrlib/builtins.py:6197
+#: bzrlib/builtins.py:6263
 msgid "    bzr view --all"
 msgstr ""
 
-#: bzrlib/builtins.py:6199
+#: bzrlib/builtins.py:6265
 msgid "  To delete all views::"
 msgstr ""
 
-#: bzrlib/builtins.py:6201
+#: bzrlib/builtins.py:6267
 msgid "    bzr view --delete --all"
 msgstr ""
 
 # help of 'all' option of 'view' command
-#: bzrlib/builtins.py:6208
+#: bzrlib/builtins.py:6274
 msgid "Apply list or delete action to all views."
 msgstr ""
 
 # help of 'delete' option of 'view' command
-#: bzrlib/builtins.py:6211
+#: bzrlib/builtins.py:6277
 msgid "Delete the view."
 msgstr ""
 
 # help of 'name' option of 'view' command
-#: bzrlib/builtins.py:6214
+#: bzrlib/builtins.py:6280
 msgid "Name of the view to define, list or delete."
 msgstr ""
 
 # help of 'switch' option of 'view' command
-#: bzrlib/builtins.py:6218
+#: bzrlib/builtins.py:6284
 msgid "Name of the view to switch to."
 msgstr ""
 
-#: bzrlib/builtins.py:6237
+#: bzrlib/builtins.py:6303
 msgid "Both --delete and a file list specified"
 msgstr ""
 
-#: bzrlib/builtins.py:6240
+#: bzrlib/builtins.py:6306
 msgid "Both --delete and --switch specified"
 msgstr ""
 
-#: bzrlib/builtins.py:6243
+#: bzrlib/builtins.py:6309
 msgid "Deleted all views.\n"
 msgstr ""
 
-#: bzrlib/builtins.py:6245
+#: bzrlib/builtins.py:6311
 msgid "No current view to delete"
 msgstr ""
 
-#: bzrlib/builtins.py:6248
+#: bzrlib/builtins.py:6314
 #, python-format
 msgid "Deleted '%s' view.\n"
 msgstr ""
 
-#: bzrlib/builtins.py:6252
+#: bzrlib/builtins.py:6318
 msgid "Both --switch and a file list specified"
 msgstr ""
 
-#: bzrlib/builtins.py:6255
+#: bzrlib/builtins.py:6321
 msgid "Both --switch and --all specified"
 msgstr ""
 
-#: bzrlib/builtins.py:6258
+#: bzrlib/builtins.py:6324
 msgid "No current view to disable"
 msgstr ""
 
-#: bzrlib/builtins.py:6260
+#: bzrlib/builtins.py:6326
 #, python-format
 msgid "Disabled '%s' view.\n"
 msgstr ""
 
-#: bzrlib/builtins.py:6264 bzrlib/builtins.py:6286
+#: bzrlib/builtins.py:6330 bzrlib/builtins.py:6352
 msgid "Using '{0}' view: {1}\n"
 msgstr ""
 
-#: bzrlib/builtins.py:6267
+#: bzrlib/builtins.py:6333
 msgid "Views defined:\n"
 msgstr ""
 
-#: bzrlib/builtins.py:6276
+#: bzrlib/builtins.py:6342
 msgid "No views defined.\n"
 msgstr ""
 
-#: bzrlib/builtins.py:6283
+#: bzrlib/builtins.py:6349
 msgid "Cannot change the 'off' pseudo view"
 msgstr ""
 
-#: bzrlib/builtins.py:6291
+#: bzrlib/builtins.py:6357
 msgid "No current view.\n"
 msgstr ""
 
-#: bzrlib/builtins.py:6294
+#: bzrlib/builtins.py:6360
 msgid "'{0}' view is: {1}\n"
 msgstr ""
 
-#: bzrlib/builtins.py:6314
+#: bzrlib/builtins.py:6380
 msgid "    <no hooks installed>\n"
 msgstr ""
 
-#: bzrlib/builtins.py:6318
+#: bzrlib/builtins.py:6384
 msgid "Remove a branch."
 msgstr ""
 
-#: bzrlib/builtins.py:6320
+#: bzrlib/builtins.py:6386
 msgid ""
 "This will remove the branch from the specified location but \n"
 "will keep any working tree or repository in place."
 msgstr ""
 
-#: bzrlib/builtins.py:6325
+#: bzrlib/builtins.py:6391
 msgid "  Remove the branch at repo/trunk::"
 msgstr ""
 
-#: bzrlib/builtins.py:6327
+#: bzrlib/builtins.py:6393
 msgid "    bzr remove-branch repo/trunk"
 msgstr ""
 
 # help of 'writer=plain' option of 'shelve' command
-#: bzrlib/builtins.py:6342
+#: bzrlib/builtins.py:6408
 msgid "Plaintext diff output."
 msgstr ""
 
-#: bzrlib/builtins.py:6343
+#: bzrlib/builtins.py:6409
 msgid "Temporarily set aside some changes from the current tree."
 msgstr ""
 
-#: bzrlib/builtins.py:6345
+#: bzrlib/builtins.py:6411
 msgid ""
 "Shelve allows you to temporarily put changes you've made \"on the shelf\",\n"
 "ie. out of the way, until a later time when you can bring them back from\n"
@@ -4213,11 +4267,11 @@
 "will they survive its deletion."
 msgstr ""
 
-#: bzrlib/builtins.py:6351
+#: bzrlib/builtins.py:6417
 msgid "If shelve --list is specified, previously-shelved changes are listed."
 msgstr ""
 
-#: bzrlib/builtins.py:6353
+#: bzrlib/builtins.py:6419
 msgid ""
 "Shelve is intended to help separate several sets of changes that have\n"
 "been inappropriately mingled.  If you just want to get rid of all changes\n"
@@ -4225,35 +4279,35 @@
 "shelve all text changes at once, use shelve --all."
 msgstr ""
 
-#: bzrlib/builtins.py:6358
+#: bzrlib/builtins.py:6424
 msgid ""
 "If filenames are specified, only the changes to those files will be\n"
 "shelved. Other files will be left untouched."
 msgstr ""
 
-#: bzrlib/builtins.py:6361
+#: bzrlib/builtins.py:6427
 msgid ""
 "If a revision is specified, changes since that revision will be shelved."
 msgstr ""
 
-#: bzrlib/builtins.py:6363
+#: bzrlib/builtins.py:6429
 msgid ""
 "You can put multiple items on the shelf, and by default, 'unshelve' will\n"
 "restore the most recently shelved changes."
 msgstr ""
 
-#: bzrlib/builtins.py:6366
+#: bzrlib/builtins.py:6432
 msgid ""
 "For complicated changes, it is possible to edit the changes in a separate\n"
 "editor program to decide what the file remaining in the working copy\n"
 "should look like.  To do this, add the configuration option"
 msgstr ""
 
-#: bzrlib/builtins.py:6370
+#: bzrlib/builtins.py:6436
 msgid "    change_editor = PROGRAM @new_path @old_path"
 msgstr ""
 
-#: bzrlib/builtins.py:6372
+#: bzrlib/builtins.py:6438
 msgid ""
 "where @new_path is replaced with the path of the new version of the \n"
 "file and @old_path is replaced with the path of the old version of \n"
@@ -4263,39 +4317,39 @@
 msgstr ""
 
 # help of 'all' option of 'shelve' command
-#: bzrlib/builtins.py:6384
+#: bzrlib/builtins.py:6450
 msgid "Shelve all changes."
 msgstr ""
 
 # help of 'writer' option of 'shelve' command
-#: bzrlib/builtins.py:6386
+#: bzrlib/builtins.py:6452
 msgid "Method to use for writing diffs."
 msgstr ""
 
 # title of 'writer' option of 'shelve' command
-#: bzrlib/builtins.py:6386
+#: bzrlib/builtins.py:6452
 msgid "writer"
 msgstr ""
 
 # help of 'list' option of 'shelve' command
-#: bzrlib/builtins.py:6390
+#: bzrlib/builtins.py:6456
 msgid "List shelved changes."
 msgstr ""
 
 # help of 'destroy' option of 'shelve' command
-#: bzrlib/builtins.py:6392
+#: bzrlib/builtins.py:6458
 msgid "Destroy removed changes instead of shelving them."
 msgstr ""
 
-#: bzrlib/builtins.py:6421
+#: bzrlib/builtins.py:6487
 msgid "No shelved changes."
 msgstr ""
 
-#: bzrlib/builtins.py:6432
+#: bzrlib/builtins.py:6498
 msgid "Restore shelved changes."
 msgstr ""
 
-#: bzrlib/builtins.py:6434
+#: bzrlib/builtins.py:6500
 msgid ""
 "By default, the most recently shelved changes are restored. However if you\n"
 "specify a shelf by id those changes will be restored instead.  This works\n"
@@ -4303,377 +4357,384 @@
 msgstr ""
 
 # help of 'action' option of 'unshelve' command
-#: bzrlib/builtins.py:6443
+#: bzrlib/builtins.py:6509
 msgid "The action to perform."
 msgstr ""
 
+# title of 'action' option of 'resolve' command
+# title of 'action' option of 'unshelve' command
+#: bzrlib/builtins.py:6509 bzrlib/conflicts.py:694
+msgid "action"
+msgstr ""
+
 # help of 'action=apply' option of 'unshelve' command
-#: bzrlib/builtins.py:6445
+#: bzrlib/builtins.py:6511
 msgid "Apply changes and remove from the shelf."
 msgstr ""
 
 # help of 'action=dry-run' option of 'unshelve' command
-#: bzrlib/builtins.py:6446
+#: bzrlib/builtins.py:6512
 msgid "Show changes, but do not apply or remove them."
 msgstr ""
 
 # help of 'action=preview' option of 'unshelve' command
-#: bzrlib/builtins.py:6447
+#: bzrlib/builtins.py:6513
 msgid ""
 "Instead of unshelving the changes, show the diff that would result from "
 "unshelving."
 msgstr ""
 
 # help of 'action=delete-only' option of 'unshelve' command
-#: bzrlib/builtins.py:6449
+#: bzrlib/builtins.py:6515
 msgid "Delete changes without applying them."
 msgstr ""
 
 # help of 'action=keep' option of 'unshelve' command
-#: bzrlib/builtins.py:6450
+#: bzrlib/builtins.py:6516
 msgid "Apply changes but don't delete them."
 msgstr ""
 
-#: bzrlib/builtins.py:6465
+#: bzrlib/builtins.py:6531
 msgid "Remove unwanted files from working tree."
 msgstr ""
 
-#: bzrlib/builtins.py:6467
+#: bzrlib/builtins.py:6533
 msgid ""
 "By default, only unknown files, not ignored files, are deleted.  Versioned\n"
 "files are never deleted."
 msgstr ""
 
-#: bzrlib/builtins.py:6470
+#: bzrlib/builtins.py:6536
 msgid ""
 "Another class is 'detritus', which includes files emitted by bzr during\n"
 "normal operations and selftests.  (The value of these files decreases with\n"
 "time.)"
 msgstr ""
 
-#: bzrlib/builtins.py:6474
+#: bzrlib/builtins.py:6540
 msgid ""
 "If no options are specified, unknown files are deleted.  Otherwise, option\n"
 "flags are respected, and may be combined."
 msgstr ""
 
-#: bzrlib/builtins.py:6477
+#: bzrlib/builtins.py:6543
 msgid "To check what clean-tree will do, use --dry-run."
 msgstr ""
 
 # help of 'ignored' option of 'clean-tree' command
-#: bzrlib/builtins.py:6480
+#: bzrlib/builtins.py:6546
 msgid "Delete all ignored files."
 msgstr ""
 
 # help of 'detritus' option of 'clean-tree' command
-#: bzrlib/builtins.py:6481
+#: bzrlib/builtins.py:6547
 msgid ""
 "Delete conflict files, merge and revert backups, and failed selftest dirs."
 msgstr ""
 
 # help of 'unknown' option of 'clean-tree' command
-#: bzrlib/builtins.py:6484
+#: bzrlib/builtins.py:6550
 msgid "Delete files unknown to bzr (default)."
 msgstr ""
 
 # help of 'dry-run' option of 'clean-tree' command
-#: bzrlib/builtins.py:6485
+#: bzrlib/builtins.py:6551
 msgid "Show files to delete instead of deleting them."
 msgstr ""
 
 # help of 'force' option of 'clean-tree' command
-#: bzrlib/builtins.py:6487
+#: bzrlib/builtins.py:6553
 msgid "Do not prompt before deleting."
 msgstr ""
 
-#: bzrlib/bundle/__init__.py:57
+#: bzrlib/bundle/__init__.py:59
 msgid "A directory cannot be a bundle"
 msgstr ""
 
-#: bzrlib/bundle/apply_bundle.py:37
+#: bzrlib/bundle/apply_bundle.py:40
 msgid "Install revisions"
 msgstr ""
 
-#: bzrlib/bundle/commands.py:61
+#: bzrlib/bundle/commands.py:64
 msgid "--verbose requires a merge directive"
 msgstr ""
 
-#: bzrlib/bundle/commands.py:64
+#: bzrlib/bundle/commands.py:67
 msgid "Bundle format not supported"
 msgstr ""
 
-#: bzrlib/bundle/commands.py:74
+#: bzrlib/bundle/commands.py:77
 msgid "Records\n"
 msgstr ""
 
-#: bzrlib/bundle/commands.py:78
+#: bzrlib/bundle/commands.py:81
 msgid "{0}: {1} ({2} multiparent)\n"
 msgstr ""
 
-#: bzrlib/bundle/commands.py:80
+#: bzrlib/bundle/commands.py:83
 #, python-format
 msgid "unique files: %d\n"
 msgstr ""
 
-#: bzrlib/bundle/commands.py:89
+#: bzrlib/bundle/commands.py:92
 msgid "Revisions\n"
 msgstr ""
 
-#: bzrlib/bundle/commands.py:90
+#: bzrlib/bundle/commands.py:93
 #, python-format
 msgid "nicks: %s\n"
 msgstr ""
 
-#: bzrlib/bundle/commands.py:92
+#: bzrlib/bundle/commands.py:95
 #, python-format
 msgid ""
 "committers: \n"
 "%s\n"
 msgstr ""
 
-#: bzrlib/bundle/commands.py:100
+#: bzrlib/bundle/commands.py:103
 msgid "Decoded contents\n"
 msgstr ""
 
-#: bzrlib/bundle/serializer/v4.py:325
+#: bzrlib/bundle/serializer/v4.py:327
 #, python-format
 msgid "Bundling %d revision."
 msgid_plural "Bundling %d revisions."
 msgstr[0] ""
 msgstr[1] ""
 
-#: bzrlib/bzrdir.py:487
+#: bzrlib/bzrdir.py:489
 msgid ""
 "making backup of {0}\n"
 "  to {1}"
 msgstr ""
 
-#: bzrlib/bzrdir.py:510
+#: bzrlib/bzrdir.py:512
 msgid "renamed {0} to {1}"
 msgstr ""
 
-#: bzrlib/bzrdir.py:1512
+#: bzrlib/bzrdir.py:1663
 #, python-format
 msgid ""
 "Source repository format does not support stacking, using format:\n"
 "  %s"
 msgstr ""
 
-#: bzrlib/bzrdir.py:1532
+#: bzrlib/bzrdir.py:1683
 #, python-format
 msgid ""
 "Source branch format does not support stacking, using format:\n"
 "  %s"
 msgstr ""
 
-#: bzrlib/bzrdir.py:1677
+#: bzrlib/bzrdir.py:1829
 msgid "starting repository conversion"
 msgstr ""
 
-#: bzrlib/bzrdir.py:1906
+#: bzrlib/bzrdir.py:2058
 msgid "Using default stacking branch {0} at {1}"
 msgstr ""
 
-#: bzrlib/check.py:106
+#: bzrlib/check.py:108
 msgid "check"
 msgstr ""
 
-#: bzrlib/check.py:108
+#: bzrlib/check.py:110
 msgid "checking revisions"
 msgstr ""
 
-#: bzrlib/check.py:110
+#: bzrlib/check.py:112
 msgid "checking commit contents"
 msgstr ""
 
-#: bzrlib/check.py:112
+#: bzrlib/check.py:114
 msgid "checking file graphs"
 msgstr ""
 
-#: bzrlib/check.py:116
+#: bzrlib/check.py:118
 msgid "checking branches and trees"
 msgstr ""
 
-#: bzrlib/check.py:203
+#: bzrlib/check.py:205
 msgid "checked repository {0} format {1}"
 msgstr ""
 
-#: bzrlib/check.py:206
+#: bzrlib/check.py:208
 #, python-format
 msgid "%6d revisions"
 msgstr ""
 
-#: bzrlib/check.py:207
+#: bzrlib/check.py:209
 #, python-format
 msgid "%6d file-ids"
 msgstr ""
 
-#: bzrlib/check.py:209
+#: bzrlib/check.py:211
 #, python-format
 msgid "%6d unreferenced text versions"
 msgstr ""
 
-#: bzrlib/check.py:213
+#: bzrlib/check.py:215
 msgid "unreferenced version: {{{0}}} in {1}"
 msgstr ""
 
-#: bzrlib/check.py:216
+#: bzrlib/check.py:218
 #, python-format
 msgid "%6d revisions are missing inventory_sha1"
 msgstr ""
 
-#: bzrlib/check.py:219
+#: bzrlib/check.py:221
 #, python-format
 msgid "%6d revisions are mentioned but not present"
 msgstr ""
 
-#: bzrlib/check.py:222
+#: bzrlib/check.py:224
 #, python-format
 msgid "%6d ghost revisions"
 msgstr ""
 
-#: bzrlib/check.py:227
+#: bzrlib/check.py:229
 #, python-format
 msgid "%6d revisions missing parents in ancestry"
 msgstr ""
 
-#: bzrlib/check.py:231
+#: bzrlib/check.py:233
 #, python-format
 msgid "      %s should be in the ancestry for:"
 msgstr ""
 
-#: bzrlib/check.py:235
+#: bzrlib/check.py:237
 #, python-format
 msgid "%6d inconsistent parents"
 msgstr ""
 
-#: bzrlib/check.py:239
+#: bzrlib/check.py:241
 msgid "      * {0} version {1} has parents {2!r} but should have {3!r}"
 msgstr ""
 
-#: bzrlib/check.py:245
+#: bzrlib/check.py:247
 #, python-format
 msgid "%6d revisions have incorrect parents in the revision index"
 msgstr ""
 
-#: bzrlib/check.py:251
+#: bzrlib/check.py:253
 msgid "       {0} has wrong parents in index: {1!r} should be {2!r}"
 msgstr ""
 
-#: bzrlib/check.py:265
+#: bzrlib/check.py:267
 msgid "Mismatched internal revid {{{0}}} and index revid {{{1}}}"
 msgstr ""
 
-#: bzrlib/check.py:294
+#: bzrlib/check.py:296
 msgid ""
 "Multiple expected sha1s for {0}. {{{1}}} expects {{{2}}}, {{{3}}} expects "
 "{{{4}}}"
 msgstr ""
 
-#: bzrlib/check.py:352
+#: bzrlib/check.py:354
 #, python-format
 msgid "Checking branch at '%s'."
 msgstr ""
 
-#: bzrlib/check.py:372
+#: bzrlib/check.py:374
 #, python-format
 msgid "Checking working tree at '%s'."
 msgstr ""
 
-#: bzrlib/check.py:425 bzrlib/check.py:439
+#: bzrlib/check.py:427 bzrlib/check.py:441
 msgid "No branch found at specified location."
 msgstr ""
 
-#: bzrlib/check.py:427 bzrlib/check.py:437
+#: bzrlib/check.py:429 bzrlib/check.py:439
 msgid "No working tree found at specified location."
 msgstr ""
 
-#: bzrlib/check.py:430
+#: bzrlib/check.py:432
 #, python-format
 msgid "Checking repository at '%s'."
 msgstr ""
 
-#: bzrlib/check.py:441
+#: bzrlib/check.py:443
 msgid "No repository found at specified location."
 msgstr ""
 
-#: bzrlib/clean_tree.py:62
+#: bzrlib/clean_tree.py:63
 msgid "Nothing to delete."
 msgstr ""
 
-#: bzrlib/clean_tree.py:67
+#: bzrlib/clean_tree.py:68
 msgid "Are you sure you wish to delete these"
 msgstr ""
 
-#: bzrlib/clean_tree.py:69
+#: bzrlib/clean_tree.py:70
 msgid "Canceled"
 msgstr ""
 
-#: bzrlib/clean_tree.py:106
+#: bzrlib/clean_tree.py:107
 #, python-format
 msgid "unable to remove %s"
 msgstr ""
 
-#: bzrlib/clean_tree.py:110
+#: bzrlib/clean_tree.py:111
 msgid "deleting paths:"
 msgstr ""
 
-#: bzrlib/clean_tree.py:124
+#: bzrlib/clean_tree.py:125
 msgid "unable to remove \"{0}\": {1}."
 msgstr ""
 
-#: bzrlib/clean_tree.py:129
+#: bzrlib/clean_tree.py:130
 msgid "No files deleted."
 msgstr ""
 
-#: bzrlib/cmd_version_info.py:45
+#: bzrlib/cmd_version_info.py:47
 msgid "No known version info format {0}. Supported types are: {1}"
 msgstr ""
 
 # help of 'format=custom' option of 'version-info' command
-#: bzrlib/cmd_version_info.py:50
+#: bzrlib/cmd_version_info.py:52
 msgid "Version info in Custom template-based format."
 msgstr ""
 
 # help of 'format=python' option of 'version-info' command
-#: bzrlib/cmd_version_info.py:50
+#: bzrlib/cmd_version_info.py:52
 msgid "Version info in Python format."
 msgstr ""
 
 # help of 'format=rio' option of 'version-info' command
-#: bzrlib/cmd_version_info.py:50
+#: bzrlib/cmd_version_info.py:52
 msgid "Version info in RIO (simple text) format (default)."
 msgstr ""
 
-#: bzrlib/cmd_version_info.py:51
+#: bzrlib/cmd_version_info.py:53
 msgid "Show version information about this tree."
 msgstr ""
 
-#: bzrlib/cmd_version_info.py:53
+#: bzrlib/cmd_version_info.py:55
 msgid ""
 "You can use this command to add information about version into\n"
 "source code of an application. The output can be in one of the\n"
 "supported formats or in a custom format based on a template."
 msgstr ""
 
-#: bzrlib/cmd_version_info.py:57
+#: bzrlib/cmd_version_info.py:59 en/help_topics/configuration.txt:700
+#: en/help_topics/configuration.txt:710
 msgid "For example::"
 msgstr ""
 
-#: bzrlib/cmd_version_info.py:59
+#: bzrlib/cmd_version_info.py:61
 msgid ""
 "  bzr version-info --custom \\\n"
 "    --template=\"#define VERSION_INFO \\\"Project 1.2.3 (r{revno})\\\"\\n\""
 msgstr ""
 
-#: bzrlib/cmd_version_info.py:62
+#: bzrlib/cmd_version_info.py:64
 msgid ""
 "will produce a C header file with formatted string containing the\n"
 "current revision number. Other supported variables in templates are:"
 msgstr ""
 
-#: bzrlib/cmd_version_info.py:65
+#: bzrlib/cmd_version_info.py:67
 msgid ""
 "  * {date} - date of the last revision\n"
 "  * {build_date} - current date\n"
@@ -4685,71 +4746,71 @@
 msgstr ""
 
 # help of 'format' option of 'version-info' command
-#: bzrlib/cmd_version_info.py:75
+#: bzrlib/cmd_version_info.py:77
 msgid "Select the output format."
 msgstr ""
 
 # help of 'all' option of 'version-info' command
-#: bzrlib/cmd_version_info.py:79
+#: bzrlib/cmd_version_info.py:81
 msgid "Include all possible information."
 msgstr ""
 
 # help of 'check-clean' option of 'version-info' command
-#: bzrlib/cmd_version_info.py:80
+#: bzrlib/cmd_version_info.py:82
 msgid "Check if tree is clean."
 msgstr ""
 
 # help of 'include-history' option of 'version-info' command
-#: bzrlib/cmd_version_info.py:82
+#: bzrlib/cmd_version_info.py:84
 msgid "Include the revision-history."
 msgstr ""
 
 # help of 'include-file-revisions' option of 'version-info' command
-#: bzrlib/cmd_version_info.py:84
+#: bzrlib/cmd_version_info.py:86
 msgid "Include the last revision for each file."
 msgstr ""
 
 # help of 'template' option of 'version-info' command
-#: bzrlib/cmd_version_info.py:85
+#: bzrlib/cmd_version_info.py:87
 msgid "Template for the output."
 msgstr ""
 
-#: bzrlib/cmd_version_info.py:99
+#: bzrlib/cmd_version_info.py:101
 msgid "bzr version-info --revision takes exactly one revision specifier"
 msgstr ""
 
-#: bzrlib/commands.py:232
+#: bzrlib/commands.py:228
 #, python-format
 msgid "unknown command \"%s\""
 msgstr ""
 
-#: bzrlib/commands.py:479
+#: bzrlib/commands.py:475
 msgid "No help for this command."
 msgstr ""
 
-#: bzrlib/commands.py:492
+#: bzrlib/commands.py:488
 #, python-format
 msgid ":Purpose: %s\n"
 msgstr ""
 
-#: bzrlib/commands.py:494
+#: bzrlib/commands.py:490
 #, python-format
 msgid ""
 ":Usage:\n"
 "%s\n"
 msgstr ""
 
-#: bzrlib/commands.py:496
+#: bzrlib/commands.py:492
 #, python-format
 msgid ":Usage:   %s\n"
 msgstr ""
 
-#: bzrlib/commands.py:515
+#: bzrlib/commands.py:511
 #, python-format
 msgid ":Options:%s"
 msgstr ""
 
-#: bzrlib/commands.py:526
+#: bzrlib/commands.py:522
 #, python-format
 msgid ""
 ":Description:\n"
@@ -4757,175 +4818,185 @@
 "\n"
 msgstr ""
 
-#: bzrlib/commands.py:536
+#: bzrlib/commands.py:532
 #, python-format
 msgid ""
 "See bzr help %s for more details and examples.\n"
 "\n"
 msgstr ""
 
+#: bzrlib/commands.py:537
+msgid ":Aliases:  "
+msgstr ""
+
 #: bzrlib/commands.py:541
-msgid ":Aliases:  "
-msgstr ""
-
-#: bzrlib/commands.py:545
 #, python-format
 msgid ":From:     plugin \"%s\"\n"
 msgstr ""
 
+#: bzrlib/commands.py:553
+msgid ":doc:`{0} <{1}-help>`"
+msgstr ""
+
 #: bzrlib/commands.py:557
-msgid ":doc:`{0} <{1}-help>`"
-msgstr ""
-
-#: bzrlib/commands.py:561
 #, python-format
 msgid ":See also: %s"
 msgstr ""
 
-#: bzrlib/commands.py:819 bzrlib/gpg.py:317
+#: bzrlib/commands.py:815 bzrlib/gpg.py:324
 msgid "Only ASCII permitted in option names"
 msgstr ""
 
-#: bzrlib/commands.py:844 bzrlib/commands.py:852
+#: bzrlib/commands.py:840 bzrlib/commands.py:848
 msgid "command {0!r} needs one or more {1}"
 msgstr ""
 
-#: bzrlib/commands.py:861
+#: bzrlib/commands.py:857
 msgid "command {0!r} requires argument {1}"
 msgstr ""
 
-#: bzrlib/commands.py:868
+#: bzrlib/commands.py:864
 msgid "extra argument to command {0}: {1}"
 msgstr ""
 
-#: bzrlib/commands.py:965
+#: bzrlib/commands.py:961
 #, python-format
 msgid "Profile data written to \"%s\"."
 msgstr ""
 
-#: bzrlib/commit.py:116 bzrlib/commit.py:738
+#: bzrlib/commit.py:117 bzrlib/commit.py:740
 msgid "added"
 msgstr ""
 
-#: bzrlib/commit.py:116 bzrlib/commit.py:746
+#: bzrlib/commit.py:117 bzrlib/commit.py:748
 msgid "modified"
 msgstr ""
 
-#: bzrlib/commit.py:130
+#: bzrlib/commit.py:131
 #, python-format
 msgid "Committing%s"
 msgstr ""
 
-#: bzrlib/commit.py:133
+#: bzrlib/commit.py:134
 #, python-format
 msgid "Committed revision %d."
 msgstr ""
 
-#: bzrlib/commit.py:142
+#: bzrlib/commit.py:143
 #, python-format
 msgid "deleted %s"
 msgstr ""
 
-#: bzrlib/commit.py:145
+#: bzrlib/commit.py:146
 #, python-format
 msgid "missing %s"
 msgstr ""
 
-#: bzrlib/commit.py:510
+#: bzrlib/commit.py:511
 msgid ""
 "Conflicting tags in bound branch:\n"
 "{0}"
 msgstr ""
 
-#: bzrlib/commit.py:740
+#: bzrlib/commit.py:742
 msgid "renamed"
 msgstr ""
 
-#: bzrlib/commit.py:975
+#: bzrlib/commit.py:977
 msgid "unchanged"
 msgstr ""
 
-#: bzrlib/commit.py:997
+#: bzrlib/commit.py:999
 msgid "{0} [{1}] - Stage"
 msgstr ""
 
-#: bzrlib/commit.py:1000
+#: bzrlib/commit.py:1002
 #, python-format
 msgid "%s - Stage"
 msgstr ""
 
-#: bzrlib/commit_signature_commands.py:34
+#: bzrlib/commit_signature_commands.py:36
 msgid "Sign all commits by a given committer."
 msgstr ""
 
-#: bzrlib/commit_signature_commands.py:36
+#: bzrlib/commit_signature_commands.py:38
 msgid ""
 "If location is not specified the local tree is used.\n"
 "If committer is not specified the default committer is used."
 msgstr ""
 
-#: bzrlib/commit_signature_commands.py:39
+#: bzrlib/commit_signature_commands.py:41
 msgid "This does not sign commits that already have signatures."
 msgstr ""
 
 # help of 'dry-run' option of 'sign-my-commits' command
-#: bzrlib/commit_signature_commands.py:47
+#: bzrlib/commit_signature_commands.py:49
 msgid ""
 "Don't actually sign anything, just print the revisions that would be signed."
 msgstr ""
 
-#: bzrlib/commit_signature_commands.py:101
+#: bzrlib/commit_signature_commands.py:103
 msgid "Verify all commit signatures."
 msgstr ""
 
-#: bzrlib/commit_signature_commands.py:103
+#: bzrlib/commit_signature_commands.py:105
 msgid "Verifies that all commits in the branch are signed by known GnuPG keys."
 msgstr ""
 
 # help of 'acceptable-keys' option of 'verify-signatures' command
-#: bzrlib/commit_signature_commands.py:108
+#: bzrlib/commit_signature_commands.py:110
 msgid ""
 "Comma separated list of GPG key patterns which are acceptable for "
 "verification."
 msgstr ""
 
-#: bzrlib/commit_signature_commands.py:145
+#: bzrlib/commit_signature_commands.py:147
 msgid "Cannot verify a range of non-revision-history revisions"
 msgstr ""
 
-#: bzrlib/commit_signature_commands.py:166
+#: bzrlib/commit_signature_commands.py:168
 msgid "All commits signed with verifiable keys"
 msgstr ""
 
-#: bzrlib/config.py:451
+#: bzrlib/config.py:475
 msgid "Invalid config value for \"{0}\"  value {1!r} is not an SI unit."
 msgstr ""
 
-#: bzrlib/config.py:2762
+#: bzrlib/config.py:2499
+msgid "{0} is not an SI unit."
+msgstr ""
+
+#: bzrlib/config.py:2956
+msgid ""
+"Option {0} in section {1} of {2} was changed from {3} to {4}. The {5} value "
+"will be saved."
+msgstr ""
+
+#: bzrlib/config.py:3100
 #, python-format
 msgid "Invalid '%s', should be of the form 'name=value'"
 msgstr ""
 
-#: bzrlib/config.py:3469
+#: bzrlib/config.py:3969
 msgid "Display, set or remove a configuration option."
 msgstr ""
 
-#: bzrlib/config.py:3471
+#: bzrlib/config.py:3971
 msgid "Display the active value for a given option."
 msgstr ""
 
-#: bzrlib/config.py:3473
+#: bzrlib/config.py:3973
 msgid ""
 "If --all is specified, NAME is interpreted as a regular expression and all\n"
 "matching options are displayed mentioning their scope. The active value\n"
 "that bzr will take into account is the first one displayed for each option."
 msgstr ""
 
-#: bzrlib/config.py:3477
+#: bzrlib/config.py:3977
 msgid "If no NAME is given, --all .* is implied."
 msgstr ""
 
-#: bzrlib/config.py:3479
+#: bzrlib/config.py:3979
 msgid ""
 "Setting a value is achieved by using name=value without spaces. The value\n"
 "is set in the most relevant scope and can be checked by displaying the\n"
@@ -4933,73 +5004,65 @@
 msgstr ""
 
 # help of 'scope' option of 'config' command
-#: bzrlib/config.py:3491
+#: bzrlib/config.py:3991
 msgid "Reduce the scope to the specified configuration file."
 msgstr ""
 
 # help of 'all' option of 'config' command
-#: bzrlib/config.py:3495
+#: bzrlib/config.py:3995
 msgid "Display all the defined values for the matching options."
 msgstr ""
 
 # help of 'remove' option of 'config' command
-#: bzrlib/config.py:3497
+#: bzrlib/config.py:3997
 msgid "Remove the option from the configuration file."
 msgstr ""
 
-#: bzrlib/conflicts.py:48
+#: bzrlib/conflicts.py:50
 msgid "List files with conflicts."
 msgstr ""
 
-#: bzrlib/conflicts.py:50
-msgid ""
-"Merge will do its best to combine the changes in two branches, but there\n"
-"are some kinds of problems only a human can fix.  When it encounters those,\n"
-"it will mark a conflict.  A conflict means that you need to fix something,\n"
-"before you should commit."
-msgstr ""
-
-#: bzrlib/conflicts.py:55
+#: bzrlib/conflicts.py:57
 msgid ""
 "Conflicts normally are listed as short, human-readable messages.  If --text\n"
 "is supplied, the pathnames of files with text conflicts are listed,\n"
 "instead.  (This is useful for editing all files with text conflicts.)"
 msgstr ""
 
-#: bzrlib/conflicts.py:59
+#: bzrlib/conflicts.py:61
 msgid "Use bzr resolve when you have fixed a problem."
 msgstr ""
 
 # help of 'text' option of 'conflicts' command
-#: bzrlib/conflicts.py:64
+#: bzrlib/conflicts.py:66
 msgid "List paths of files with text conflicts."
 msgstr ""
 
 # help of 'action=done' option of 'resolve' command
-#: bzrlib/conflicts.py:83
+#: bzrlib/conflicts.py:85
 msgid "Marks the conflict as resolved."
 msgstr ""
 
 # help of 'action=take-this' option of 'resolve' command
-#: bzrlib/conflicts.py:86
+#: bzrlib/conflicts.py:88
 msgid "Resolve the conflict preserving the version in the working tree."
 msgstr ""
 
 # help of 'action=take-other' option of 'resolve' command
-#: bzrlib/conflicts.py:89
+#: bzrlib/conflicts.py:91
 msgid "Resolve the conflict taking the merged version into account."
 msgstr ""
 
 # help of 'action' option of 'resolve' command
-#: bzrlib/conflicts.py:96
+#: bzrlib/conflicts.py:98
 msgid "How to resolve the conflict."
 msgstr ""
 
-#: bzrlib/conflicts.py:102
+#: bzrlib/conflicts.py:104
 msgid "Mark a conflict as resolved."
 msgstr ""
 
-#: bzrlib/conflicts.py:109
+#: bzrlib/conflicts.py:111
 msgid ""
 "Once you have fixed a problem, use \"bzr resolve\" to automatically mark\n"
 "text conflicts as fixed, \"bzr resolve FILE\" to mark a specific conflict "
@@ -5008,283 +5071,282 @@
 msgstr ""
 
 # help of 'all' option of 'resolve' command
-#: bzrlib/conflicts.py:117
+#: bzrlib/conflicts.py:119
 msgid "Resolve all conflicts in this tree."
 msgstr ""
 
-#: bzrlib/conflicts.py:124
+#: bzrlib/conflicts.py:126
 msgid "If --all is specified, no FILE may be provided"
 msgstr ""
 
-#: bzrlib/conflicts.py:149
+#: bzrlib/conflicts.py:151
 #, python-format
 msgid "%d conflict auto-resolved."
 msgid_plural "%d conflicts auto-resolved."
 msgstr[0] ""
 msgstr[1] ""
 
-#: bzrlib/conflicts.py:152
+#: bzrlib/conflicts.py:154
 msgid "Remaining conflicts:"
 msgstr ""
 
-#: bzrlib/conflicts.py:157
+#: bzrlib/conflicts.py:159
 msgid "All conflicts resolved."
 msgstr ""
 
-#: bzrlib/conflicts.py:166
+#: bzrlib/conflicts.py:168
 msgid "{0} conflict resolved, {1} remaining"
 msgid_plural "{0} conflicts resolved, {1} remaining"
 msgstr[0] ""
 msgstr[1] ""
 
-# title of 'action' option of 'resolve' command
-#: bzrlib/conflicts.py:692
-msgid "action"
-msgstr ""
-
-#: bzrlib/controldir.py:682
+#: bzrlib/controldir.py:698
 msgid "{0} is{1} redirected to {2}"
 msgstr ""
 
-#: bzrlib/diff.py:397
+#: bzrlib/diff.py:399
 #, python-format
 msgid "*** Ignoring files outside view. View is %s"
 msgstr ""
 
-#: bzrlib/errors.py:155
+#: bzrlib/errors.py:157
 msgid "The tree builder is already building a tree."
 msgstr ""
 
-#: bzrlib/errors.py:176
+#: bzrlib/errors.py:178
 msgid "The dirstate file (%(state)s) appears to be corrupt: %(msg)s"
 msgstr ""
 
-#: bzrlib/errors.py:195
+#: bzrlib/errors.py:197
 msgid ""
 "The API for \"%(api)s\" is not compatible with \"%(wanted)s\". It supports "
 "versions \"%(minimum)s\" to \"%(current)s\"."
 msgstr ""
 
-#: bzrlib/errors.py:207
+#: bzrlib/errors.py:209
 msgid "The transport '%(transport)s' is only accessible within this process."
 msgstr ""
 
-#: bzrlib/errors.py:225
+#: bzrlib/errors.py:227
 msgid "Invalid revision number %(revno)s"
 msgstr ""
 
-#: bzrlib/errors.py:234
+#: bzrlib/errors.py:236
 msgid "Invalid revision-id {%(revision_id)s} in %(branch)s"
 msgstr ""
 
-#: bzrlib/errors.py:245
+#: bzrlib/errors.py:247
 msgid "Reserved revision-id {%(revision_id)s}"
 msgstr ""
 
-#: bzrlib/errors.py:259
+#: bzrlib/errors.py:261
 msgid "There is no public branch set for \"%(branch_url)s\"."
 msgstr ""
 
-#: bzrlib/errors.py:269
+#: bzrlib/errors.py:271
 msgid ""
 "No help could be found for '%(topic)s'. Please use 'bzr help topics' to "
 "obtain a list of topics."
 msgstr ""
 
-#: bzrlib/errors.py:278
+#: bzrlib/errors.py:280
 msgid "The file id \"%(file_id)s\" is not present in the tree %(tree)s."
 msgstr ""
 
-#: bzrlib/errors.py:288
+#: bzrlib/errors.py:290
 msgid ""
 "The file id \"%(file_id)s\" is not present in the repository %(repository)r"
 msgstr ""
 
-#: bzrlib/errors.py:297
+#: bzrlib/errors.py:299
 msgid "The branch '%(branch)s' is not stacked."
 msgstr ""
 
-#: bzrlib/errors.py:311
+#: bzrlib/errors.py:313
 msgid "No WorkingTree exists for \"%(base)s\"."
 msgstr ""
 
-#: bzrlib/errors.py:320
+#: bzrlib/errors.py:322
 msgid "Not currently building a tree."
 msgstr ""
 
-#: bzrlib/errors.py:325
+#: bzrlib/errors.py:327
 msgid "%(url)s is not a local path."
 msgstr ""
 
-#: bzrlib/errors.py:353
+#: bzrlib/errors.py:355
 msgid "%(not_locked)r is not write locked but needs to be."
 msgstr ""
 
-#: bzrlib/errors.py:361
+#: bzrlib/errors.py:363
 msgid "Error in command line options"
 msgstr ""
 
-#: bzrlib/errors.py:366
+#: bzrlib/errors.py:368
 msgid "%(value)s is not an index of type %(_type)s."
 msgstr ""
 
-#: bzrlib/errors.py:376
+#: bzrlib/errors.py:378
 msgid "Error in data for index %(value)s."
 msgstr ""
 
-#: bzrlib/errors.py:385
+#: bzrlib/errors.py:387
 msgid "The key '%(key)s' is already in index '%(index)s'."
 msgstr ""
 
-#: bzrlib/errors.py:395
+#: bzrlib/errors.py:397
 msgid "The key '%(key)s' is not a valid key."
 msgstr ""
 
-#: bzrlib/errors.py:404
+#: bzrlib/errors.py:406
 msgid "Could not parse options for index %(value)s."
 msgstr ""
 
-#: bzrlib/errors.py:413
+#: bzrlib/errors.py:415
 msgid "The value '%(value)s' is not a valid value."
 msgstr ""
 
-#: bzrlib/errors.py:441
+#: bzrlib/errors.py:443
 msgid "Generic path error: %(path)r%(extra)s)"
 msgstr ""
 
-#: bzrlib/errors.py:454
+#: bzrlib/errors.py:456
 msgid "No such file: %(path)r%(extra)s"
 msgstr ""
 
-#: bzrlib/errors.py:459
+#: bzrlib/errors.py:461
 msgid "File exists: %(path)r%(extra)s"
 msgstr ""
 
-#: bzrlib/errors.py:465
+#: bzrlib/errors.py:467
 msgid ""
 "Could not rename %(source)s => %(dest)s because both files exist. (Use --"
 "after to tell bzr about a rename that has already happened)%(extra)s"
 msgstr ""
 
-#: bzrlib/errors.py:481
+#: bzrlib/errors.py:483
 msgid "\"%(path)s\" is not a directory %(extra)s"
 msgstr ""
 
-#: bzrlib/errors.py:486
+#: bzrlib/errors.py:488
 msgid "\"%(path)s\" is not in the working directory %(extra)s"
 msgstr ""
 
-#: bzrlib/errors.py:491
+#: bzrlib/errors.py:493
 msgid "Directory not empty: \"%(path)s\"%(extra)s"
 msgstr ""
 
-#: bzrlib/errors.py:496
+#: bzrlib/errors.py:498
 msgid "Hard-linking \"%(path)s\" is not supported"
 msgstr ""
 
-#: bzrlib/errors.py:511
+#: bzrlib/errors.py:513
 msgid "Device or resource busy: \"%(path)s\"%(extra)s"
 msgstr ""
 
-#: bzrlib/errors.py:516
+#: bzrlib/errors.py:518
 msgid "Permission denied: \"%(path)s\"%(extra)s"
 msgstr ""
 
-#: bzrlib/errors.py:521
+#: bzrlib/errors.py:523
 msgid "Invalid url supplied to transport: \"%(path)s\"%(extra)s"
 msgstr ""
 
-#: bzrlib/errors.py:526
+#: bzrlib/errors.py:528
 msgid "Invalid URL join request: %(reason)s: %(base)r + %(join_args)r"
 msgstr ""
 
-#: bzrlib/errors.py:537
+#: bzrlib/errors.py:539
 msgid "URLs differ by more than path: %(from_)r and %(to)r"
 msgstr ""
 
-#: bzrlib/errors.py:559
+#: bzrlib/errors.py:561
 msgid "The %(type)s hook '%(hook)s' is unknown in this version of bzrlib."
 msgstr ""
 
-#: bzrlib/errors.py:569
+#: bzrlib/errors.py:571
 msgid "Unsupported protocol for url \"%(path)s\"%(extra)s"
 msgstr ""
 
-#: bzrlib/errors.py:577
+#: bzrlib/errors.py:579
 msgid ""
 "The branch '%(url)s'(%(format)s) is not a stackable format. You will need to "
 "upgrade the branch to permit branch stacking."
 msgstr ""
 
-#: bzrlib/errors.py:588
+#: bzrlib/errors.py:590
 msgid "The branch '%(branch_url)s' cannot be stacked on '%(target_url)s'."
 msgstr ""
 
-#: bzrlib/errors.py:598
+#: bzrlib/errors.py:600
 msgid ""
 "The repository '%(url)s'(%(format)s) is not a stackable format. You will "
 "need to upgrade the repository to permit branch stacking."
 msgstr ""
 
-#: bzrlib/errors.py:609
+#: bzrlib/errors.py:611
 msgid "Error reading from %(path)r."
 msgstr ""
 
-#: bzrlib/errors.py:628
+#: bzrlib/errors.py:630
 msgid "Path \"%(path)s\" is not a child of path \"%(base)s\"%(extra)s"
 msgstr ""
 
-#: bzrlib/errors.py:644
+#: bzrlib/errors.py:646
 msgid "Path \"%(path)s\" is not unicode normalized"
 msgstr ""
 
-#: bzrlib/errors.py:652
+#: bzrlib/errors.py:654
 msgid "Not a branch: \"%(path)s\"%(detail)s."
 msgstr ""
 
-#: bzrlib/errors.py:694
+#: bzrlib/errors.py:696
 msgid "No submit branch available for branch \"%(path)s\""
 msgstr ""
 
-#: bzrlib/errors.py:703
+#: bzrlib/errors.py:705
 msgid "Already a branch: \"%(path)s\"."
 msgstr ""
 
-#: bzrlib/errors.py:709
+#: bzrlib/errors.py:711
 msgid ""
 "Directory contains a branch, but no working tree (use bzr checkout if you "
 "wish to build a working tree): \"%(path)s\""
 msgstr ""
 
-#: bzrlib/errors.py:714
+#: bzrlib/errors.py:716
 msgid ""
 "\"%(function)s\" called on an AtomicFile after it was closed: \"%(path)s\""
 msgstr ""
 
-#: bzrlib/errors.py:724
+#: bzrlib/errors.py:726
 msgid ""
 "Parent not accessible given base \"%(base)s\" and relative path \"%(path)s\""
 msgstr ""
 
-#: bzrlib/errors.py:734
+#: bzrlib/errors.py:736
 msgid "No repository present: \"%(path)s\""
 msgstr ""
 
-#: bzrlib/errors.py:741
+#: bzrlib/errors.py:743
 msgid ""
 "Unsupported branch format: %(format)s\n"
 "Please run 'bzr upgrade'"
 msgstr ""
 
-#: bzrlib/errors.py:747
+#: bzrlib/errors.py:749
 msgid "Unknown %(kind)s format: %(format)r"
 msgstr ""
 
-#: bzrlib/errors.py:756
+#: bzrlib/errors.py:758
 msgid "Format %(format)s is not compatible with .bzr version %(bzrdir)s."
 msgstr ""
 
-#: bzrlib/errors.py:769
+#: bzrlib/errors.py:768
+msgid "Parse error on line %(lineno)d of %(format)s format: %(line)s"
+msgstr ""
+
+#: bzrlib/errors.py:783
 msgid ""
 "%(target)s\n"
 "is not compatible with\n"
@@ -5292,441 +5354,441 @@
 "%(details)s"
 msgstr ""
 
-#: bzrlib/errors.py:785
+#: bzrlib/errors.py:799
 msgid "Revision is not compatible with %(repo_format)s"
 msgstr ""
 
-#: bzrlib/errors.py:795
+#: bzrlib/errors.py:809
 msgid "%(context_info)s%(path)s is already versioned."
 msgstr ""
 
-#: bzrlib/errors.py:816
+#: bzrlib/errors.py:830
 msgid "%(context_info)s%(path)s is not versioned."
 msgstr ""
 
-#: bzrlib/errors.py:837
+#: bzrlib/errors.py:851
 msgid "Path(s) are not versioned: %(paths_as_string)s"
 msgstr ""
 
-#: bzrlib/errors.py:848
+#: bzrlib/errors.py:862
 msgid "Path(s) do not exist: %(paths_as_string)s%(extra)s"
 msgstr ""
 
-#: bzrlib/errors.py:867
+#: bzrlib/errors.py:881
 msgid "Cannot operate on \"%(filename)s\" of unsupported kind \"%(kind)s\""
 msgstr ""
 
-#: bzrlib/errors.py:875
+#: bzrlib/errors.py:889
 msgid ""
 "Filename %(filename)r is not valid in your current filesystem encoding "
 "%(fs_encoding)s"
 msgstr ""
 
-#: bzrlib/errors.py:886
+#: bzrlib/errors.py:900
 msgid "Cannot operate on \"%(filename)s\" because it is a control file"
 msgstr ""
 
-#: bzrlib/errors.py:904
+#: bzrlib/errors.py:918
 msgid "The lock for '%(lock_description)s' is in use and cannot be broken."
 msgstr ""
 
-#: bzrlib/errors.py:943
+#: bzrlib/errors.py:957
 msgid "Cannot lock %(lock)s: %(why)s"
 msgstr ""
 
-#: bzrlib/errors.py:953
+#: bzrlib/errors.py:967
 msgid ""
 "A transaction related operation was attempted after the transaction finished."
 msgstr ""
 
-#: bzrlib/errors.py:980
+#: bzrlib/errors.py:994
 msgid "Cannot lock: transport is read only: %(transport)s"
 msgstr ""
 
-#: bzrlib/errors.py:988
+#: bzrlib/errors.py:1002
 msgid "Could not acquire lock \"%(lock)s\": %(msg)s"
 msgstr ""
 
-#: bzrlib/errors.py:999
+#: bzrlib/errors.py:1013
 msgid "Lock was broken while still open: %(lock)s - check storage consistency!"
 msgstr ""
 
-#: bzrlib/errors.py:1010
+#: bzrlib/errors.py:1024
 msgid ""
 "Lock was released and re-acquired before being broken: %(lock)s: held by "
 "%(holder)r, wanted to break %(target)r"
 msgstr ""
 
-#: bzrlib/errors.py:1022
+#: bzrlib/errors.py:1036
 msgid ""
 "Lock is apparently held, but corrupted: %(corruption_info)s\n"
 "Use 'bzr break-lock' to clear it"
 msgstr ""
 
-#: bzrlib/errors.py:1035
+#: bzrlib/errors.py:1049
 msgid "Lock not held: %(lock)s"
 msgstr ""
 
-#: bzrlib/errors.py:1064
+#: bzrlib/errors.py:1078
 msgid "No changes to commit"
 msgstr ""
 
-#: bzrlib/errors.py:1069
+#: bzrlib/errors.py:1083
 msgid ""
 "Selected-file commit of merges is not supported yet: files %(files_str)s"
 msgstr ""
 
-#: bzrlib/errors.py:1079
+#: bzrlib/errors.py:1093
 msgid ""
 "Excluding paths during commit is not supported by repository at %(repository)"
 "r."
 msgstr ""
 
-#: bzrlib/errors.py:1088
+#: bzrlib/errors.py:1102
 msgid ""
 "The specified commit message contains characters unsupported by the current "
 "encoding."
 msgstr ""
 
-#: bzrlib/errors.py:1094
+#: bzrlib/errors.py:1108
 msgid "Upgrade URL cannot work with readonly URLs."
 msgstr ""
 
-#: bzrlib/errors.py:1099
+#: bzrlib/errors.py:1113
 msgid "The branch format %(format)s is already at the most recent format."
 msgstr ""
 
-#: bzrlib/errors.py:1122
+#: bzrlib/errors.py:1136
 msgid "Option --change does not accept revision ranges"
 msgstr ""
 
-#: bzrlib/errors.py:1127
+#: bzrlib/errors.py:1141
 msgid "No namespace registered for string: %(spec)r"
 msgstr ""
 
-#: bzrlib/errors.py:1146
+#: bzrlib/errors.py:1160
 msgid ""
 "Requested revision: '%(spec)s' does not exist in branch: %(branch_url)s"
 "%(extra)s"
 msgstr ""
 
-#: bzrlib/errors.py:1160
+#: bzrlib/errors.py:1174
 msgid ""
 "Operation denied because it would change the main history, which is not "
 "permitted by the append_revisions_only setting on branch \"%(location)s\"."
 msgstr ""
 
-#: bzrlib/errors.py:1171
+#: bzrlib/errors.py:1185
 msgid ""
 "These branches have diverged. Use the missing command to see how.\n"
 "Use the merge command to reconcile them."
 msgstr ""
 
-#: bzrlib/errors.py:1191
+#: bzrlib/errors.py:1205
 msgid ""
 "Branches have no common ancestor, and no merge base revision was specified."
 msgstr ""
 
-#: bzrlib/errors.py:1197
+#: bzrlib/errors.py:1211
 msgid ""
 "Selected merge cannot perform reverse cherrypicks.  Try merge3 or diff3."
 msgstr ""
 
-#: bzrlib/errors.py:1203
+#: bzrlib/errors.py:1217
 msgid "Revisions have no common ancestor: %(revision_a)s %(revision_b)s"
 msgstr ""
 
-#: bzrlib/errors.py:1212
+#: bzrlib/errors.py:1226
 msgid ""
 "Revisions are not derived from the same root: %(revision_a)s %(revision_b)s."
 msgstr ""
 
-#: bzrlib/errors.py:1221
+#: bzrlib/errors.py:1235
 msgid "Revision %(rev_id)s is not an ancestor of %(not_ancestor_id)s"
 msgstr ""
 
-#: bzrlib/errors.py:1230
+#: bzrlib/errors.py:1244
 msgid "Branch %(branch)s has no commits."
 msgstr ""
 
-#: bzrlib/errors.py:1248
+#: bzrlib/errors.py:1262
 msgid ""
 "Bound branch %(branch)s is out of date with master branch %(master)s."
 "%(extra_help)s"
 msgstr ""
 
-#: bzrlib/errors.py:1260
+#: bzrlib/errors.py:1274
 msgid ""
 "Cannot commit to branch %(branch)s. It is bound to %(master)s, which is "
 "bound to %(remote)s."
 msgstr ""
 
-#: bzrlib/errors.py:1272
+#: bzrlib/errors.py:1286
 msgid "Cannot pull --overwrite to a branch which is bound %(branch)s"
 msgstr ""
 
-#: bzrlib/errors.py:1281
+#: bzrlib/errors.py:1295
 msgid ""
 "Unable to connect to target of bound branch %(branch)s => %(target)s: "
 "%(error)s"
 msgstr ""
 
-#: bzrlib/errors.py:1293
+#: bzrlib/errors.py:1307
 msgid "Error in processing weave: %(msg)s"
 msgstr ""
 
-#: bzrlib/errors.py:1302
+#: bzrlib/errors.py:1316
 msgid "Revision {%(revision_id)s} already present in %(weave)s"
 msgstr ""
 
-#: bzrlib/errors.py:1313
+#: bzrlib/errors.py:1327
 msgid "Revision {%(revision_id)s} not present in %(weave)s"
 msgstr ""
 
-#: bzrlib/errors.py:1323
+#: bzrlib/errors.py:1337
 msgid "Weave invariant violated: %(what)s"
 msgstr ""
 
-#: bzrlib/errors.py:1332
+#: bzrlib/errors.py:1346
 msgid "Parents are mismatched between two revisions. %(msg)s"
 msgstr ""
 
-#: bzrlib/errors.py:1354
+#: bzrlib/errors.py:1368
 msgid ""
 "Weaves differ on text content. Revision: {%(revision_id)s}, %(weave_a)s, "
 "%(weave_b)s"
 msgstr ""
 
-#: bzrlib/errors.py:1366
+#: bzrlib/errors.py:1380
 msgid "Versioned file error"
 msgstr ""
 
-#: bzrlib/errors.py:1371
+#: bzrlib/errors.py:1385
 msgid "Revision {%(revision_id)s} not present in \"%(file_id)s\"."
 msgstr ""
 
-#: bzrlib/errors.py:1381
+#: bzrlib/errors.py:1395
 msgid "Revision {%(revision_id)s} already present in \"%(file_id)s\"."
 msgstr ""
 
-#: bzrlib/errors.py:1391
+#: bzrlib/errors.py:1405
 msgid "Text did not match its checksum: %(msg)s"
 msgstr ""
 
-#: bzrlib/errors.py:1517
+#: bzrlib/errors.py:1531
 msgid "Export format %(format)r not supported"
 msgstr ""
 
-#: bzrlib/errors.py:1526
+#: bzrlib/errors.py:1540
 msgid "Transport error: %(msg)s %(orig_error)s"
 msgstr ""
 
-#: bzrlib/errors.py:1552
+#: bzrlib/errors.py:1566
 msgid "Generic bzr smart protocol error: %(details)s"
 msgstr ""
 
-#: bzrlib/errors.py:1560
+#: bzrlib/errors.py:1574
 msgid "Received bad protocol version marker: %(marker)r"
 msgstr ""
 
-#: bzrlib/errors.py:1592
+#: bzrlib/errors.py:1606
 msgid "Transport operation not possible: %(msg)s %(orig_error)s"
 msgstr ""
 
-#: bzrlib/errors.py:1597
+#: bzrlib/errors.py:1611
 msgid "Connection error: %(msg)s %(orig_error)s"
 msgstr ""
 
-#: bzrlib/errors.py:1602
+#: bzrlib/errors.py:1616
 msgid "%(msg)s %(host)s%(port)s%(orig_error)s"
 msgstr ""
 
-#: bzrlib/errors.py:1623
+#: bzrlib/errors.py:1637
 msgid "Connection closed: %(msg)s %(orig_error)s"
 msgstr ""
 
-#: bzrlib/errors.py:1628
+#: bzrlib/errors.py:1642
 msgid "Connection Timeout: %(msg)s%(orig_error)s"
 msgstr ""
 
-#: bzrlib/errors.py:1633
+#: bzrlib/errors.py:1647
 msgid "Invalid range access in %(path)s at %(offset)s: %(msg)s"
 msgstr ""
 
-#: bzrlib/errors.py:1643
+#: bzrlib/errors.py:1657
 msgid "Invalid http response for %(path)s: %(msg)s%(orig_error)s"
 msgstr ""
 
-#: bzrlib/errors.py:1658
+#: bzrlib/errors.py:1672
 msgid "Invalid http range %(range)r for %(path)s: %(msg)s"
 msgstr ""
 
-#: bzrlib/errors.py:1672
+#: bzrlib/errors.py:1686
 msgid "HTTP MIME Boundary missing for %(path)s: %(msg)s"
 msgstr ""
 
-#: bzrlib/errors.py:1680
+#: bzrlib/errors.py:1694
 msgid "Invalid http Content-type \"%(ctype)s\" for %(path)s: %(msg)s"
 msgstr ""
 
-#: bzrlib/errors.py:1689
+#: bzrlib/errors.py:1703
 msgid "%(source)s is%(permanently)s redirected to %(target)s"
 msgstr ""
 
-#: bzrlib/errors.py:1703
+#: bzrlib/errors.py:1717
 msgid "Too many redirections"
 msgstr ""
 
-#: bzrlib/errors.py:1708
+#: bzrlib/errors.py:1722
 msgid "Working tree has conflicts."
 msgstr ""
 
-#: bzrlib/errors.py:1712
+#: bzrlib/errors.py:1726
 msgid "Config file %(filename)s is not UTF-8 encoded\n"
 msgstr ""
 
-#: bzrlib/errors.py:1721
+#: bzrlib/errors.py:1735
 msgid ""
 "Error(s) parsing config file %(filename)s:\n"
 "%(errors)s"
 msgstr ""
 
-#: bzrlib/errors.py:1732
+#: bzrlib/errors.py:1746
 msgid "Bad value \"%(value)s\" for option \"%(name)s\"."
 msgstr ""
 
-#: bzrlib/errors.py:1740
+#: bzrlib/errors.py:1754
 msgid "%(username)r does not seem to contain a reasonable email address"
 msgstr ""
 
-#: bzrlib/errors.py:1749
+#: bzrlib/errors.py:1763
 msgid "Failed to GPG sign data with command \"%(command_line)s\""
 msgstr ""
 
-#: bzrlib/errors.py:1757
+#: bzrlib/errors.py:1771
 msgid "Failed to verify GPG signature data with error \"%(error)s\""
 msgstr ""
 
-#: bzrlib/errors.py:1765
+#: bzrlib/errors.py:1779
 msgid "Unable to import library \"%(library)s\": %(error)s"
 msgstr ""
 
-#: bzrlib/errors.py:1773
+#: bzrlib/errors.py:1787
 msgid "python-gpgme is not installed, it is needed to verify signatures"
 msgstr ""
 
-#: bzrlib/errors.py:1781
+#: bzrlib/errors.py:1795
 msgid ""
 "The working tree for %(basedir)s has changed since the last commit, but "
 "weave merge requires that it be unchanged"
 msgstr ""
 
-#: bzrlib/errors.py:1791
+#: bzrlib/errors.py:1805
 msgid ""
 "Can't reprocess and show base, because reprocessing obscures the "
 "relationship of conflicting lines to the base"
 msgstr ""
 
-#: bzrlib/errors.py:1797
+#: bzrlib/errors.py:1811
 msgid "Cycle in graph %(graph)r"
 msgstr ""
 
-#: bzrlib/errors.py:1825
+#: bzrlib/errors.py:1839
 msgid "File %(filename)s is not conflicted."
 msgstr ""
 
-#: bzrlib/errors.py:1847
+#: bzrlib/errors.py:1861
 msgid "No bundle was found in \"%(filename)s\"."
 msgstr ""
 
-#: bzrlib/errors.py:1856
+#: bzrlib/errors.py:1870
 msgid "Unable to handle bundle version %(version)s: %(msg)s"
 msgstr ""
 
-#: bzrlib/errors.py:1866
+#: bzrlib/errors.py:1880
 msgid "Branch %(base)s is missing revision %(text_revision)s of %(file_id)s"
 msgstr ""
 
-#: bzrlib/errors.py:1879
+#: bzrlib/errors.py:1893
 msgid "File id {%(file_id)s} already exists in inventory as %(entry)s"
 msgstr ""
 
-#: bzrlib/errors.py:1889
+#: bzrlib/errors.py:1903
 msgid "Key %(key)s is already present in map"
 msgstr ""
 
-#: bzrlib/errors.py:1894
+#: bzrlib/errors.py:1908
 msgid "The prefix %(prefix)s is in the help search path twice."
 msgstr ""
 
-#: bzrlib/errors.py:1904
+#: bzrlib/errors.py:1918
 msgid ""
 "No final name for trans_id %(trans_id)r\n"
 "file-id: %(file_id)r\n"
 "root trans-id: %(root_trans_id)r\n"
 msgstr ""
 
-#: bzrlib/errors.py:1936
+#: bzrlib/errors.py:1950
 msgid "Attempt to reuse a transform that has already been applied."
 msgstr ""
 
-#: bzrlib/errors.py:1941
+#: bzrlib/errors.py:1955
 msgid "Moving the root directory is not supported at this time"
 msgstr ""
 
-#: bzrlib/errors.py:1946
+#: bzrlib/errors.py:1960
 msgid "Failed to rename %(from_path)s to %(to_path)s: %(why)s"
 msgstr ""
 
-#: bzrlib/errors.py:1957
+#: bzrlib/errors.py:1971
 msgid ""
 "Could not move %(from_path)s%(operator)s %(to_path)s%(_has_extra)s%(extra)s"
 msgstr ""
 
-#: bzrlib/errors.py:1993
+#: bzrlib/errors.py:2007
 msgid ""
 "Could not rename %(from_path)s%(operator)s %(to_path)s%(_has_extra)s%(extra)s"
 msgstr ""
 
-#: bzrlib/errors.py:2023
+#: bzrlib/errors.py:2037
 msgid "Unable to import paramiko (required for sftp support): %(error)s"
 msgstr ""
 
-#: bzrlib/errors.py:2031
+#: bzrlib/errors.py:2045
 msgid "Nothing to merge."
 msgstr ""
 
-#: bzrlib/errors.py:2036
+#: bzrlib/errors.py:2050
 msgid "Format %(format)s cannot be initialised by this version of bzr."
 msgstr ""
 
-#: bzrlib/errors.py:2045
+#: bzrlib/errors.py:2059
 msgid ""
 "Cannot convert from format %(from_format)s to format %(format)s.    "
 "%(problem)s"
 msgstr ""
 
-#: bzrlib/errors.py:2057
+#: bzrlib/errors.py:2071
 msgid "Could not find an appropriate Differ for file \"%(path)s\""
 msgstr ""
 
-#: bzrlib/errors.py:2065
+#: bzrlib/errors.py:2079
 msgid "%(exe_name)s could not be found on this machine"
 msgstr ""
 
-#: bzrlib/errors.py:2073
+#: bzrlib/errors.py:2087
 msgid "Diff is not installed on this machine: %(msg)s"
 msgstr ""
 
-#: bzrlib/errors.py:2081
+#: bzrlib/errors.py:2095
 msgid "Diff3 is not installed on this machine."
 msgstr ""
 
-#: bzrlib/errors.py:2087
+#: bzrlib/errors.py:2101
 msgid "The content being inserted is already present."
 msgstr ""
 
-#: bzrlib/errors.py:2092
+#: bzrlib/errors.py:2106
 msgid ""
 "This tree contains left-over files from a failed operation.\n"
 "    Please examine %(limbo_dir)s to see if it contains any files you wish "
@@ -5734,14 +5796,14 @@
 "    keep, and delete it when you are done."
 msgstr ""
 
-#: bzrlib/errors.py:2103
+#: bzrlib/errors.py:2117
 msgid ""
 "This tree contains left-over files from a failed operation.\n"
 "    Please examine %(pending_deletion)s to see if it contains any files you\n"
 "    wish to keep, and delete it when you are done."
 msgstr ""
 
-#: bzrlib/errors.py:2113
+#: bzrlib/errors.py:2127
 msgid ""
 "Unable to delete transform temporary directory %(limbo_dir)s.\n"
 "    Please examine %(limbo_dir)s to see if it contains any files you wish "
@@ -5749,697 +5811,694 @@
 "    keep, and delete it when you are done."
 msgstr ""
 
-#: bzrlib/errors.py:2124
+#: bzrlib/errors.py:2138
 msgid ""
 "Unable to delete transform temporary directory %(pending_deletion)s.  Please "
 "examine %(pending_deletion)s to see if it contains any files you wish to "
 "keep, and delete it when you are done."
 msgstr ""
 
-#: bzrlib/errors.py:2134
+#: bzrlib/errors.py:2148
 msgid "Working tree is out of date, please run 'bzr update'.%(more)s"
 msgstr ""
 
-#: bzrlib/errors.py:2148
+#: bzrlib/errors.py:2162
 msgid "Public branch \"%(public_location)s\" lacks revision \"%(revstring)s\"."
 msgstr ""
 
-#: bzrlib/errors.py:2161
+#: bzrlib/errors.py:2175
 msgid "Error in merge modified format"
 msgstr ""
 
-#: bzrlib/errors.py:2166
+#: bzrlib/errors.py:2180
 msgid "Format error in conflict listings"
 msgstr ""
 
-#: bzrlib/errors.py:2170
+#: bzrlib/errors.py:2184
 msgid ""
 "Inconsistency in dirstate file %(dirstate_path)s.\n"
 "Error: %(description)s"
 msgstr ""
 
-#: bzrlib/errors.py:2181
+#: bzrlib/errors.py:2195
 msgid ""
 "An error has been detected in the repository %(repo_path)s.\n"
 "Please run bzr reconcile on this repository."
 msgstr ""
 
-#: bzrlib/errors.py:2192
+#: bzrlib/errors.py:2206
 msgid ""
 "An inconsistent delta was supplied involving %(path)r, %(file_id)r\n"
 "reason: %(reason)s"
 msgstr ""
 
-#: bzrlib/errors.py:2205
+#: bzrlib/errors.py:2219
 msgid ""
 "An inconsistent delta was supplied: %(delta)r\n"
 "reason: %(reason)s"
 msgstr ""
 
-#: bzrlib/errors.py:2217
+#: bzrlib/errors.py:2231
 msgid "To use this feature you must upgrade your branch at %(path)s."
 msgstr ""
 
-#: bzrlib/errors.py:2226
+#: bzrlib/errors.py:2240
 msgid "To use this feature you must upgrade your repository at %(path)s."
 msgstr ""
 
-#: bzrlib/errors.py:2231
+#: bzrlib/errors.py:2245
 msgid ""
 "To use this feature you must upgrade your branch at %(path)s to a format "
 "which supports rich roots."
 msgstr ""
 
-#: bzrlib/errors.py:2237
+#: bzrlib/errors.py:2251
 msgid "Cannot perform local-only commits on unbound branches."
 msgstr ""
 
-#: bzrlib/errors.py:2242
+#: bzrlib/errors.py:2256
 msgid "The method %(mname)s is not supported on objects of type %(tname)s."
 msgstr ""
 
-#: bzrlib/errors.py:2263
+#: bzrlib/errors.py:2277
 msgid "Ghost tags not supported by format %(format)r."
 msgstr ""
 
-#: bzrlib/errors.py:2271
+#: bzrlib/errors.py:2285
 msgid "File is binary but should be text."
 msgstr ""
 
-#: bzrlib/errors.py:2276
+#: bzrlib/errors.py:2290
 msgid "The path %(path)s is not permitted on this platform"
 msgstr ""
 
-#: bzrlib/errors.py:2285
+#: bzrlib/errors.py:2299
 msgid ""
 "Testament did not match expected value.\n"
 "       For revision_id {%(revision_id)s}, expected {%(expected)s}, measured\n"
 "       {%(measured)s}"
 msgstr ""
 
-#: bzrlib/errors.py:2297
+#: bzrlib/errors.py:2311
 msgid "Not a bzr revision-bundle: %(text)r"
 msgstr ""
 
-#: bzrlib/errors.py:2306
+#: bzrlib/errors.py:2320
 msgid "Bad bzr revision-bundle: %(text)r"
 msgstr ""
 
-#: bzrlib/errors.py:2315
+#: bzrlib/errors.py:2329
 msgid "Malformed bzr revision-bundle header: %(text)r"
 msgstr ""
 
-#: bzrlib/errors.py:2320
+#: bzrlib/errors.py:2334
 msgid "Malformed patches in bzr revision-bundle: %(text)r"
 msgstr ""
 
-#: bzrlib/errors.py:2325
+#: bzrlib/errors.py:2339
 msgid "Malformed footer in bzr revision-bundle: %(text)r"
 msgstr ""
 
-#: bzrlib/errors.py:2330
+#: bzrlib/errors.py:2344
 msgid "End of line marker was not \\n in bzr revision-bundle"
 msgstr ""
 
-#: bzrlib/errors.py:2340
+#: bzrlib/errors.py:2354
 msgid "Bundle format %(bundle_format)s is incompatible with %(other)s"
 msgstr ""
 
-#: bzrlib/errors.py:2350
+#: bzrlib/errors.py:2364
 msgid "Root class for inventory serialization errors"
 msgstr ""
 
-#: bzrlib/errors.py:2354
+#: bzrlib/errors.py:2368
 msgid ""
 "The inventory was not in the expected format:\n"
 " %(msg)s"
 msgstr ""
 
-#: bzrlib/errors.py:2363
+#: bzrlib/errors.py:2377
 msgid "This operation requires rich root data storage"
 msgstr ""
 
-#: bzrlib/errors.py:2376
+#: bzrlib/errors.py:2390
 msgid "Unrecognised value for BZR_SSH environment variable: %(vendor)s"
 msgstr ""
 
-#: bzrlib/errors.py:2385
+#: bzrlib/errors.py:2399
 msgid ""
 "Don't know how to handle SSH connections. Please set BZR_SSH environment "
 "variable."
 msgstr ""
 
-#: bzrlib/errors.py:2392
+#: bzrlib/errors.py:2406
 msgid ""
 "Could not determine revno for {%(revision_id)s} because its ancestry shows a "
 "ghost at {%(ghost_revision_id)s}"
 msgstr ""
 
-#: bzrlib/errors.py:2402
+#: bzrlib/errors.py:2416
 msgid "Ghost revision {%(revision_id)s} cannot be used here."
 msgstr ""
 
-#: bzrlib/errors.py:2453
+#: bzrlib/errors.py:2467
 msgid ""
 "A merge directive must provide either a bundle or a public branch location."
 msgstr ""
 
-#: bzrlib/errors.py:2460
+#: bzrlib/errors.py:2474
 msgid "Bad merge directive payload %(start)r"
 msgstr ""
 
-#: bzrlib/errors.py:2470
+#: bzrlib/errors.py:2484
 msgid "Preview patch does not match requested changes."
 msgstr ""
 
-#: bzrlib/errors.py:2476
+#: bzrlib/errors.py:2490
 msgid "Patch_type was %(patch_type)s, but no patch was supplied."
 msgstr ""
 
-#: bzrlib/errors.py:2486
+#: bzrlib/errors.py:2500
 msgid ""
 "Your branch does not have all of the revisions required in order to merge "
 "this merge directive and the target location specified in the merge "
 "directive is not a branch: %(location)s."
 msgstr ""
 
-#: bzrlib/errors.py:2498
+#: bzrlib/errors.py:2512
 msgid "Unsupported entry kind %(kind)s"
 msgstr ""
 
-#: bzrlib/errors.py:2506
+#: bzrlib/errors.py:2520
 msgid "Can't subsume %(other_tree)s into %(tree)s. %(reason)s"
 msgstr ""
 
-#: bzrlib/errors.py:2516
+#: bzrlib/errors.py:2530
 msgid "Subsume target %(other_tree)s needs to be upgraded."
 msgstr ""
 
-#: bzrlib/errors.py:2535
+#: bzrlib/errors.py:2549
 msgid "No such tag: %(tag_name)s"
 msgstr ""
 
-#: bzrlib/errors.py:2543
+#: bzrlib/errors.py:2557
 msgid "Tags not supported by %(branch)s; you may be able to use bzr upgrade."
 msgstr ""
 
-#: bzrlib/errors.py:2552
+#: bzrlib/errors.py:2566
 msgid "Tag %(tag_name)s already exists."
 msgstr ""
 
-#: bzrlib/errors.py:2560
+#: bzrlib/errors.py:2574
 msgid ""
 "Did not understand bug identifier %(bug_id)s: %(reason)s. See \"bzr help bugs"
 "\" for more information on this feature."
 msgstr ""
 
-#: bzrlib/errors.py:2570
+#: bzrlib/errors.py:2584
 msgid ""
 "The URL for bug tracker \"%(abbreviation)s\" doesn't contain {id}: %(url)s"
 msgstr ""
 
-#: bzrlib/errors.py:2580
+#: bzrlib/errors.py:2594
 msgid ""
 "Cannot find registered bug tracker called %(abbreviation)s on %(branch)s"
 msgstr ""
 
-#: bzrlib/errors.py:2590
+#: bzrlib/errors.py:2604
 msgid "Invalid line in bugs property: '%(line)s'"
 msgstr ""
 
-#: bzrlib/errors.py:2598
+#: bzrlib/errors.py:2612
 msgid "Invalid bug status: '%(status)s'"
 msgstr ""
 
-#: bzrlib/errors.py:2606
+#: bzrlib/errors.py:2620
 msgid "Could not understand response from smart server: %(response_tuple)r"
 msgstr ""
 
-#: bzrlib/errors.py:2645
+#: bzrlib/errors.py:2659
 msgid "Server sent an unexpected error: %(error_tuple)r"
 msgstr ""
 
-#: bzrlib/errors.py:2664
+#: bzrlib/errors.py:2678
 msgid "Unrecognised container format: %(container_format)r"
 msgstr ""
 
-#: bzrlib/errors.py:2672
+#: bzrlib/errors.py:2686
 msgid "Unexpected end of container stream"
 msgstr ""
 
-#: bzrlib/errors.py:2677
+#: bzrlib/errors.py:2691
 msgid "Unknown record type: %(record_type)r"
 msgstr ""
 
-#: bzrlib/errors.py:2685
+#: bzrlib/errors.py:2699
 msgid "Invalid record: %(reason)s"
 msgstr ""
 
-#: bzrlib/errors.py:2693
+#: bzrlib/errors.py:2707
 msgid "Container has data after end marker: %(excess)r"
 msgstr ""
 
-#: bzrlib/errors.py:2701
+#: bzrlib/errors.py:2715
 msgid "Container has multiple records with the same name: %(name)s"
 msgstr ""
 
-#: bzrlib/errors.py:2714
+#: bzrlib/errors.py:2728
 msgid "Corrupt or incompatible data stream: %(reason)s"
 msgstr ""
 
-#: bzrlib/errors.py:2722
+#: bzrlib/errors.py:2736
 msgid "SMTP error: %(error)s"
 msgstr ""
 
-#: bzrlib/errors.py:2730
+#: bzrlib/errors.py:2744
 msgid "No message supplied."
 msgstr ""
 
-#: bzrlib/errors.py:2735
+#: bzrlib/errors.py:2749
 msgid "No mail-to address (--mail-to) or output (-o) specified."
 msgstr ""
 
-#: bzrlib/errors.py:2740
+#: bzrlib/errors.py:2754
 msgid "Unknown mail client: %(mail_client)s"
 msgstr ""
 
-#: bzrlib/errors.py:2748
+#: bzrlib/errors.py:2762
 msgid ""
 "Unable to find mail client with the following names: "
 "%(mail_command_list_string)s"
 msgstr ""
 
-#: bzrlib/errors.py:2758
+#: bzrlib/errors.py:2772
 msgid "SMTP connection to %(host)s refused"
 msgstr ""
 
-#: bzrlib/errors.py:2767
+#: bzrlib/errors.py:2781
 msgid "Please specify smtp_server.  No server at default %(host)s."
 msgstr ""
 
-#: bzrlib/errors.py:2781
+#: bzrlib/errors.py:2795
 msgid ""
 "'%(display_url)s' is not in sync with %(target_url)s.  See bzr help sync-for-"
 "reconfigure."
 msgstr ""
 
-#: bzrlib/errors.py:2793
+#: bzrlib/errors.py:2807
 msgid "'%(display_url)s' is already a branch."
 msgstr ""
 
-#: bzrlib/errors.py:2798
+#: bzrlib/errors.py:2812
 msgid "'%(display_url)s' is already a tree."
 msgstr ""
 
-#: bzrlib/errors.py:2803
+#: bzrlib/errors.py:2817
 msgid "'%(display_url)s' is already a checkout."
 msgstr ""
 
-#: bzrlib/errors.py:2808
+#: bzrlib/errors.py:2822
 msgid "'%(display_url)s' is already a lightweight checkout."
 msgstr ""
 
-#: bzrlib/errors.py:2813
+#: bzrlib/errors.py:2827
 msgid "'%(display_url)s' is already using a shared repository."
 msgstr ""
 
-#: bzrlib/errors.py:2818
+#: bzrlib/errors.py:2832
 msgid "'%(display_url)s' is already standalone."
 msgstr ""
 
-#: bzrlib/errors.py:2823
+#: bzrlib/errors.py:2837
 msgid "Shared repository '%(display_url)s' already creates working trees."
 msgstr ""
 
-#: bzrlib/errors.py:2829
+#: bzrlib/errors.py:2843
 msgid ""
 "Shared repository '%(display_url)s' already doesn't create working trees."
 msgstr ""
 
-#: bzrlib/errors.py:2835
+#: bzrlib/errors.py:2849
 msgid "Requested reconfiguration of '%(display_url)s' is not supported."
 msgstr ""
 
-#: bzrlib/errors.py:2840
+#: bzrlib/errors.py:2854
 msgid "No location could be found to bind to at %(display_url)s."
 msgstr ""
 
-#: bzrlib/errors.py:2845
+#: bzrlib/errors.py:2859
 msgid ""
 "Working tree \"%(display_url)s\" has uncommitted changes (See bzr status)."
 "%(more)s"
 msgstr ""
 
-#: bzrlib/errors.py:2864
+#: bzrlib/errors.py:2878
 msgid ""
 "Working tree \"%(display_url)s\" has shelved changes (See bzr shelve --list)."
 "%(more)s"
 msgstr ""
 
-#: bzrlib/errors.py:2870
+#: bzrlib/errors.py:2884
 msgid "Variable {%(name)s} is not available."
 msgstr ""
 
-#: bzrlib/errors.py:2878
+#: bzrlib/errors.py:2892
 msgid "No template specified."
 msgstr ""
 
-#: bzrlib/errors.py:2883
+#: bzrlib/errors.py:2897
 msgid "Unable to create symlink %(path_str)son this platform"
 msgstr ""
 
-#: bzrlib/errors.py:2898
+#: bzrlib/errors.py:2912
 msgid ""
 "Unsupported timezone format \"%(timezone)s\", options are \"utc\", \"original"
 "\", \"local\"."
 msgstr ""
 
-#: bzrlib/errors.py:2932
+#: bzrlib/errors.py:2946
 msgid ""
 "Unable to encode %(kind)s path %(path)r in user encoding %(user_encoding)s"
 msgstr ""
 
-#: bzrlib/errors.py:2944
+#: bzrlib/errors.py:2958
 msgid "The \"%(config_id)s\" configuration does not exist."
 msgstr ""
 
-#: bzrlib/errors.py:2952
+#: bzrlib/errors.py:2966
 msgid "The \"%(option_name)s\" configuration option does not exist."
 msgstr ""
 
-#: bzrlib/errors.py:2960
+#: bzrlib/errors.py:2974
 msgid "The alias \"%(alias_name)s\" does not exist."
 msgstr ""
 
-#: bzrlib/errors.py:2974
+#: bzrlib/errors.py:2988
 msgid "\"%(alias_name)s\" is not a valid location alias."
 msgstr ""
 
-#: bzrlib/errors.py:2982
+#: bzrlib/errors.py:2996
 msgid "No %(alias_name)s location assigned."
 msgstr ""
 
-#: bzrlib/errors.py:2990
+#: bzrlib/errors.py:3004
 msgid "Cannot bind address \"%(host)s:%(port)i\": %(orig_error)s."
 msgstr ""
 
-#: bzrlib/errors.py:3000
+#: bzrlib/errors.py:3014
 msgid "Unknown rules detected: %(unknowns_str)s."
 msgstr ""
 
-#: bzrlib/errors.py:3011
+#: bzrlib/errors.py:3025
 msgid "Tip change rejected: %(msg)s"
 msgstr ""
 
-#: bzrlib/errors.py:3019
+#: bzrlib/errors.py:3033
 msgid "Shelf corrupt."
 msgstr ""
 
-#: bzrlib/errors.py:3024
+#: bzrlib/errors.py:3038
 msgid "Corruption while decompressing repository file%(orig_error)s"
 msgstr ""
 
-#: bzrlib/errors.py:3036
+#: bzrlib/errors.py:3050
 msgid "No changes are shelved with id \"%(shelf_id)d\"."
 msgstr ""
 
-#: bzrlib/errors.py:3044
+#: bzrlib/errors.py:3058
 msgid "\"%(invalid_id)s\" is not a valid shelf id, try a number instead."
 msgstr ""
 
-#: bzrlib/errors.py:3052
+#: bzrlib/errors.py:3066
 msgid "An attempt to access a url outside the server jail was made: '%(url)s'."
 msgstr ""
 
-#: bzrlib/errors.py:3060
+#: bzrlib/errors.py:3074
 msgid "The user aborted the operation."
 msgstr ""
 
-#: bzrlib/errors.py:3065
+#: bzrlib/errors.py:3079
 msgid "Branching '%(url)s'(%(format)s) must create a working tree."
 msgstr ""
 
-#: bzrlib/errors.py:3075
+#: bzrlib/errors.py:3089
 msgid "No such view: %(view_name)s."
 msgstr ""
 
-#: bzrlib/errors.py:3085
+#: bzrlib/errors.py:3099
 msgid ""
 "Views are not supported by %(tree)s; use 'bzr upgrade' to change your tree "
 "to a later format."
 msgstr ""
 
-#: bzrlib/errors.py:3094
+#: bzrlib/errors.py:3108
 msgid ""
 "Specified file \"%(file_name)s\" is outside the current view: %(view_str)s"
 msgstr ""
 
-#: bzrlib/errors.py:3161
+#: bzrlib/errors.py:3175
 msgid "%(bzrdir)r does not support co-located branches."
 msgstr ""
 
-#: bzrlib/errors.py:3167
+#: bzrlib/errors.py:3181
 msgid ""
 "Unable to determine your name.\n"
 "Please, set your name with the 'whoami' command.\n"
 "E.g. bzr whoami \"Your Name <name@example.com>\""
 msgstr ""
 
-#: bzrlib/errors.py:3176
+#: bzrlib/errors.py:3190
 msgid "Invalid pattern(s) found. %(msg)s"
 msgstr ""
 
-#: bzrlib/errors.py:3184
+#: bzrlib/errors.py:3198
 msgid ""
 "Branch \"%(branch_url)s\" appears to be bound to itself. Please use `bzr "
 "unbind` to fix."
 msgstr ""
 
-#: bzrlib/errors.py:3195
+#: bzrlib/errors.py:3209
 msgid "Loop involving %(refs)r while expanding \"%(string)s\"."
 msgstr ""
 
-#: bzrlib/errors.py:3204
+#: bzrlib/errors.py:3218
 msgid "Option %(name)s is not defined while expanding \"%(string)s\"."
 msgstr ""
 
-#: bzrlib/errors.py:3213
+#: bzrlib/errors.py:3227
 msgid ""
 "No compatible object available for operations from %(source)r to %(target)r."
 msgstr ""
 
-#: bzrlib/errors.py:3223
+#: bzrlib/errors.py:3237
 msgid ""
 "VFS requests over the smart server are not allowed. Encountered: %(method)s, "
 "%(arguments)s."
 msgstr ""
 
-#: bzrlib/errors.py:3233
+#: bzrlib/errors.py:3247
 msgid ""
 "Kind change from %(from_kind)s to %(to_kind)s for %(path)s not supported by "
 "format %(format)r"
 msgstr ""
 
-#: bzrlib/errors.py:3249
+#: bzrlib/errors.py:3259
+msgid ""
+"Missing feature %(feature)s not provided by this version of Bazaar or any "
+"plugin."
+msgstr ""
+
+#: bzrlib/errors.py:3272
 msgid "Binary files section encountered."
 msgstr ""
 
-#: bzrlib/errors.py:3257
+#: bzrlib/errors.py:3280
 msgid ""
 "Malformed patch header.  %(desc)s\n"
 "%(line)r"
 msgstr ""
 
-#: bzrlib/errors.py:3266
+#: bzrlib/errors.py:3289
 msgid ""
 "Malformed hunk header.  %(desc)s\n"
 "%(line)r"
 msgstr ""
 
-#: bzrlib/errors.py:3275
+#: bzrlib/errors.py:3298
 msgid ""
 "Malformed line.  %(desc)s\n"
 "%(line)r"
 msgstr ""
 
-#: bzrlib/errors.py:3285
+#: bzrlib/errors.py:3308
 msgid ""
 "Text contents mismatch at line %(line_no)d.  Original has \"%(orig_line)s\", "
 "but patch says it should be \"%(patch_line)s\""
 msgstr ""
 
-#: bzrlib/export_pot.py:246
+#: bzrlib/errors.py:3319
+msgid "The feature %(feature)s has already been registered."
+msgstr ""
+
+#: bzrlib/export_pot.py:252
 #, python-format
 msgid "Exporting messages from builtin command: %s"
 msgstr ""
 
-#: bzrlib/export_pot.py:265
+#: bzrlib/export_pot.py:271
 msgid "Exporting messages from plugin command: {0} in {1}"
 msgstr ""
 
-#: bzrlib/export_pot.py:286
+#: bzrlib/export_pot.py:292
 #, python-format
 msgid "Exporting message from error: %s"
 msgstr ""
 
-#: bzrlib/fetch.py:97
+#: bzrlib/fetch.py:98
 msgid "Finding revisions"
 msgstr ""
 
-#: bzrlib/fetch.py:102
+#: bzrlib/fetch.py:103
 msgid "Fetching revisions"
 msgstr ""
 
-#: bzrlib/foreign.py:261
+#: bzrlib/foreign.py:262
 msgid "Push into a different VCS without any custom bzr metadata."
 msgstr ""
 
-#: bzrlib/foreign.py:263
+#: bzrlib/foreign.py:264
 msgid ""
 "This will afterwards rebase the local branch on the remote\n"
 "branch unless the --no-rebase option is used, in which case \n"
 "the two branches will be out of sync after the push. "
 msgstr ""
 
-# help of 'directory' option of 'dpush' command
-#: bzrlib/foreign.py:271
-msgid ""
-"Branch to push from, rather than the one containing the working directory."
-msgstr ""
-
 # help of 'no-rebase' option of 'dpush' command
-#: bzrlib/foreign.py:276
+#: bzrlib/foreign.py:277
 msgid "Do not rebase after push."
 msgstr ""
 
-# help of 'strict' option of 'dpush' command
-#: bzrlib/foreign.py:278
-msgid ""
-"Refuse to push if there are uncommitted changes in the working tree, --no-"
-"strict disables the check."
-msgstr ""
-
-#: bzrlib/foreign.py:310
+#: bzrlib/foreign.py:311
 #, python-format
 msgid "Using saved location: %s\n"
 msgstr ""
 
-#: bzrlib/foreign.py:320
+#: bzrlib/foreign.py:321
 msgid ""
 "{0!r} and {1!r} are in the same VCS, lossy push not necessary. Please use "
 "regular push."
 msgstr ""
 
-#: bzrlib/gpg.py:116 bzrlib/gpg.py:454
+#: bzrlib/gpg.py:119 bzrlib/gpg.py:460
 msgid "{0} commits with valid signatures"
 msgstr ""
 
-#: bzrlib/gpg.py:120 bzrlib/gpg.py:459
+#: bzrlib/gpg.py:123 bzrlib/gpg.py:465
 msgid "{0} commit with unknown key"
 msgid_plural "{0} commits with unknown keys"
 msgstr[0] ""
 msgstr[1] ""
 
-#: bzrlib/gpg.py:126 bzrlib/gpg.py:466
+#: bzrlib/gpg.py:129 bzrlib/gpg.py:472
 msgid "{0} commit not valid"
 msgid_plural "{0} commits not valid"
 msgstr[0] ""
 msgstr[1] ""
 
-#: bzrlib/gpg.py:132 bzrlib/gpg.py:473
+#: bzrlib/gpg.py:135 bzrlib/gpg.py:479
 msgid "{0} commit not signed"
 msgid_plural "{0} commits not signed"
 msgstr[0] ""
 msgstr[1] ""
 
-#: bzrlib/gpg.py:138 bzrlib/gpg.py:480
+#: bzrlib/gpg.py:141 bzrlib/gpg.py:486
 msgid "{0} commit with key now expired"
 msgid_plural "{0} commits with key now expired"
 msgstr[0] ""
 msgstr[1] ""
 
-#: bzrlib/gpg.py:336
+#: bzrlib/gpg.py:343
 msgid "No GnuPG key results for pattern: {0}"
 msgstr ""
 
-#: bzrlib/gpg.py:379
+#: bzrlib/gpg.py:386
 msgid "{0} signed {1} commit"
 msgid_plural "{0} signed {1} commits"
 msgstr[0] ""
 msgstr[1] ""
 
-#: bzrlib/gpg.py:396 bzrlib/gpg.py:412
+#: bzrlib/gpg.py:403 bzrlib/gpg.py:419
 msgid "{0} commit by author {1}"
 msgid_plural "{0} commits by author {1}"
 msgstr[0] ""
 msgstr[1] ""
 
-#: bzrlib/gpg.py:426
+#: bzrlib/gpg.py:433
 msgid "Unknown key {0} signed {1} commit"
 msgid_plural "Unknown key {0} signed {1} commits"
 msgstr[0] ""
 msgstr[1] ""
 
-#: bzrlib/gpg.py:444
+#: bzrlib/gpg.py:452
 msgid "{0} commit by author {1} with key {2} now expired"
 msgid_plural "{0} commits by author {1} with key {2} now expired"
 msgstr[0] ""
 msgstr[1] ""
 
-#: bzrlib/groupcompress.py:1737
+#: bzrlib/groupcompress.py:1739
 #, python-format
 msgid "Insert claimed random_id=True, but then inserted %r two times"
 msgstr ""
 
-#: bzrlib/hooks.py:329
+#: bzrlib/hooks.py:331
 #, python-format
 msgid "Introduced in: %s"
 msgstr ""
 
-#: bzrlib/hooks.py:332
+#: bzrlib/hooks.py:334
 #, python-format
 msgid "Deprecated in: %s"
 msgstr ""
 
-#: bzrlib/knit.py:1764 bzrlib/knit.py:1800
+#: bzrlib/knit.py:1766 bzrlib/knit.py:1802
 msgid "Walking content"
 msgstr ""
 
-#: bzrlib/knit.py:3328
+#: bzrlib/knit.py:3330
 msgid "annotating"
 msgstr ""
 
-#: bzrlib/lock.py:547
+#: bzrlib/lock.py:548
 msgid "{0!r} was {1} locked again"
 msgstr ""
 
-#: bzrlib/lockdir.py:320
+#: bzrlib/lockdir.py:321
 #, python-format
 msgid "error removing pending lock: %s"
 msgstr ""
 
-#: bzrlib/lockdir.py:615
+#: bzrlib/lockdir.py:616
 msgid "Unable to obtain"
 msgstr ""
 
-#: bzrlib/lockdir.py:617
+#: bzrlib/lockdir.py:618
 msgid "Lock owner changed for"
 msgstr ""
 
-#: bzrlib/lockdir.py:619
+#: bzrlib/lockdir.py:620
 msgid "{0} lock {1} {2}."
 msgstr ""
 
-#: bzrlib/lockdir.py:626
+#: bzrlib/lockdir.py:627
 #, python-format
 msgid "Will continue to try until %s, unless you press Ctrl-C."
 msgstr ""
 
-#: bzrlib/lockdir.py:628
+#: bzrlib/lockdir.py:629
 msgid "See \"bzr help break-lock\" for more."
 msgstr ""
 
-#: bzrlib/lockdir.py:738
+#: bzrlib/lockdir.py:739
 #, python-format
 msgid ""
 "held by %(user)s on %(hostname)s (process #%(pid)s), acquired %(time_ago)s"
@@ -6454,255 +6513,251 @@
 msgid "invalid direction %r"
 msgstr ""
 
-#: bzrlib/log.py:621
-msgid "Start revision not found in left-hand history of end revision."
-msgstr ""
-
-#: bzrlib/log.py:667
+#: bzrlib/log.py:662
 msgid "Start revision not found in history of end revision."
 msgstr ""
 
-#: bzrlib/log.py:1085 bzrlib/log.py:1143
+#: bzrlib/log.py:1080 bzrlib/log.py:1138
 msgid "Logging revision 0 is invalid."
 msgstr ""
 
-#: bzrlib/log.py:1087 bzrlib/log.py:1145
+#: bzrlib/log.py:1082 bzrlib/log.py:1140
 msgid "Start revision must be older than the end revision."
 msgstr ""
 
-#: bzrlib/log.py:1832
+#: bzrlib/log.py:1827
 #, python-format
 msgid "unknown log formatter: %r"
 msgstr ""
 
-#: bzrlib/log.py:2128
+#: bzrlib/log.py:2123
 msgid "fixes bug"
 msgid_plural "fixes bugs"
 msgstr[0] ""
 msgstr[1] ""
 
-#: bzrlib/merge.py:718
+#: bzrlib/merge.py:689
 msgid "All changes applied successfully."
 msgstr ""
 
-#: bzrlib/merge.py:720
+#: bzrlib/merge.py:691
 #, python-format
 msgid "%d conflicts encountered."
 msgstr ""
 
-#: bzrlib/merge.py:868 bzrlib/merge.py:1956
+#: bzrlib/merge.py:845 bzrlib/merge.py:1933
 msgid "Preparing file merge"
 msgstr ""
 
-#: bzrlib/multiparent.py:424
+#: bzrlib/multiparent.py:426
 msgid "Importing revisions"
 msgstr ""
 
 # help of 'help' option
-#: bzrlib/option.py:524
+#: bzrlib/option.py:526
 msgid "Show help message."
 msgstr ""
 
 # help of 'quiet' option
-#: bzrlib/option.py:526
+#: bzrlib/option.py:528
 msgid "Only display errors and warnings."
 msgstr ""
 
 # help of 'usage' option
-#: bzrlib/option.py:529
+#: bzrlib/option.py:531
 msgid "Show usage message and options."
 msgstr ""
 
 # help of 'verbose' option
-#: bzrlib/option.py:531
+#: bzrlib/option.py:533
 msgid "Display more information."
 msgstr ""
 
 # help of 'change' option
-#: bzrlib/option.py:539
+#: bzrlib/option.py:541
 msgid ""
 "Select changes introduced by the specified revision. See also \"help "
 "revisionspec\"."
 msgstr ""
 
 # help of 'directory' option
-#: bzrlib/option.py:541
+#: bzrlib/option.py:543
 msgid "Branch to operate on, instead of working directory."
 msgstr ""
 
 # help of 'log-format=long' option
-#: bzrlib/option.py:543
+#: bzrlib/option.py:545
 msgid "Detailed log format."
 msgstr ""
 
 # help of 'log-format=gnu-changelog' option
-#: bzrlib/option.py:543
+#: bzrlib/option.py:545
 msgid "Format used by GNU ChangeLog files."
 msgstr ""
 
 # help of 'log-format=line' option
-#: bzrlib/option.py:543
+#: bzrlib/option.py:545
 msgid "Log format with one line per revision."
 msgstr ""
 
 # help of 'log-format=short' option
-#: bzrlib/option.py:543
+#: bzrlib/option.py:545
 msgid "Moderately short log format."
 msgstr ""
 
 # help of 'log-format' option
-#: bzrlib/option.py:543
+#: bzrlib/option.py:545
 msgid "Use specified log format."
 msgstr ""
 
 # title of 'log-format' option
-#: bzrlib/option.py:545
+#: bzrlib/option.py:547
 msgid "Log format"
 msgstr ""
 
 # help of 'merge-type=lca' option
-#: bzrlib/option.py:547
+#: bzrlib/option.py:549
 msgid "LCA-newness merge."
 msgstr ""
 
 # help of 'merge-type=diff3' option
-#: bzrlib/option.py:547
+#: bzrlib/option.py:549
 msgid "Merge using external diff3."
 msgstr ""
 
 # help of 'merge-type=merge3' option
-#: bzrlib/option.py:547
+#: bzrlib/option.py:549
 msgid "Native diff3-style merge."
 msgstr ""
 
 # help of 'merge-type' option
-#: bzrlib/option.py:547
+#: bzrlib/option.py:549
 msgid "Select a particular merge algorithm."
 msgstr ""
 
 # help of 'merge-type=weave' option
-#: bzrlib/option.py:547
+#: bzrlib/option.py:549
 msgid "Weave-based merge."
 msgstr ""
 
 # title of 'merge-type' option
-#: bzrlib/option.py:549
+#: bzrlib/option.py:551
 msgid "Merge algorithm"
 msgstr ""
 
 # help of 'message' option
-#: bzrlib/option.py:552
+#: bzrlib/option.py:554
 msgid "Message string."
 msgstr ""
 
 # help of 'null' option
-#: bzrlib/option.py:554
+#: bzrlib/option.py:556
 msgid "Use an ASCII NUL (\\0) separator rather than a newline."
 msgstr ""
 
 # help of 'overwrite' option
-#: bzrlib/option.py:556
+#: bzrlib/option.py:558
 msgid "Ignore differences between branches and overwrite unconditionally."
 msgstr ""
 
 # help of 'remember' option
-#: bzrlib/option.py:558
+#: bzrlib/option.py:560
 msgid "Remember the specified location as a default."
 msgstr ""
 
 # help of 'reprocess' option
-#: bzrlib/option.py:560
+#: bzrlib/option.py:562
 msgid "Reprocess to reduce spurious conflicts."
 msgstr ""
 
 # help of 'revision' option
-#: bzrlib/option.py:564
+#: bzrlib/option.py:566
 msgid "See \"help revisionspec\" for details."
 msgstr ""
 
 # help of 'show-ids' option
-#: bzrlib/option.py:566
+#: bzrlib/option.py:568
 msgid "Show internal object ids."
 msgstr ""
 
 # help of 'timezone' option
-#: bzrlib/option.py:569
+#: bzrlib/option.py:571
 msgid "Display timezone as local, original, or utc."
 msgstr ""
 
-#: bzrlib/osutils.py:94
+#: bzrlib/osutils.py:100
 msgid "Parameter {0!r} encoding is unsupported by {1} application locale."
 msgstr ""
 
-#: bzrlib/osutils.py:214
+#: bzrlib/osutils.py:220
 msgid "lstat/stat of ({0!r}): {1!r}"
 msgstr ""
 
-#: bzrlib/osutils.py:964 bzrlib/osutils.py:975
+#: bzrlib/osutils.py:997 bzrlib/osutils.py:1008
 #, python-format
 msgid "sorry, %r not allowed in path"
 msgstr ""
 
-#: bzrlib/osutils.py:1193
+#: bzrlib/osutils.py:1226
 #, python-format
 msgid "%r is too short to calculate a relative path"
 msgstr ""
 
-#: bzrlib/plugin.py:142
+#: bzrlib/plugin.py:143
 #, python-format
 msgid "\"%s\" is not a valid <plugin_name>@<plugin_path> description "
 msgstr ""
 
 # help of 'plugin' option of 'bash-completion' command
-#: bzrlib/plugins/bash_completion/bashcomp.py:408
+#: bzrlib/plugins/bash_completion/bashcomp.py:411
 msgid "Enable completions for the selected plugin (default: all plugins)"
 msgstr ""
 
-#: bzrlib/plugins/bash_completion/bashcomp.py:409
+#: bzrlib/plugins/bash_completion/bashcomp.py:412
 msgid "Generate a shell function for bash command line completion."
 msgstr ""
 
-#: bzrlib/plugins/bash_completion/bashcomp.py:411
+#: bzrlib/plugins/bash_completion/bashcomp.py:414
 msgid ""
 "This command generates a shell function which can be used by bash to\n"
 "automatically complete the currently typed command when the user presses\n"
 "the completion key (usually tab)."
 msgstr ""
 
-#: bzrlib/plugins/bash_completion/bashcomp.py:415
+#: bzrlib/plugins/bash_completion/bashcomp.py:418
 msgid ""
 "Commonly used like this:\n"
 "    eval \"`bzr bash-completion`\""
 msgstr ""
 
 # help of 'function-name' option of 'bash-completion' command
-#: bzrlib/plugins/bash_completion/bashcomp.py:421
+#: bzrlib/plugins/bash_completion/bashcomp.py:424
 msgid "Name of the generated function (default: _bzr)"
 msgstr ""
 
 # help of 'function-only' option of 'bash-completion' command
-#: bzrlib/plugins/bash_completion/bashcomp.py:423
+#: bzrlib/plugins/bash_completion/bashcomp.py:426
 msgid "Generate only the shell function, don't enable it"
 msgstr ""
 
-#: bzrlib/plugins/launchpad/__init__.py:79
+#: bzrlib/plugins/launchpad/__init__.py:81
 msgid "Register a branch with launchpad.net."
 msgstr ""
 
-#: bzrlib/plugins/launchpad/__init__.py:81
+#: bzrlib/plugins/launchpad/__init__.py:83
 msgid ""
 "This command lists a bzr branch in the directory of branches on\n"
 "launchpad.net.  Registration allows the branch to be associated with\n"
 "bugs or specifications."
 msgstr ""
 
-#: bzrlib/plugins/launchpad/__init__.py:85
+#: bzrlib/plugins/launchpad/__init__.py:87
 msgid ""
 "Before using this command you must register the project to which the\n"
 "branch belongs, and create an account for yourself on launchpad.net."
 msgstr ""
 
-#: bzrlib/plugins/launchpad/__init__.py:88
+#: bzrlib/plugins/launchpad/__init__.py:90
 msgid ""
 "arguments:\n"
 "    public_url: The publicly visible url for the branch to register.\n"
@@ -6714,7 +6769,7 @@
 "                otherwise error."
 msgstr ""
 
-#: bzrlib/plugins/launchpad/__init__.py:97
+#: bzrlib/plugins/launchpad/__init__.py:99
 msgid ""
 "example:\n"
 "    bzr register-branch http://foo.com/bzr/fooproject.mine \\\n"
@@ -6722,135 +6777,135 @@
 msgstr ""
 
 # help of 'project' option of 'register-branch' command
-#: bzrlib/plugins/launchpad/__init__.py:104
+#: bzrlib/plugins/launchpad/__init__.py:106
 msgid "Launchpad project short name to associate with the branch."
 msgstr ""
 
 # help of 'branch-name' option of 'register-branch' command
-#: bzrlib/plugins/launchpad/__init__.py:111
+#: bzrlib/plugins/launchpad/__init__.py:113
 msgid ""
 "Short name for the branch; by default taken from the last component of the "
 "url."
 msgstr ""
 
 # help of 'branch-title' option of 'register-branch' command
-#: bzrlib/plugins/launchpad/__init__.py:115
+#: bzrlib/plugins/launchpad/__init__.py:117
 msgid "One-sentence description of the branch."
 msgstr ""
 
 # help of 'branch-description' option of 'register-branch' command
-#: bzrlib/plugins/launchpad/__init__.py:118
+#: bzrlib/plugins/launchpad/__init__.py:120
 msgid "Longer description of the purpose or contents of the branch."
 msgstr ""
 
 # help of 'author' option of 'register-branch' command
-#: bzrlib/plugins/launchpad/__init__.py:121
+#: bzrlib/plugins/launchpad/__init__.py:123
 msgid "Branch author's email address, if not yourself."
 msgstr ""
 
 # help of 'link-bug' option of 'register-branch' command
-#: bzrlib/plugins/launchpad/__init__.py:124
+#: bzrlib/plugins/launchpad/__init__.py:126
 msgid "The bug this branch fixes."
 msgstr ""
 
 # help of 'dry-run' option of 'register-branch' command
-#: bzrlib/plugins/launchpad/__init__.py:127
+#: bzrlib/plugins/launchpad/__init__.py:129
 msgid "Prepare the request but don't actually send it."
 msgstr ""
 
-#: bzrlib/plugins/launchpad/__init__.py:149
+#: bzrlib/plugins/launchpad/__init__.py:151
 msgid ""
 "register-branch requires a public branch url - see bzr help register-branch."
 msgstr ""
 
-#: bzrlib/plugins/launchpad/__init__.py:157
+#: bzrlib/plugins/launchpad/__init__.py:159
 msgid "--product is deprecated; please use --project."
 msgstr ""
 
-#: bzrlib/plugins/launchpad/__init__.py:189
+#: bzrlib/plugins/launchpad/__init__.py:191
 msgid "Open a Launchpad branch page in your web browser."
 msgstr ""
 
 # help of 'dry-run' option of 'launchpad-open' command
-#: bzrlib/plugins/launchpad/__init__.py:194
+#: bzrlib/plugins/launchpad/__init__.py:196
 msgid "Do not actually open the browser. Just say the URL we would use."
 msgstr ""
 
-#: bzrlib/plugins/launchpad/__init__.py:229
+#: bzrlib/plugins/launchpad/__init__.py:231
 #, python-format
 msgid "Opening %s in web browser"
 msgstr ""
 
-#: bzrlib/plugins/launchpad/__init__.py:239
+#: bzrlib/plugins/launchpad/__init__.py:241
 msgid "Show or set the Launchpad user ID."
 msgstr ""
 
-#: bzrlib/plugins/launchpad/__init__.py:241
+#: bzrlib/plugins/launchpad/__init__.py:243
 msgid ""
 "When communicating with Launchpad, some commands need to know your\n"
 "Launchpad user ID.  This command can be used to set or show the\n"
 "user ID that Bazaar will use for such communication."
 msgstr ""
 
-#: bzrlib/plugins/launchpad/__init__.py:245
+#: bzrlib/plugins/launchpad/__init__.py:247
 msgid ""
 ":Examples:\n"
 "  Show the Launchpad ID of the current user::"
 msgstr ""
 
-#: bzrlib/plugins/launchpad/__init__.py:248
+#: bzrlib/plugins/launchpad/__init__.py:250
 msgid "      bzr launchpad-login"
 msgstr ""
 
-#: bzrlib/plugins/launchpad/__init__.py:250
+#: bzrlib/plugins/launchpad/__init__.py:252
 msgid "  Set the Launchpad ID of the current user to 'bob'::"
 msgstr ""
 
-#: bzrlib/plugins/launchpad/__init__.py:252
+#: bzrlib/plugins/launchpad/__init__.py:254
 msgid "      bzr launchpad-login bob"
 msgstr ""
 
 # help of 'no-check' option of 'launchpad-login' command
-#: bzrlib/plugins/launchpad/__init__.py:259
+#: bzrlib/plugins/launchpad/__init__.py:261
 msgid "Don't check that the user name is valid."
 msgstr ""
 
-#: bzrlib/plugins/launchpad/__init__.py:274
-#: bzrlib/plugins/launchpad/__init__.py:285
+#: bzrlib/plugins/launchpad/__init__.py:276
+#: bzrlib/plugins/launchpad/__init__.py:287
 msgid "Launchpad user ID exists and has SSH keys.\n"
 msgstr ""
 
-#: bzrlib/plugins/launchpad/__init__.py:277
+#: bzrlib/plugins/launchpad/__init__.py:279
 msgid "No Launchpad user ID configured.\n"
 msgstr ""
 
-#: bzrlib/plugins/launchpad/__init__.py:288
+#: bzrlib/plugins/launchpad/__init__.py:290
 #, python-format
 msgid "Launchpad user ID set to '%s'.\n"
 msgstr ""
 
-#: bzrlib/plugins/launchpad/__init__.py:296
+#: bzrlib/plugins/launchpad/__init__.py:298
 msgid "Ask Launchpad to mirror a branch now."
 msgstr ""
 
-#: bzrlib/plugins/launchpad/__init__.py:316
+#: bzrlib/plugins/launchpad/__init__.py:318
 msgid "Propose merging a branch on Launchpad."
 msgstr ""
 
-#: bzrlib/plugins/launchpad/__init__.py:318
+#: bzrlib/plugins/launchpad/__init__.py:320
 msgid ""
 "This will open your usual editor to provide the initial comment.  When it\n"
 "has created the proposal, it will open it in your default web browser."
 msgstr ""
 
-#: bzrlib/plugins/launchpad/__init__.py:321
+#: bzrlib/plugins/launchpad/__init__.py:323
 msgid ""
 "The branch will be proposed to merge into SUBMIT_BRANCH.  If SUBMIT_BRANCH\n"
 "is not supplied, the remembered submit branch will be used.  If no submit\n"
 "branch is remembered, the development focus will be used."
 msgstr ""
 
-#: bzrlib/plugins/launchpad/__init__.py:325
+#: bzrlib/plugins/launchpad/__init__.py:327
 msgid ""
 "By default, the SUBMIT_BRANCH's review team will be requested to review\n"
 "the merge proposal.  This can be overriden by specifying --review (-R).\n"
@@ -6858,41 +6913,41 @@
 "may optionally be followed by '=' and the review type.  For example:"
 msgstr ""
 
-#: bzrlib/plugins/launchpad/__init__.py:330
+#: bzrlib/plugins/launchpad/__init__.py:332
 msgid "  bzr lp-propose-merge --review jrandom --review review-team=qa"
 msgstr ""
 
-#: bzrlib/plugins/launchpad/__init__.py:332
+#: bzrlib/plugins/launchpad/__init__.py:334
 msgid ""
 "This will propose a merge,  request \"jrandom\" to perform a review of\n"
 "unspecified type, and request \"review-team\" to perform a \"qa\" review."
 msgstr ""
 
 # help of 'staging' option of 'lp-propose-merge' command
-#: bzrlib/plugins/launchpad/__init__.py:337
+#: bzrlib/plugins/launchpad/__init__.py:339
 msgid "Propose the merge on staging."
 msgstr ""
 
 # help of 'message' option of 'lp-propose-merge' command
-#: bzrlib/plugins/launchpad/__init__.py:339
+#: bzrlib/plugins/launchpad/__init__.py:341
 msgid "Commit message."
 msgstr ""
 
 # help of 'approve' option of 'lp-propose-merge' command
-#: bzrlib/plugins/launchpad/__init__.py:341
+#: bzrlib/plugins/launchpad/__init__.py:343
 msgid "Mark the proposal as approved immediately."
 msgstr ""
 
 # help of 'review' option of 'lp-propose-merge' command
-#: bzrlib/plugins/launchpad/__init__.py:343
+#: bzrlib/plugins/launchpad/__init__.py:345
 msgid "Requested reviewer and optional type."
 msgstr ""
 
-#: bzrlib/plugins/launchpad/__init__.py:380
+#: bzrlib/plugins/launchpad/__init__.py:382
 msgid "Find the proposal to merge this revision."
 msgstr ""
 
-#: bzrlib/plugins/launchpad/__init__.py:382
+#: bzrlib/plugins/launchpad/__init__.py:384
 msgid ""
 "Finds the merge proposal(s) that discussed landing the specified revision.\n"
 "This works only if the selected branch was the merge proposal target, and\n"
@@ -6900,241 +6955,241 @@
 "are opened in a web browser."
 msgstr ""
 
-#: bzrlib/plugins/launchpad/__init__.py:387
+#: bzrlib/plugins/launchpad/__init__.py:389
 msgid ""
 "Any revision involved in the merge may be specified-- the revision in\n"
 "which the merge was performed, or one of the revisions that was merged."
 msgstr ""
 
-#: bzrlib/plugins/launchpad/__init__.py:390
+#: bzrlib/plugins/launchpad/__init__.py:392
 msgid "So, to find the merge proposal that reviewed line 1 of README::"
 msgstr ""
 
-#: bzrlib/plugins/launchpad/__init__.py:392
+#: bzrlib/plugins/launchpad/__init__.py:394
 msgid "  bzr lp-find-proposal -r annotate:README:1"
 msgstr ""
 
-#: bzrlib/plugins/launchpad/__init__.py:407
+#: bzrlib/plugins/launchpad/__init__.py:409
 msgid "No review found."
 msgstr ""
 
-#: bzrlib/plugins/launchpad/__init__.py:408
+#: bzrlib/plugins/launchpad/__init__.py:410
 #, python-format
 msgid "%d proposals(s) found."
 msgstr ""
 
-#: bzrlib/plugins/launchpad/__init__.py:418
+#: bzrlib/plugins/launchpad/__init__.py:420
 msgid "Finding revision-id"
 msgstr ""
 
-#: bzrlib/plugins/launchpad/__init__.py:425
+#: bzrlib/plugins/launchpad/__init__.py:427
 msgid "Finding merge"
 msgstr ""
 
-#: bzrlib/plugins/launchpad/__init__.py:430
+#: bzrlib/plugins/launchpad/__init__.py:432
 msgid "Finding revno"
 msgstr ""
 
-#: bzrlib/plugins/launchpad/__init__.py:435
+#: bzrlib/plugins/launchpad/__init__.py:437
 msgid "Finding Launchpad branch"
 msgstr ""
 
-#: bzrlib/plugins/launchpad/__init__.py:438
+#: bzrlib/plugins/launchpad/__init__.py:440
 msgid "Finding proposals"
 msgstr ""
 
-#: bzrlib/plugins/launchpad/account.py:64
+#: bzrlib/plugins/launchpad/account.py:66
 msgid "Setting ssh/sftp usernames for launchpad.net."
 msgstr ""
 
-#: bzrlib/plugins/launchpad/lp_api.py:239
-#: bzrlib/plugins/launchpad/lp_api.py:244
+#: bzrlib/plugins/launchpad/lp_api.py:241
+#: bzrlib/plugins/launchpad/lp_api.py:246
 #, python-format
 msgid "%s is not registered on Launchpad"
 msgstr ""
 
-#: bzrlib/plugins/launchpad/lp_api.py:254
+#: bzrlib/plugins/launchpad/lp_api.py:256
 #, python-format
 msgid "%s has no development focus."
 msgstr ""
 
-#: bzrlib/plugins/launchpad/lp_api.py:259
+#: bzrlib/plugins/launchpad/lp_api.py:261
 #, python-format
 msgid "development focus %s has no branch."
 msgstr ""
 
-#: bzrlib/plugins/launchpad/lp_api.py:264
+#: bzrlib/plugins/launchpad/lp_api.py:266
 #, python-format
 msgid "source package %s has no branch."
 msgstr ""
 
-#: bzrlib/plugins/launchpad/lp_api.py:268
+#: bzrlib/plugins/launchpad/lp_api.py:270
 #, python-format
 msgid "%s has no associated product or source package."
 msgstr ""
 
-#: bzrlib/plugins/launchpad/lp_api.py:280
+#: bzrlib/plugins/launchpad/lp_api.py:282
 #, python-format
 msgid "%s is already up-to-date."
 msgstr ""
 
-#: bzrlib/plugins/launchpad/lp_api.py:287
+#: bzrlib/plugins/launchpad/lp_api.py:289
 #, python-format
 msgid "Pushing to %s"
 msgstr ""
 
-#: bzrlib/plugins/launchpad/lp_directory.py:169
+#: bzrlib/plugins/launchpad/lp_directory.py:170
 msgid ""
 "resolution for {0}\n"
 "  local: {1}\n"
 " remote: {2}"
 msgstr ""
 
-#: bzrlib/plugins/launchpad/lp_propose.py:147
+#: bzrlib/plugins/launchpad/lp_propose.py:149
 #, python-format
 msgid "There is already a branch merge proposal: %s"
 msgstr ""
 
-#: bzrlib/plugins/weave_fmt/bzrdir.py:226
+#: bzrlib/plugins/weave_fmt/bzrdir.py:236
 msgid "pb parameter to convert() is deprecated"
 msgstr ""
 
-#: bzrlib/plugins/weave_fmt/bzrdir.py:229
+#: bzrlib/plugins/weave_fmt/bzrdir.py:239
 msgid "starting upgrade from format 4 to 5"
 msgstr ""
 
-#: bzrlib/plugins/weave_fmt/bzrdir.py:239
+#: bzrlib/plugins/weave_fmt/bzrdir.py:249
 msgid "note: upgrade may be faster if all store files are ungzipped first"
 msgstr ""
 
-#: bzrlib/plugins/weave_fmt/bzrdir.py:268
+#: bzrlib/plugins/weave_fmt/bzrdir.py:278
 msgid "converting revision"
 msgstr ""
 
-#: bzrlib/plugins/weave_fmt/bzrdir.py:273
+#: bzrlib/plugins/weave_fmt/bzrdir.py:283
 msgid "upgraded to weaves:"
 msgstr ""
 
-#: bzrlib/plugins/weave_fmt/bzrdir.py:274
+#: bzrlib/plugins/weave_fmt/bzrdir.py:284
 #, python-format
 msgid "%6d revisions and inventories"
 msgstr ""
 
-#: bzrlib/plugins/weave_fmt/bzrdir.py:276
+#: bzrlib/plugins/weave_fmt/bzrdir.py:286
 #, python-format
 msgid "%6d revisions not present"
 msgstr ""
 
-#: bzrlib/plugins/weave_fmt/bzrdir.py:278
+#: bzrlib/plugins/weave_fmt/bzrdir.py:288
 #, python-format
 msgid "%6d texts"
 msgstr ""
 
-#: bzrlib/plugins/weave_fmt/bzrdir.py:314
+#: bzrlib/plugins/weave_fmt/bzrdir.py:324
 msgid "writing weave"
 msgstr ""
 
-#: bzrlib/plugins/weave_fmt/bzrdir.py:318
-#: bzrlib/plugins/weave_fmt/bzrdir.py:320
+#: bzrlib/plugins/weave_fmt/bzrdir.py:328
+#: bzrlib/plugins/weave_fmt/bzrdir.py:330
 msgid "inventory"
 msgstr ""
 
-#: bzrlib/plugins/weave_fmt/bzrdir.py:337
+#: bzrlib/plugins/weave_fmt/bzrdir.py:347
 msgid "write revision"
 msgstr ""
 
-#: bzrlib/plugins/weave_fmt/bzrdir.py:351
+#: bzrlib/plugins/weave_fmt/bzrdir.py:361
 msgid "loading revision"
 msgstr ""
 
-#: bzrlib/plugins/weave_fmt/bzrdir.py:356
+#: bzrlib/plugins/weave_fmt/bzrdir.py:366
 #, python-format
 msgid "revision {%s} not present in branch; will be converted as a ghost"
 msgstr ""
 
-#: bzrlib/plugins/weave_fmt/bzrdir.py:496
+#: bzrlib/plugins/weave_fmt/bzrdir.py:506
 msgid "starting upgrade from format 5 to 6"
 msgstr ""
 
-#: bzrlib/plugins/weave_fmt/bzrdir.py:506
+#: bzrlib/plugins/weave_fmt/bzrdir.py:516
 #, python-format
 msgid "adding prefixes to %s"
 msgstr ""
 
-#: bzrlib/plugins/weave_fmt/bzrdir.py:546
+#: bzrlib/plugins/weave_fmt/bzrdir.py:556
 msgid "starting upgrade from format 6 to metadir"
 msgstr ""
 
-#: bzrlib/plugins/weave_fmt/bzrdir.py:554
+#: bzrlib/plugins/weave_fmt/bzrdir.py:564
 msgid "Removing ancestry.weave"
 msgstr ""
 
-#: bzrlib/plugins/weave_fmt/bzrdir.py:559
+#: bzrlib/plugins/weave_fmt/bzrdir.py:569
 msgid "Finding branch files"
 msgstr ""
 
-#: bzrlib/plugins/weave_fmt/bzrdir.py:569
+#: bzrlib/plugins/weave_fmt/bzrdir.py:579
 msgid "Upgrading repository"
 msgstr ""
 
-#: bzrlib/plugins/weave_fmt/bzrdir.py:579
+#: bzrlib/plugins/weave_fmt/bzrdir.py:589
 msgid "Upgrading branch"
 msgstr ""
 
-#: bzrlib/plugins/weave_fmt/bzrdir.py:602
+#: bzrlib/plugins/weave_fmt/bzrdir.py:612
 msgid "No working tree."
 msgstr ""
 
-#: bzrlib/plugins/weave_fmt/bzrdir.py:609
+#: bzrlib/plugins/weave_fmt/bzrdir.py:619
 msgid "Upgrading working tree"
 msgstr ""
 
-#: bzrlib/plugins/weave_fmt/bzrdir.py:630
+#: bzrlib/plugins/weave_fmt/bzrdir.py:640
 #, python-format
 msgid "Make %s lock"
 msgstr ""
 
-#: bzrlib/plugins/weave_fmt/bzrdir.py:641
+#: bzrlib/plugins/weave_fmt/bzrdir.py:651
 #, python-format
 msgid "Moving %s"
 msgstr ""
 
-#: bzrlib/push.py:54
+#: bzrlib/push.py:56
 msgid "Created new branch."
 msgstr ""
 
-#: bzrlib/push.py:96
+#: bzrlib/push.py:98
 #, python-format
 msgid ""
 "Target directory %s already contains a .bzr directory, but it is not valid."
 msgstr ""
 
-#: bzrlib/push.py:99
+#: bzrlib/push.py:101
 #, python-format
 msgid ""
 "Target directory %s already exists, but does not have a .bzr directory. "
 "Supply --use-existing-dir to push there anyway."
 msgstr ""
 
-#: bzrlib/push.py:120
+#: bzrlib/push.py:122
 #, python-format
 msgid "Too many redirections trying to make %s."
 msgstr ""
 
-#: bzrlib/push.py:145
+#: bzrlib/push.py:147
 msgid ""
 "These branches have diverged.  See \"bzr help diverged-branches\" for more "
 "information."
 msgstr ""
 
-#: bzrlib/push.py:149
+#: bzrlib/push.py:151
 #, python-format
 msgid ""
 "It is not possible to losslessly push to %s. You may want to use dpush "
 "instead."
 msgstr ""
 
-#: bzrlib/push.py:155
+#: bzrlib/push.py:157
 #, python-format
 msgid ""
 "At %s you have a valid .bzr control directory, but not a branch or "
@@ -7142,505 +7197,505 @@
 "directory out of the way and try again."
 msgstr ""
 
-#: bzrlib/reconcile.py:96
+#: bzrlib/reconcile.py:97
 #, python-format
 msgid "Reconciling branch %s"
 msgstr ""
 
-#: bzrlib/reconcile.py:102
+#: bzrlib/reconcile.py:103
 #, python-format
 msgid "Reconciling repository %s"
 msgstr ""
 
-#: bzrlib/reconcile.py:104
+#: bzrlib/reconcile.py:105
 msgid "Reconciling repository"
 msgstr ""
 
-#: bzrlib/reconcile.py:110
+#: bzrlib/reconcile.py:111
 #, python-format
 msgid "%s cannot canonicalize CHKs."
 msgstr ""
 
-#: bzrlib/reconcile.py:118
+#: bzrlib/reconcile.py:119
 msgid "Reconcile aborted: revision index has inconsistent parents."
 msgstr ""
 
-#: bzrlib/reconcile.py:120
+#: bzrlib/reconcile.py:121
 msgid "Run \"bzr check\" for more details."
 msgstr ""
 
-#: bzrlib/reconcile.py:122
+#: bzrlib/reconcile.py:123
 msgid "Reconciliation complete."
 msgstr ""
 
-#: bzrlib/reconcile.py:165
+#: bzrlib/reconcile.py:166
 msgid "Fixing last revision info {0}  => {1}"
 msgstr ""
 
-#: bzrlib/reconcile.py:172
+#: bzrlib/reconcile.py:173
 msgid "revision_history ok."
 msgstr ""
 
-#: bzrlib/reconcile.py:233
+#: bzrlib/reconcile.py:234
 msgid "Reading inventory data"
 msgstr ""
 
-#: bzrlib/reconcile.py:253 bzrlib/reconcile.py:383
+#: bzrlib/reconcile.py:254 bzrlib/reconcile.py:384
 msgid "Inventory ok."
 msgstr ""
 
-#: bzrlib/reconcile.py:255 bzrlib/reconcile.py:385
+#: bzrlib/reconcile.py:256 bzrlib/reconcile.py:386
 msgid "Backing up inventory"
 msgstr ""
 
-#: bzrlib/reconcile.py:257
+#: bzrlib/reconcile.py:258
 msgid "Backup inventory created."
 msgstr ""
 
-#: bzrlib/reconcile.py:273 bzrlib/reconcile.py:404
+#: bzrlib/reconcile.py:274 bzrlib/reconcile.py:405
 msgid "Writing weave"
 msgstr ""
 
-#: bzrlib/reconcile.py:276 bzrlib/reconcile.py:407
+#: bzrlib/reconcile.py:277 bzrlib/reconcile.py:408
 msgid "Inventory regenerated."
 msgstr ""
 
-#: bzrlib/reconcile.py:370 bzrlib/reconcile.py:372 bzrlib/reconcile.py:375
+#: bzrlib/reconcile.py:371 bzrlib/reconcile.py:373 bzrlib/reconcile.py:376
 msgid "Reading indexes"
 msgstr ""
 
-#: bzrlib/reconcile.py:379 bzrlib/reconcile.py:381
+#: bzrlib/reconcile.py:380 bzrlib/reconcile.py:382
 msgid "Checking unused inventories"
 msgstr ""
 
-#: bzrlib/reconcile.py:387
+#: bzrlib/reconcile.py:388
 msgid "Backup Inventory created"
 msgstr ""
 
-#: bzrlib/reconcile.py:445
+#: bzrlib/reconcile.py:446
 msgid "Fixing text parents"
 msgstr ""
 
-#: bzrlib/reconfigure.py:52
+#: bzrlib/reconfigure.py:54
 msgid "{0} is now stacked on {1}\n"
 msgstr ""
 
-#: bzrlib/reconfigure.py:67
+#: bzrlib/reconfigure.py:69
 #, python-format
 msgid "%s is now not stacked\n"
 msgstr ""
 
-#: bzrlib/remote.py:1134 bzrlib/repository.py:287
+#: bzrlib/remote.py:1180 bzrlib/repository.py:289
 #, python-format
 msgid "bzr: ERROR (ignored): %s"
 msgstr ""
 
-#: bzrlib/remote.py:2217
+#: bzrlib/remote.py:2493
 msgid "Copying repository content as tarball..."
 msgstr ""
 
-#: bzrlib/rename_map.py:68
+#: bzrlib/rename_map.py:69
 msgid "Calculating hashes"
 msgstr ""
 
-#: bzrlib/rename_map.py:106
+#: bzrlib/rename_map.py:107
 msgid "Determining hash hits"
 msgstr ""
 
-#: bzrlib/rename_map.py:241
+#: bzrlib/rename_map.py:242
 msgid "{0} => {1}"
 msgstr ""
 
-#: bzrlib/repository.py:1781
+#: bzrlib/repository.py:1787
 msgid "Moving repository to repository.backup"
 msgstr ""
 
-#: bzrlib/repository.py:1788
+#: bzrlib/repository.py:1794
 msgid "Creating new repository"
 msgstr ""
 
-#: bzrlib/repository.py:1793
+#: bzrlib/repository.py:1799
 msgid "Copying content"
 msgstr ""
 
-#: bzrlib/repository.py:1797
+#: bzrlib/repository.py:1803
 msgid "Deleting old repository content"
 msgstr ""
 
-#: bzrlib/repository.py:1799
+#: bzrlib/repository.py:1805
 msgid "repository converted"
 msgstr ""
 
-#: bzrlib/revisionspec.py:904
+#: bzrlib/revisionspec.py:903
 msgid "Using {0} {1}"
 msgstr ""
 
-#: bzrlib/send.py:57
+#: bzrlib/send.py:58
 #, python-format
 msgid "Mail client \"%s\" does not support specifying body"
 msgstr ""
 
-#: bzrlib/send.py:61
+#: bzrlib/send.py:62
 msgid "--remember requires a branch to be specified."
 msgstr ""
 
-#: bzrlib/send.py:75
+#: bzrlib/send.py:77
 msgid "No submit branch known or specified"
 msgstr ""
 
-#: bzrlib/send.py:78
+#: bzrlib/send.py:80
 msgid "Using saved {0} location \"{1}\" to determine what changes to submit."
 msgstr ""
 
-#: bzrlib/send.py:95
+#: bzrlib/send.py:98
 #, python-format
 msgid "No such send format '%s'."
 msgstr ""
 
-#: bzrlib/send.py:112
+#: bzrlib/send.py:114
 msgid "bzr send takes at most two one revision identifiers"
 msgstr ""
 
-#: bzrlib/send.py:125
+#: bzrlib/send.py:127
 msgid "No revisions to submit."
 msgstr ""
 
-#: bzrlib/send.py:136
+#: bzrlib/send.py:139
 msgid ""
 "- not supported for merge directives that use more than one output file."
 msgstr ""
 
-#: bzrlib/send.py:178
+#: bzrlib/send.py:185
 msgid "Format 0.9 does not permit bundle with no patch"
 msgstr ""
 
-#: bzrlib/shelf_ui.py:45
+#: bzrlib/shelf_ui.py:46
 #, python-format
 msgid "Shelve adding file \"%(path)s\"?"
 msgstr ""
 
-#: bzrlib/shelf_ui.py:46
+#: bzrlib/shelf_ui.py:47
 msgid "Shelve binary changes?"
 msgstr ""
 
-#: bzrlib/shelf_ui.py:47
+#: bzrlib/shelf_ui.py:48
 msgid "Shelve changing \"%s\" from %(other)s to %(this)s?"
 msgstr ""
 
-#: bzrlib/shelf_ui.py:49
+#: bzrlib/shelf_ui.py:50
 #, python-format
 msgid "Shelve removing file \"%(path)s\"?"
 msgstr ""
 
-#: bzrlib/shelf_ui.py:50
+#: bzrlib/shelf_ui.py:51
 #, python-format
 msgid "Shelve %d change(s)?"
 msgstr ""
 
-#: bzrlib/shelf_ui.py:51
+#: bzrlib/shelf_ui.py:52
 msgid "Shelve?"
 msgstr ""
 
-#: bzrlib/shelf_ui.py:52
+#: bzrlib/shelf_ui.py:53
 #, python-format
 msgid ""
 "Shelve changing target of \"%(path)s\" from \"%(other)s\" to \"%(this)s\"?"
 msgstr ""
 
-#: bzrlib/shelf_ui.py:54
+#: bzrlib/shelf_ui.py:55
 #, python-format
 msgid "Shelve renaming \"%(other)s\" => \"%(this)s\"?"
 msgstr ""
 
-#: bzrlib/shelf_ui.py:69
+#: bzrlib/shelf_ui.py:70
 #, python-format
 msgid "Changes shelved with id \"%d\"."
 msgstr ""
 
-#: bzrlib/shelf_ui.py:73
+#: bzrlib/shelf_ui.py:74
 msgid "Selected changes destroyed."
 msgstr ""
 
-#: bzrlib/shelf_ui.py:77
+#: bzrlib/shelf_ui.py:78
 msgid "Selected changes:"
 msgstr ""
 
-#: bzrlib/shelf_ui.py:97
+#: bzrlib/shelf_ui.py:98
 #, python-format
 msgid "Delete file \"%(path)s\"?"
 msgstr ""
 
-#: bzrlib/shelf_ui.py:98
+#: bzrlib/shelf_ui.py:99
 msgid "Apply binary changes?"
 msgstr ""
 
-#: bzrlib/shelf_ui.py:99
+#: bzrlib/shelf_ui.py:100
 #, python-format
 msgid "Change \"%(path)s\" from %(this)s to %(other)s?"
 msgstr ""
 
-#: bzrlib/shelf_ui.py:101
+#: bzrlib/shelf_ui.py:102
 #, python-format
 msgid "Add file \"%(path)s\"?"
 msgstr ""
 
-#: bzrlib/shelf_ui.py:102
+#: bzrlib/shelf_ui.py:103
 #, python-format
 msgid "Apply %d change(s)?"
 msgstr ""
 
-#: bzrlib/shelf_ui.py:103
+#: bzrlib/shelf_ui.py:104
 msgid "Apply change?"
 msgstr ""
 
-#: bzrlib/shelf_ui.py:104
+#: bzrlib/shelf_ui.py:105
 #, python-format
 msgid "Change target of \"%(path)s\" from \"%(this)s\" to \"%(other)s\"?"
 msgstr ""
 
-#: bzrlib/shelf_ui.py:106
+#: bzrlib/shelf_ui.py:107
 #, python-format
 msgid "Rename \"%(this)s\" => \"%(other)s\"?"
 msgstr ""
 
-#: bzrlib/shelf_ui.py:401
+#: bzrlib/shelf_ui.py:402
 msgid "No changes are shelved."
 msgstr ""
 
-#: bzrlib/shelf_ui.py:459
+#: bzrlib/shelf_ui.py:460
 #, python-format
 msgid "Using changes with id \"%d\"."
 msgstr ""
 
-#: bzrlib/shelf_ui.py:463
+#: bzrlib/shelf_ui.py:464
 #, python-format
 msgid "Message: %s"
 msgstr ""
 
-#: bzrlib/shelf_ui.py:475
+#: bzrlib/shelf_ui.py:476
 #, python-format
 msgid "Deleted changes with id \"%d\"."
 msgstr ""
 
-#: bzrlib/smart/medium.py:712
+#: bzrlib/smart/medium.py:714
 msgid "HPSS calls: {0} ({1} vfs) {2}"
 msgstr ""
 
-#: bzrlib/smart/server.py:167
+#: bzrlib/smart/server.py:169
 msgid "Requested to stop gracefully"
 msgstr ""
 
-#: bzrlib/smart/server.py:177
+#: bzrlib/smart/server.py:179
 #, python-format
 msgid "Waiting for %d client(s) to finish"
 msgstr ""
 
-#: bzrlib/smart/server.py:183
+#: bzrlib/smart/server.py:185
 #, python-format
 msgid "Still waiting for %d client(s) to finish"
 msgstr ""
 
-#: bzrlib/smart/server.py:217
+#: bzrlib/smart/server.py:219
 #, python-format
 msgid "listening socket error: %s"
 msgstr ""
 
-#: bzrlib/smart/server.py:450
+#: bzrlib/smart/server.py:452
 #, python-format
 msgid "listening on port: %s"
 msgstr ""
 
-#: bzrlib/switch.py:67
+#: bzrlib/switch.py:69
 msgid "Pending merges must be committed or reverted before using switch."
 msgstr ""
 
-#: bzrlib/switch.py:94
+#: bzrlib/switch.py:96
 msgid ""
 "Cannot switch as local commits found in the checkout. Commit these to the "
 "bound branch or use --force to throw them away."
 msgstr ""
 
-#: bzrlib/switch.py:99
+#: bzrlib/switch.py:101
 #, python-format
 msgid ""
 "Unable to connect to current master branch %(target)s: %(error)s To switch "
 "anyway, use --force."
 msgstr ""
 
-#: bzrlib/switch.py:108
+#: bzrlib/switch.py:110
 msgid "Cannot switch a branch, only a checkout."
 msgstr ""
 
-#: bzrlib/switch.py:144
+#: bzrlib/switch.py:146
 #, python-format
 msgid "Tree is up to date at revision %d."
 msgstr ""
 
-#: bzrlib/switch.py:150
+#: bzrlib/switch.py:152
 #, python-format
 msgid "Updated to revision %d."
 msgstr ""
 
-#: bzrlib/transform.py:1723 bzrlib/transform.py:1734 bzrlib/transform.py:1736
+#: bzrlib/transform.py:1730 bzrlib/transform.py:1741 bzrlib/transform.py:1743
 msgid "Apply phase"
 msgstr ""
 
-#: bzrlib/transform.py:1762 bzrlib/transform.py:1830
+#: bzrlib/transform.py:1769 bzrlib/transform.py:1837
 msgid "removing file"
 msgstr ""
 
-#: bzrlib/transform.py:1780 bzrlib/transform.py:1865
+#: bzrlib/transform.py:1787 bzrlib/transform.py:1872
 msgid "adding file"
 msgstr ""
 
-#: bzrlib/transform.py:2580
+#: bzrlib/transform.py:2587
 msgid "Building tree"
 msgstr ""
 
-#: bzrlib/transform.py:2670 bzrlib/transform.py:2697
+#: bzrlib/transform.py:2677 bzrlib/transform.py:2704
 msgid "Adding file contents"
 msgstr ""
 
-#: bzrlib/transform.py:3017
+#: bzrlib/transform.py:3024
 msgid "Resolution pass"
 msgstr ""
 
-#: bzrlib/transport/ftp/_gssapi.py:86
+#: bzrlib/transport/ftp/_gssapi.py:88
 #, python-format
 msgid "Authenticated as %s"
 msgstr ""
 
-#: bzrlib/tree.py:632
+#: bzrlib/tree.py:634
 msgid "*** {0} content-filter: {1} => {2!r}"
 msgstr ""
 
-#: bzrlib/upgrade.py:76
+#: bzrlib/upgrade.py:77
 #, python-format
 msgid "This is a checkout. The branch (%s) needs to be upgraded separately."
 msgstr ""
 
-#: bzrlib/upgrade.py:99
+#: bzrlib/upgrade.py:100
 #, python-format
 msgid "cannot upgrade from bzrdir format %s"
 msgstr ""
 
-#: bzrlib/upgrade.py:102
+#: bzrlib/upgrade.py:103
 #, python-format
 msgid "starting upgrade of %s"
 msgstr ""
 
-#: bzrlib/upgrade.py:109
+#: bzrlib/upgrade.py:110
 msgid "finished"
 msgstr ""
 
-#: bzrlib/upgrade.py:119
+#: bzrlib/upgrade.py:120
 msgid "Deleting backup.bzr"
 msgstr ""
 
-#: bzrlib/upgrade.py:150
+#: bzrlib/upgrade.py:151
 msgid ""
 "\n"
 "SUMMARY: {0} upgrades attempted, {1} succeeded, {2} failed"
 msgstr ""
 
-#: bzrlib/upgrade.py:207
+#: bzrlib/upgrade.py:208
 #, python-format
 msgid "Found %d dependent branches - upgrading ..."
 msgstr ""
 
-#: bzrlib/upgrade.py:275
+#: bzrlib/upgrade.py:276
 msgid "Upgrading bzrdirs"
 msgstr ""
 
-#: bzrlib/upgrade.py:281
+#: bzrlib/upgrade.py:282
 #, python-format
 msgid "Upgrading %s"
 msgstr ""
 
-#: bzrlib/upgrade.py:282
+#: bzrlib/upgrade.py:283
 msgid "Upgrading {0} {1} ..."
 msgstr ""
 
-#: bzrlib/upgrade.py:300
+#: bzrlib/upgrade.py:301
 msgid "Removing backup ..."
 msgstr ""
 
-#: bzrlib/upgrade.py:304
+#: bzrlib/upgrade.py:305
 msgid "failed to clean-up {0}: {1}"
 msgstr ""
 
-#: bzrlib/vf_repository.py:1093
+#: bzrlib/vf_repository.py:1090
 msgid "inventories"
 msgstr ""
 
-#: bzrlib/vf_repository.py:1119
+#: bzrlib/vf_repository.py:1116
 msgid "texts"
 msgstr ""
 
-#: bzrlib/vf_repository.py:1624 bzrlib/vf_repository.py:1633
+#: bzrlib/vf_repository.py:1621 bzrlib/vf_repository.py:1630
 msgid "Calculating text parents"
 msgstr ""
 
-#: bzrlib/vf_repository.py:1709
+#: bzrlib/vf_repository.py:1706
 msgid "Fetch texts"
 msgstr ""
 
-#: bzrlib/vf_repository.py:2538
+#: bzrlib/vf_repository.py:2535
 msgid "loading text store"
 msgstr ""
 
-#: bzrlib/vf_repository.py:2544
+#: bzrlib/vf_repository.py:2541
 msgid "checking text graph"
 msgstr ""
 
-#: bzrlib/vf_repository.py:2998 bzrlib/vf_repository.py:3012
-#: bzrlib/vf_repository.py:3127
+#: bzrlib/vf_repository.py:2995 bzrlib/vf_repository.py:3009
+#: bzrlib/vf_repository.py:3124
 msgid "Transferring revisions"
 msgstr ""
 
-#: bzrlib/win32utils.py:137
+#: bzrlib/win32utils.py:146
 msgid "Failed to GetProcessMemoryInfo()"
 msgstr ""
 
-#: bzrlib/win32utils.py:158
+#: bzrlib/win32utils.py:167
 msgid "Cannot debug memory on win32 without ctypes or win32process"
 msgstr ""
 
-#: bzrlib/win32utils.py:163
+#: bzrlib/win32utils.py:172
 msgid "WorkingSize {0:>7}KiB\tPeakWorking {1:>7}KiB\t{2}"
 msgstr ""
 
-#: bzrlib/win32utils.py:171
+#: bzrlib/win32utils.py:180
 #, python-format
 msgid "WorkingSize       %8d KiB"
 msgstr ""
 
-#: bzrlib/win32utils.py:172
+#: bzrlib/win32utils.py:181
 #, python-format
 msgid "PeakWorking       %8d KiB"
 msgstr ""
 
-#: bzrlib/win32utils.py:173
+#: bzrlib/win32utils.py:182
 #, python-format
 msgid "PagefileUsage     %8d KiB"
 msgstr ""
 
-#: bzrlib/win32utils.py:174
+#: bzrlib/win32utils.py:183
 #, python-format
 msgid "PeakPagefileUsage %8d KiB"
 msgstr ""
 
-#: bzrlib/win32utils.py:176
+#: bzrlib/win32utils.py:185
 #, python-format
 msgid "PrivateUsage      %8d KiB"
 msgstr ""
 
-#: bzrlib/win32utils.py:177
+#: bzrlib/win32utils.py:186
 #, python-format
 msgid "PageFaultCount    %8d"
 msgstr ""
 
-#: bzrlib/workingtree.py:1467
+#: bzrlib/workingtree.py:1478
 msgid "Rerun update after fixing the conflicts."
 msgstr ""
 
@@ -7650,7 +7705,7 @@
 
 #: dummy/help_topics/basic/detail.txt:1
 msgid ""
-"Bazaar 2.5b4 -- a free distributed version-control tool\n"
+"Bazaar 2.5b5 -- a free distributed version-control tool\n"
 "http://bazaar.canonical.com/"
 msgstr ""
 
@@ -7721,6 +7776,8 @@
 msgstr ""
 
 #: dummy/help_topics/branches/detail.txt:15
+#: dummy/help_topics/checkouts/detail.txt:66
+#: dummy/help_topics/repositories/detail.txt:36
 msgid "Related commands::"
 msgstr ""
 
@@ -9009,7 +9066,7 @@
 msgid "    bzr commit --fixes <tracker>:<id>"
 msgstr ""
 
-#: en/help_topics/bugs.txt:13
+#: en/help_topics/bugs.txt:13 en/help_topics/configuration.txt:398
 msgid "or::"
 msgstr ""
 
@@ -9868,7 +9925,7 @@
 "``/home/vila/src/bzr/bugs/832013-expand-in-stack`` we'll get::"
 msgstr ""
 
-#: en/help_topics/configuration.txt:318
+#: en/help_topics/configuration.txt:318 en/help_topics/configuration.txt:329
 msgid ""
 "   $ bzr config mypush\n"
 "   lp:~vila/bzr/832013-expand-in-stack"
@@ -10732,7 +10789,11 @@
 "--------------"
 msgstr ""
 
-#: en/help_topics/conflict-types.txt:63
+#: en/help_topics/conflict-types.txt:63 en/help_topics/conflict-types.txt:120
+#: en/help_topics/conflict-types.txt:151 en/help_topics/conflict-types.txt:175
+#: en/help_topics/conflict-types.txt:198 en/help_topics/conflict-types.txt:213
+#: en/help_topics/conflict-types.txt:239 en/help_topics/conflict-types.txt:281
+#: en/help_topics/conflict-types.txt:303 en/help_topics/conflict-types.txt:339
 msgid "Typical message::"
 msgstr ""
 
@@ -10864,14 +10925,17 @@
 "copy\" has been renamed to THIS or OTHER."
 msgstr ""
 
-#: en/help_topics/conflict-types.txt:134
+#: en/help_topics/conflict-types.txt:134 en/help_topics/conflict-types.txt:182
 msgid ""
 "To resolve that kind of conflict, you should rebuild FILE from either "
 "version\n"
 "or a combination of both."
 msgstr ""
 
-#: en/help_topics/conflict-types.txt:137
+#: en/help_topics/conflict-types.txt:137 en/help_topics/conflict-types.txt:185
+#: en/help_topics/conflict-types.txt:226 en/help_topics/conflict-types.txt:252
+#: en/help_topics/conflict-types.txt:291 en/help_topics/conflict-types.txt:326
+#: en/help_topics/conflict-types.txt:361
 msgid "``bzr resolve`` recognizes the following actions:"
 msgstr ""
 
@@ -10889,7 +10953,10 @@
 "``.OTHER`` files if they are still present in the working tree."
 msgstr ""
 
-#: en/help_topics/conflict-types.txt:146
+#: en/help_topics/conflict-types.txt:146 en/help_topics/conflict-types.txt:193
+#: en/help_topics/conflict-types.txt:234 en/help_topics/conflict-types.txt:276
+#: en/help_topics/conflict-types.txt:298 en/help_topics/conflict-types.txt:334
+#: en/help_topics/conflict-types.txt:369
 msgid ""
 "Bazaar cannot auto-detect when conflicts of this kind have been resolved."
 msgstr ""
@@ -11007,7 +11074,7 @@
 "Resolving this issue depends very much on the particular scenario."
 msgstr ""
 
-#: en/help_topics/conflict-types.txt:223
+#: en/help_topics/conflict-types.txt:223 en/help_topics/conflict-types.txt:249
 msgid ""
 "To resolve that kind of conflict, you should either remove or rename the\n"
 "children or the directory or a combination of both."
@@ -11401,7 +11468,7 @@
 "    transition."
 msgstr ""
 
-#: en/help_topics/current-formats.txt:8
+#: en/help_topics/current-formats.txt:8 en/help_topics/other-formats.txt:17
 msgid ""
 "\n"
 "See :doc:`formats-help` for more about storage formats."
@@ -11608,7 +11675,8 @@
 "to use as a starting point::"
 msgstr ""
 
-#: en/help_topics/eol.txt:42
+#: en/help_topics/eol.txt:42 en/help_topics/eol.txt:52
+#: en/help_topics/eol.txt:67 en/help_topics/eol.txt:82
 msgid ""
 "  [name *]\n"
 "  eol = native"
@@ -11781,7 +11849,7 @@
 "====="
 msgstr ""
 
-#: en/help_topics/hooks.txt:5
+#: en/help_topics/hooks.txt:5 en/help_topics/rules.txt:4
 msgid ""
 "Introduction\n"
 "------------"
@@ -11848,7 +11916,8 @@
 "~~~~~~~~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/hooks.txt:38
+#: en/help_topics/hooks.txt:38 en/help_topics/hooks.txt:56
+#: en/help_topics/hooks.txt:102 en/help_topics/hooks.txt:259
 msgid "Introduced in: 2.2"
 msgstr ""
 
@@ -11866,7 +11935,8 @@
 "~~~~"
 msgstr ""
 
-#: en/help_topics/hooks.txt:48
+#: en/help_topics/hooks.txt:48 en/help_topics/hooks.txt:290
+#: en/help_topics/hooks.txt:304
 msgid "Introduced in: 1.8"
 msgstr ""
 
@@ -11896,7 +11966,7 @@
 "~~~~~~~~~~~~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/hooks.txt:66
+#: en/help_topics/hooks.txt:66 en/help_topics/hooks.txt:402
 msgid "Introduced in: 1.4"
 msgstr ""
 
@@ -11908,13 +11978,15 @@
 "uncommit will all trigger this hook."
 msgstr ""
 
-#: en/help_topics/hooks.txt:73
+#: en/help_topics/hooks.txt:73 en/help_topics/hooks.txt:389
 msgid ""
 "post_commit\n"
 "~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/hooks.txt:76
+#: en/help_topics/hooks.txt:76 en/help_topics/hooks.txt:86
+#: en/help_topics/hooks.txt:94 en/help_topics/hooks.txt:110
+#: en/help_topics/hooks.txt:145
 msgid "Introduced in: 0.15"
 msgstr ""
 
@@ -12085,7 +12157,8 @@
 "~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/hooks.txt:184
+#: en/help_topics/hooks.txt:184 en/help_topics/hooks.txt:196
+#: en/help_topics/hooks.txt:205 en/help_topics/hooks.txt:448
 msgid "Introduced in: 1.17"
 msgstr ""
 
@@ -12138,7 +12211,10 @@
 "~~~"
 msgstr ""
 
-#: en/help_topics/hooks.txt:218
+#: en/help_topics/hooks.txt:218 en/help_topics/hooks.txt:226
+#: en/help_topics/hooks.txt:233 en/help_topics/hooks.txt:241
+#: en/help_topics/hooks.txt:248 en/help_topics/hooks.txt:370
+#: en/help_topics/hooks.txt:427
 msgid "Introduced in: 2.4"
 msgstr ""
 
@@ -12238,7 +12314,8 @@
 "~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/hooks.txt:278
+#: en/help_topics/hooks.txt:278 en/help_topics/hooks.txt:297
+#: en/help_topics/hooks.txt:505
 msgid "Introduced in: 1.15"
 msgstr ""
 
@@ -12313,44 +12390,73 @@
 
 #: en/help_topics/hooks.txt:323
 msgid ""
+"post_merge\n"
+"~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:326 en/help_topics/hooks.txt:334
+#: en/help_topics/hooks.txt:384 en/help_topics/hooks.txt:493
+msgid "Introduced in: 2.5"
+msgstr ""
+
+#: en/help_topics/hooks.txt:328
+msgid ""
+"Called after a merge. Receives a Merger object as the single argument.\n"
+"The return value is ignored."
+msgstr ""
+
+#: en/help_topics/hooks.txt:331
+msgid ""
+"pre_merge\n"
+"~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:336
+msgid ""
+"Called before a merge. Receives a Merger object as the single\n"
+"argument."
+msgstr ""
+
+#: en/help_topics/hooks.txt:339
+msgid ""
 "MergeDirectiveHooks\n"
 "-------------------"
 msgstr ""
 
-#: en/help_topics/hooks.txt:326
+#: en/help_topics/hooks.txt:342
 msgid ""
 "merge_request_body\n"
 "~~~~~~~~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/hooks.txt:329
+#: en/help_topics/hooks.txt:345
 msgid "Introduced in: 1.15.0"
 msgstr ""
 
-#: en/help_topics/hooks.txt:331
+#: en/help_topics/hooks.txt:347
 msgid ""
 "Called with a MergeRequestBodyParams when a body is needed for a merge\n"
 "request.  Callbacks must return a body.  If more than one callback is\n"
 "registered, the output of one callback is provided to the next."
 msgstr ""
 
-#: en/help_topics/hooks.txt:335
+#: en/help_topics/hooks.txt:351
 msgid ""
 "MessageEditorHooks\n"
 "------------------"
 msgstr ""
 
-#: en/help_topics/hooks.txt:338
+#: en/help_topics/hooks.txt:354
 msgid ""
 "commit_message_template\n"
 "~~~~~~~~~~~~~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/hooks.txt:341
+#: en/help_topics/hooks.txt:357
 msgid "Introduced in: 1.10"
 msgstr ""
 
-#: en/help_topics/hooks.txt:343
+#: en/help_topics/hooks.txt:359
 msgid ""
 "Called when a commit message is being generated.\n"
 "commit_message_template is called with the bzrlib.commit.Commit object\n"
@@ -12361,13 +12467,13 @@
 "second, and so on."
 msgstr ""
 
-#: en/help_topics/hooks.txt:351
+#: en/help_topics/hooks.txt:367
 msgid ""
 "set_commit_message\n"
 "~~~~~~~~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/hooks.txt:356
+#: en/help_topics/hooks.txt:372
 msgid ""
 "Set a fixed commit message. set_commit_message is called with the\n"
 "bzrlib.commit.Commit object (so you can also change e.g. revision\n"
@@ -12376,17 +12482,29 @@
 "should use the message editor as normal."
 msgstr ""
 
-#: en/help_topics/hooks.txt:362
+#: en/help_topics/hooks.txt:378
 msgid ""
 "MutableTreeHooks\n"
 "----------------"
 msgstr ""
 
-#: en/help_topics/hooks.txt:368
+#: en/help_topics/hooks.txt:381
+msgid ""
+"post_build_tree\n"
+"~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:386
+msgid ""
+"Called after a completely new tree is built. The hook is called with\n"
+"the tree as its only argument."
+msgstr ""
+
+#: en/help_topics/hooks.txt:392
 msgid "Introduced in: 2.0"
 msgstr ""
 
-#: en/help_topics/hooks.txt:370
+#: en/help_topics/hooks.txt:394
 msgid ""
 "Called after a commit is performed on a tree. The hook is called with\n"
 "a bzrlib.mutabletree.PostCommitHookParams object. The mutable tree the\n"
@@ -12394,13 +12512,13 @@
 "that object."
 msgstr ""
 
-#: en/help_topics/hooks.txt:375
+#: en/help_topics/hooks.txt:399
 msgid ""
 "start_commit\n"
 "~~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/hooks.txt:380
+#: en/help_topics/hooks.txt:404
 msgid ""
 "Called before a commit is performed on a tree. The start commit hook\n"
 "is able to change the tree before the commit takes place. start_commit\n"
@@ -12408,42 +12526,42 @@
 "being performed on."
 msgstr ""
 
-#: en/help_topics/hooks.txt:385
+#: en/help_topics/hooks.txt:409
 msgid ""
 "SmartClientHooks\n"
 "----------------"
 msgstr ""
 
-#: en/help_topics/hooks.txt:388
+#: en/help_topics/hooks.txt:412
 msgid ""
 "call\n"
 "~~~~"
 msgstr ""
 
-#: en/help_topics/hooks.txt:391
+#: en/help_topics/hooks.txt:415
 msgid "Introduced in: unknown"
 msgstr ""
 
-#: en/help_topics/hooks.txt:393
+#: en/help_topics/hooks.txt:417
 msgid ""
 "Called when the smart client is submitting a request to the smart\n"
 "server. Called with a bzrlib.smart.client.CallHookParams object.\n"
 "Streaming request bodies, and responses, are not accessible."
 msgstr ""
 
-#: en/help_topics/hooks.txt:397
+#: en/help_topics/hooks.txt:421
 msgid ""
 "SmartServerHooks\n"
 "----------------"
 msgstr ""
 
-#: en/help_topics/hooks.txt:400
+#: en/help_topics/hooks.txt:424
 msgid ""
 "server_exception\n"
 "~~~~~~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/hooks.txt:405
+#: en/help_topics/hooks.txt:429
 msgid ""
 "Called by the bzr server when an exception occurs. server_exception is\n"
 "called with the sys.exc_info() tuple return true for the hook if the\n"
@@ -12451,17 +12569,17 @@
 "normally."
 msgstr ""
 
-#: en/help_topics/hooks.txt:410
+#: en/help_topics/hooks.txt:434
 msgid ""
 "server_started\n"
 "~~~~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/hooks.txt:413
+#: en/help_topics/hooks.txt:437 en/help_topics/hooks.txt:456
 msgid "Introduced in: 0.16"
 msgstr ""
 
-#: en/help_topics/hooks.txt:415
+#: en/help_topics/hooks.txt:439
 msgid ""
 "Called by the bzr server when it starts serving a directory.\n"
 "server_started is called with (backing urls, public url), where\n"
@@ -12470,48 +12588,48 @@
 "served."
 msgstr ""
 
-#: en/help_topics/hooks.txt:421
+#: en/help_topics/hooks.txt:445
 msgid ""
 "server_started_ex\n"
 "~~~~~~~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/hooks.txt:426
+#: en/help_topics/hooks.txt:450
 msgid ""
 "Called by the bzr server when it starts serving a directory.\n"
 "server_started is called with (backing_urls, server_obj)."
 msgstr ""
 
-#: en/help_topics/hooks.txt:429
+#: en/help_topics/hooks.txt:453
 msgid ""
 "server_stopped\n"
 "~~~~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/hooks.txt:434
+#: en/help_topics/hooks.txt:458
 msgid ""
 "Called by the bzr server when it stops serving a directory.\n"
 "server_stopped is called with the same parameters as the\n"
 "server_started hook: (backing_urls, public_url)."
 msgstr ""
 
-#: en/help_topics/hooks.txt:438
+#: en/help_topics/hooks.txt:462
 msgid ""
 "StatusHooks\n"
 "-----------"
 msgstr ""
 
-#: en/help_topics/hooks.txt:441
+#: en/help_topics/hooks.txt:465
 msgid ""
 "post_status\n"
 "~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/hooks.txt:444
+#: en/help_topics/hooks.txt:468 en/help_topics/hooks.txt:479
 msgid "Introduced in: 2.3"
 msgstr ""
 
-#: en/help_topics/hooks.txt:446
+#: en/help_topics/hooks.txt:470
 msgid ""
 "Called with argument StatusHookParams after Bazaar has displayed the\n"
 "status. StatusHookParams has the attributes (old_tree, new_tree,\n"
@@ -12520,13 +12638,13 @@
 "status command. to_file is the output stream for writing."
 msgstr ""
 
-#: en/help_topics/hooks.txt:452
+#: en/help_topics/hooks.txt:476
 msgid ""
 "pre_status\n"
 "~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/hooks.txt:457
+#: en/help_topics/hooks.txt:481
 msgid ""
 "Called with argument StatusHookParams before Bazaar displays the\n"
 "status. StatusHookParams has the attributes (old_tree, new_tree,\n"
@@ -12535,19 +12653,38 @@
 "status command. to_file is the output stream for writing."
 msgstr ""
 
-#: en/help_topics/hooks.txt:463
+#: en/help_topics/hooks.txt:487
+msgid ""
+"TransportHooks\n"
+"--------------"
+msgstr ""
+
+#: en/help_topics/hooks.txt:490
+msgid ""
+"post_connect\n"
+"~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:495
+msgid ""
+"Called after a new connection is established or a reconnect occurs.\n"
+"The sole argument passed is either the connected transport or smart\n"
+"medium instance."
+msgstr ""
+
+#: en/help_topics/hooks.txt:499
 msgid ""
 "RioVersionInfoBuilderHooks\n"
 "--------------------------"
 msgstr ""
 
-#: en/help_topics/hooks.txt:466
+#: en/help_topics/hooks.txt:502
 msgid ""
 "revision\n"
 "~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/hooks.txt:471
+#: en/help_topics/hooks.txt:507
 msgid ""
 "Invoked when adding information about a revision to the RIO stanza\n"
 "that is printed. revision is called with a revision object and a RIO\n"
@@ -12859,14 +12996,16 @@
 "    is specified, the parent branch is used instead."
 msgstr ""
 
-#: en/help_topics/revisionspec.txt:73
+#: en/help_topics/revisionspec.txt:73 en/help_topics/revisionspec.txt:85
 msgid ""
 "    The common ancestor is the last revision that existed in both\n"
 "    branches. Usually this is the branch point, but it could also be\n"
 "    a revision that was merged."
 msgstr ""
 
-#: en/help_topics/revisionspec.txt:77
+#: en/help_topics/revisionspec.txt:77 en/help_topics/revisionspec.txt:93
+#: en/help_topics/revisionspec.txt:109 en/help_topics/revisionspec.txt:119
+#: en/help_topics/revisionspec.txt:153
 msgid "    Examples::"
 msgstr ""
 

